(* ::Package:: *)

(* AutoDipole - Package of an automated dipole subtraction by
Kouhei Hasegawa, Sven Moch, and Peter Uwer, 2009 *)


(* SuperAutoDipole - MSSM extension by Kouhei Hasegawa, 2010 *)


(* Filename:PDFfactorizationfortran.m  :conversion into FORTRAN form *)


(* To convert P- and K-terms into Fortran expression and to write down fortran files,
 1.PKterm.f
 2.checkPK.f
 *)


(* Write PKterm.f *)


PandKtermsfortran:=Module[{},
targetPKdir=StringJoin[targetdir,"/PK"];
CreateDirectory[targetPKdir];
namePKtermf=StringJoin[targetPKdir,"/PKterm.f"];
namecheckPKf=StringJoin[targetPKdir,"/checkPK.f"];
namenexternalPKinc=StringJoin[targetPKdir,"/nexternal.inc"];

str61=OpenWrite[namePKtermf,FormatType->FortranForm,PageWidth->65];
createPKfortran;
Close[str61];
str62=OpenWrite[namecheckPKf,FormatType->FortranForm,PageWidth->65];
writecheckPK;
Close[str62];
str63=OpenWrite[namenexternalPKinc,FormatType->FortranForm,PageWidth->65];
writenexternalPK;
Close[str63];
]


createPKfortran:=Module[{},   
WriteString[str61,
"c Generated by AutoDipole\n",
"c Kouhei Hasegawa, Sven Moch, and Peter Uwer, 2009\n",
"c SUSY extension by Kouhei Hasegawa, 2010\n",
"c Filename:PKterm.f\n",
"c Subroutine: PKterm evaluates all P and K terms\n",
"c\n",
"c input\n",
"c   real p      :a phase space point\n",
"c   real x      :a momentum fraction\n",
"c output\n",
"c   real SumP   :sum of all P-terms\n",
"c   real SumK   :sum of all K-terms\n",
"\n"];       
If[ pkinfo[1]==1, writePKterm12[1]];
If[ pkinfo[2]==1, writePKterm12[2]];
                  writePKSubroutines;
]


writePKterm12[leg_]:=Module[{},
                  writePKhead[leg];
                  writePKscalar[leg];
                  writePKcallCLB[leg];
                  writePKterm[leg];
                  writePKSum[leg];
                  endformatPK[str61];
]


writePKhead[leg_]:=Module[{},
WriteString[str61,"c Subroutine to calculate P and K terms of Leg ",leg,"\n"];
WriteString[str61,"c LO and Virtual process:",{{XV[1],p[1]},{XV[2],p[2]}}," --> ",tfinalV,"\n"];
If[pkdiagonal[leg] >= 1, WriteString[str61,"c B1:",sepPK1[leg,1],"-",sepPK1[leg,2],"\n"];];
If[pkecsp[leg,61] >= 1, WriteString[str61,"c B3u:",sepPK3u[leg,1],"-",sepPK3u[leg,2],"\n"];];
If[pkecsp[leg,62] >= 1, WriteString[str61,"c B3ubar:",sepPK3ubar[leg,1],"-",sepPK3ubar[leg,2],"\n"];];
If[pkecsp[leg,63] >= 1, WriteString[str61,"c B3d:",sepPK3d[leg,1],"-",sepPK3d[leg,2],"\n"];];
If[pkecsp[leg,64] >= 1, WriteString[str61,"c B3dbar:",sepPK3dbar[leg,1],"-",sepPK3dbar[leg,2],"\n"];];
If[pkecsp[leg,65] >= 1, WriteString[str61,"c B3s:",sepPK3s[leg,1],"-",sepPK3s[leg,2],"\n"];];
If[pkecsp[leg,66] >= 1, WriteString[str61,"c B3sbar:",sepPK3sbar[leg,1],"-",sepPK3sbar[leg,2],"\n"];];
If[pkecsp[leg,67] >= 1, WriteString[str61,"c B3c:",sepPK3c[leg,1],"-",sepPK3c[leg,2],"\n"];];
If[pkecsp[leg,68] >= 1, WriteString[str61,"c B3cbar:",sepPK3cbar[leg,1],"-",sepPK3cbar[leg,2],"\n"];];
If[pkecsp[leg,69] >= 1, WriteString[str61,"c B3b:",sepPK3b[leg,1],"-",sepPK3b[leg,2],"\n"];];
If[pkecsp[leg,70] >= 1, WriteString[str61,"c B3bbar:",sepPK3bbar[leg,1],"-",sepPK3bbar[leg,2],"\n"];];
If[pkecsp[leg,71] >= 1, WriteString[str61,"c B4u:",sepPK4u[leg,1],"-",sepPK4u[leg,2],"\n"];];
If[pkecsp[leg,72] >= 1, WriteString[str61,"c B4ubar:",sepPK4ubar[leg,1],"-",sepPK4ubar[leg,2],"\n"];];
If[pkecsp[leg,73] >= 1, WriteString[str61,"c B4d:",sepPK4d[leg,1],"-",sepPK4d[leg,2],"\n"];];
If[pkecsp[leg,74] >= 1, WriteString[str61,"c B4dbar:",sepPK4dbar[leg,1],"-",sepPK4dbar[leg,2],"\n"];];
If[pkecsp[leg,75] >= 1, WriteString[str61,"c B4s:",sepPK4s[leg,1],"-",sepPK4s[leg,2],"\n"];];
If[pkecsp[leg,76] >= 1, WriteString[str61,"c B4sbar:",sepPK4sbar[leg,1],"-",sepPK4sbar[leg,2],"\n"];];
If[pkecsp[leg,77] >= 1, WriteString[str61,"c B4c:",sepPK4c[leg,1],"-",sepPK4c[leg,2],"\n"];];
If[pkecsp[leg,78] >= 1, WriteString[str61,"c B4cbar:",sepPK4cbar[leg,1],"-",sepPK4cbar[leg,2],"\n"];];
If[pkecsp[leg,79] >= 1, WriteString[str61,"c B4b:",sepPK4b[leg,1],"-",sepPK4b[leg,2],"\n"];];
If[pkecsp[leg,80] >= 1, WriteString[str61,"c B4bbar:",sepPK4bbar[leg,1],"-",sepPK4bbar[leg,2],"\n"];];
WriteString[str61,"c SumP = Sum_{i=1}^{", pktotal[leg], "}P(i) \n"];
WriteString[str61,"c SumK = Sum_{i=1}^{", pktotal[leg], "}K(i) \n\n"];
WriteString[str61,"      subroutine PKterm",leg,"(p,x,SumP,SumK) \n"];
WriteString[str61,"      implicit none \n","\n"];
WriteString[str61,"      integer i,j \n",
"      double precision p(0:3,1:",nfieldPKuni,"),SumP,SumK,Pt(",pktotal[leg],"),K(",pktotal[leg],")\n",
"      double precision SumP1,SumP3u,SumP3ubar,SumP4u,SumP4ubar\n",
"      double precision SumP3d,SumP3dbar,SumP4d,SumP4dbar\n",
"      double precision SumK1,SumK3u,SumK3ubar,SumK4u,SumK4ubar\n",
"      double precision SumK3d,SumK3dbar,SumK4d,SumK4dbar\n",
"      double precision SumP3s,SumP3sbar,SumP4s,SumP4sbar\n",
"      double precision SumP3c,SumP3cbar,SumP4c,SumP4cbar\n",
"      double precision SumK3b,SumK3bbar,SumK4b,SumK4bbar\n",
"      double precision Pi,rtwo,Eul,AL,CF,CA,TR,mt,mb,dot,mu,Nf,log2\n",
"      double precision muF,x,plusd,delta\n"
];
WriteString[str61,"      double precision CLPK(",pktotal[leg],"),q(0:3,1:",nfieldpk[1],"),dilog\n"];
WriteString[str61,"      double precision "];
Do[ 
Do[
If[i != nfieldPKuni-1 || j != nfieldPKuni, WriteString[str61,"s",i,j,","]];
If[i == nfieldPKuni-1 && j == nfieldPKuni, WriteString[str61,"s",i,j]];
 ,{j,i+1,nfieldPKuni}];
,{i,1,nfieldPKuni-1}];
If[model===mssm,
 WriteString[str61,"\n      double precision msg,msul,msur,msdl,msdr,mssl,mssr,mscl,mscr\n"];
 WriteString[str61,"      double precision mst1,mst2,msb1,msb2"];
];
WriteString[str61," \n \n"];
WriteString[str61,"      common /MASS/ mt,mb  \n"];
WriteString[str61,"      common /usedalpha/ AL  \n"];
If[model===mssm,
 WriteString[str61,"      common /SUSYMASS/ msg,msul,msur,msdl,msdr,mssl,mssr,mscl,mscr,\n"];
 WriteString[str61,"     &mst1,mst2,msb1,msb2"];
];
WriteString[str61,"    \n"];
WriteString[str61,
"      Pi=3.141592653589793238D0 \n",
"      Eul=0.5772156649015328606065120d0 \n",
"      rtwo=dsqrt(2.d0) \n",
"      log2=Log(2.d0) \n",
"      CF=4.D0/3.D0 \n",
"      CA=3.D0 \n",
"      TR=0.5D0 \n"];
WriteString[str61,"      muF=",NumberForm[muFfort,18],"D0 \n"];
WriteString[str61,"      Nf=1.D0 \n"];
WriteString[str61,"\n\n"];
];


writePKscalar[leg_]:=Module[{},
Do[ 
Do[
   If[ i==leg || j==leg,
    WriteString[str61,"      s",i,j,"=2.d0*dot(p(0,",i,"),p(0,",j,"))/x \n"];,
    WriteString[str61,"      s",i,j,"=2.d0*dot(p(0,",i,"),p(0,",j,")) \n"]
    ];
,{j,i+1,nfieldPKuni}];
,{i,1,nfieldPKuni-1}];
WriteString[str61,"  \n"];
];


writePKcallCLB[leg_]:=Module[{},
WriteString[str61,
"      do i=0,3 \n",
"       q(i,1)=p(i,1) \n",
"       q(i,2)=p(i,2) \n",
"      enddo \n",
"      \n"];

If[ pkdiagonal[leg] >=1, writeCLPK[sepPK1[leg,1],sepPK1[leg,2],leg];WriteString[str61,"\n"];];

If[ pkecsp[leg,61] >=1, writeCLPK[sepPK3u[leg,1],sepPK3u[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,62] >=1, writeCLPK[sepPK3ubar[leg,1],sepPK3ubar[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,63] >=1, writeCLPK[sepPK3d[leg,1],sepPK3d[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,64] >=1, writeCLPK[sepPK3dbar[leg,1],sepPK3dbar[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,65] >=1, writeCLPK[sepPK3s[leg,1],sepPK3s[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,66] >=1, writeCLPK[sepPK3sbar[leg,1],sepPK3sbar[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,67] >=1, writeCLPK[sepPK3c[leg,1],sepPK3c[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,68] >=1, writeCLPK[sepPK3cbar[leg,1],sepPK3cbar[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,69] >=1, writeCLPK[sepPK3b[leg,1],sepPK3b[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,70] >=1, writeCLPK[sepPK3bbar[leg,1],sepPK3bbar[leg,2],leg];WriteString[str61,"\n"];];

If[ pkecsp[leg,71] >=1, writeCLPK[sepPK4u[leg,1],sepPK4u[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,72] >=1, writeCLPK[sepPK4ubar[leg,1],sepPK4ubar[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,73] >=1, writeCLPK[sepPK4d[leg,1],sepPK4d[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,74] >=1, writeCLPK[sepPK4dbar[leg,1],sepPK4dbar[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,75] >=1, writeCLPK[sepPK4s[leg,1],sepPK4s[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,76] >=1, writeCLPK[sepPK4sbar[leg,1],sepPK4sbar[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,77] >=1, writeCLPK[sepPK4c[leg,1],sepPK4c[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,78] >=1, writeCLPK[sepPK4cbar[leg,1],sepPK4cbar[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,79] >=1, writeCLPK[sepPK4b[leg,1],sepPK4b[leg,2],leg];WriteString[str61,"\n"];];
If[ pkecsp[leg,80] >=1, writeCLPK[sepPK4bbar[leg,1],sepPK4bbar[leg,2],leg];WriteString[str61,"\n"];];

WriteString[str61, "\n"];

];


writeCLPK[initialPK_,finalPK_,leg_]:=Module[{},
Do[
If[ matchkindPK[leg,i]==0, 
 WriteString[str61,
  "      call cmatrix1(p(0,1),",matchPK[leg,i],",CLPK(",i,")) \n"
  ];
];
If[ matchkindPK[leg,i]==1, 
 WriteString[str61,
  "      call mexchange(q(0,1),p(0,1),",Part[exmomPK[leg,i],1],","
                      ,Part[exmomPK[leg,i],2] ,") \n",
  "      call cmatrix1(q(0,1),",matchPK[leg,i],",CLPK(",i,")) \n"
  ];
];
If[ matchkindPK[leg,i]==-2,
 WriteString[str61,
  "      call smatrix(p(0,1),CLPK(",i,")) \n"
  ];
];

,{i,initialPK,finalPK}];
]


writePKterm[leg_]:=Module[{},
Do[
  WriteString[str61,"      Pt(",i,")=\n"];
  WriteString[str61,"     - "];
  Write[str61,P[leg,i]];
  WriteString[str61,"   \n"];
,{i,1,pktotal[leg]}];
WriteString[str61,"\n\n"];
Do[
  WriteString[str61,"      K(",i,")=\n"];
  WriteString[str61,"     - "];
  Write[str61,K[leg,i]];
  WriteString[str61,"   \n"];
,{i,1,pktotal[leg]}];
]


writePKSum[leg_]:=Module[{},
If[ pkdiagonal[leg] >=1,separatesum[SumP1,SumK1,sepPK1[leg,1],sepPK1[leg,2]];];
If[ pkecsp[leg,61] >=1,separatesum[SumP3u,SumK3u,sepPK3u[leg,1],sepPK3u[leg,2]];];
If[ pkecsp[leg,62] >=1,separatesum[SumP3ubar,SumK3ubar,sepPK3ubar[leg,1],sepPK3ubar[leg,2]];];
If[ pkecsp[leg,63] >=1,separatesum[SumP3d,SumK3d,sepPK3d[leg,1],sepPK3d[leg,2]];];
If[ pkecsp[leg,64] >=1,separatesum[SumP3dbar,SumK3dbar,sepPK3dbar[leg,1],sepPK3dbar[leg,2]];];
If[ pkecsp[leg,65] >=1,separatesum[SumP3s,SumK3s,sepPK3s[leg,1],sepPK3s[leg,2]];];
If[ pkecsp[leg,66] >=1,separatesum[SumP3sbar,SumK3sbar,sepPK3sbar[leg,1],sepPK3sbar[leg,2]];];
If[ pkecsp[leg,67] >=1,separatesum[SumP3c,SumK3c,sepPK3c[leg,1],sepPK3c[leg,2]];];
If[ pkecsp[leg,68] >=1,separatesum[SumP3cbar,SumK3cbar,sepPK3cbar[leg,1],sepPK3cbar[leg,2]];];
If[ pkecsp[leg,69] >=1,separatesum[SumP3b,SumK3b,sepPK3b[leg,1],sepPK3b[leg,2]];];
If[ pkecsp[leg,70] >=1,separatesum[SumP3bbar,SumK3bbar,sepPK3bbar[leg,1],sepPK3bbar[leg,2]];];

If[ pkecsp[leg,71] >=1,separatesum[SumP4u,SumK4u,sepPK4u[leg,1],sepPK4u[leg,2]];];
If[ pkecsp[leg,72] >=1,separatesum[SumP4ubar,SumK4ubar,sepPK4ubar[leg,1],sepPK4ubar[leg,2]];];
If[ pkecsp[leg,73] >=1,separatesum[SumP4d,SumK4d,sepPK4d[leg,1],sepPK4d[leg,2]];];
If[ pkecsp[leg,74] >=1,separatesum[SumP4dbar,SumK4dbar,sepPK4dbar[leg,1],sepPK4dbar[leg,2]];];
If[ pkecsp[leg,75] >=1,separatesum[SumP4s,SumK4s,sepPK4s[leg,1],sepPK4s[leg,2]];];
If[ pkecsp[leg,76] >=1,separatesum[SumP4sbar,SumK4sbar,sepPK4sbar[leg,1],sepPK4sbar[leg,2]];];
If[ pkecsp[leg,77] >=1,separatesum[SumP4c,SumK4c,sepPK4c[leg,1],sepPK4c[leg,2]];];
If[ pkecsp[leg,78] >=1,separatesum[SumP4cbar,SumK4cbar,sepPK4cbar[leg,1],sepPK4cbar[leg,2]];];
If[ pkecsp[leg,79] >=1,separatesum[SumP4b,SumK4b,sepPK4b[leg,1],sepPK4b[leg,2]];];
If[ pkecsp[leg,80] >=1,separatesum[SumP4bbar,SumK4bbar,sepPK4bbar[leg,1],sepPK4bbar[leg,2]];];

WriteString[str61,
"      SumP = 0.d0 \n",
"      SumP = "];
If[ pkdiagonal[leg] >=1,WriteString[str61,"SumP1"];];
If[ pkecsp[leg,61] >=1,WriteString[str61,"+SumP3u"];];
If[ pkecsp[leg,62] >=1,WriteString[str61,"+SumP3ubar"];];
If[ pkecsp[leg,63] >=1,WriteString[str61,"+SumP3d"];];
If[ pkecsp[leg,64] >=1,WriteString[str61,"+SumP3dbar"];];
If[ pkecsp[leg,65] >=1,WriteString[str61,"+SumP3s"];];
If[ pkecsp[leg,66] >=1,WriteString[str61,"+SumP3sbar"];];
If[ pkecsp[leg,67] >=1,WriteString[str61,"+SumP3c"];];
If[ pkecsp[leg,68] >=1,WriteString[str61,"+SumP3cbar"];];
If[ pkecsp[leg,69] >=1,WriteString[str61,"+SumP3b"];];
If[ pkecsp[leg,70] >=1,WriteString[str61,"+SumP3bbar"];];

If[ pkecsp[leg,71] >=1,WriteString[str61,"+SumP4u"];];
If[ pkecsp[leg,72] >=1,WriteString[str61,"+SumP4ubar"];];
If[ pkecsp[leg,73] >=1,WriteString[str61,"+SumP4d"];];
If[ pkecsp[leg,74] >=1,WriteString[str61,"+SumP4dbar"];];
If[ pkecsp[leg,75] >=1,WriteString[str61,"+SumP4s"];];
If[ pkecsp[leg,76] >=1,WriteString[str61,"+SumP4sbar"];];
If[ pkecsp[leg,77] >=1,WriteString[str61,"+SumP4c"];];
If[ pkecsp[leg,78] >=1,WriteString[str61,"+SumP4cbar"];];
If[ pkecsp[leg,79] >=1,WriteString[str61,"+SumP4b"];];
If[ pkecsp[leg,80] >=1,WriteString[str61,"+SumP4bbar"];];

WriteString[str61,"\n"];
WriteString[str61,
"      SumK = 0.d0 \n",
"      SumK = "];
If[ pkdiagonal[leg] >=1,WriteString[str61,"SumK1"];];
If[ pkecsp[leg,61] >=1,WriteString[str61,"+SumK3u"];];
If[ pkecsp[leg,62] >=1,WriteString[str61,"+SumK3ubar"];];
If[ pkecsp[leg,63] >=1,WriteString[str61,"+SumK3d"];];
If[ pkecsp[leg,64] >=1,WriteString[str61,"+SumK3dbar"];];
If[ pkecsp[leg,65] >=1,WriteString[str61,"+SumK3s"];];
If[ pkecsp[leg,66] >=1,WriteString[str61,"+SumK3sbar"];];
If[ pkecsp[leg,67] >=1,WriteString[str61,"+SumK3c"];];
If[ pkecsp[leg,68] >=1,WriteString[str61,"+SumK3cbar"];];
If[ pkecsp[leg,69] >=1,WriteString[str61,"+SumK3b"];];
If[ pkecsp[leg,70] >=1,WriteString[str61,"+SumK3bbar"];];
If[ pkecsp[leg,71] >=1,WriteString[str61,"+SumK4u"];];
If[ pkecsp[leg,72] >=1,WriteString[str61,"+SumK4ubar"];];
If[ pkecsp[leg,73] >=1,WriteString[str61,"+SumK4d"];];
If[ pkecsp[leg,74] >=1,WriteString[str61,"+SumK4dbar"];];
If[ pkecsp[leg,75] >=1,WriteString[str61,"+SumK4s"];];
If[ pkecsp[leg,76] >=1,WriteString[str61,"+SumK4sbar"];];
If[ pkecsp[leg,77] >=1,WriteString[str61,"+SumK4c"];];
If[ pkecsp[leg,78] >=1,WriteString[str61,"+SumK4cbar"];];
If[ pkecsp[leg,79] >=1,WriteString[str61,"+SumK4b"];];
If[ pkecsp[leg,80] >=1,WriteString[str61,"+SumK4bbar"];];

WriteString[str61,"\n\n"];
]


separatesum[sump_,sumk_,initial_,final_]:=Module[{},
WriteString[str61,
"      ",sump," = 0.d0 \n",
"      ",sumk," = 0.d0 \n",
"      do i=",initial,",",final," \n",
"      ",sump," = ",sump," + Pt(i) \n",
"      ",sumk," = ",sumk," + K(i) \n",
"      enddo",
"\n","\n"
];
]


endformatPK[str_]:=Module[{},WriteString[str,"      return \n","      end \n","\n"];]


writePKSubroutines:=Module[{},
WriteString[str61,
"      subroutine mexchange(q,p,i,j)\n",
"      implicit none\n",
"      integer i,j,k,l\n",
"      double precision p(0:3,1:",nfieldPKuni,"),q(0:3,1:",nfieldPKuni,")\n",
"      do k=0,3\n",
"       do l=3,",nfieldPKuni,"\n",
"        q(k,l) = p(k,l)\n",
"       enddo\n",
"       q(k,i) = p(k,j)\n",
"       q(k,j) = p(k,i)\n",
"      enddo\n",
"      return\n",
"      end\n",
" \n"];
WriteString[str61,
"      double precision function plusd(xx)\n",
"      implicit none\n",
"      double precision xx\n",
"      plusd=xx\n",
"      return\n",
"      end\n\n"];
WriteString[str61,
"      double precision function delta(yy)\n",
"      implicit none\n",
"      double precision yy\n",
"      delta=0.d0\n",
"      return\n",
"      end\n\n"];
];


(* Write checkPK.f *)


writecheckPK:=Module[{},
WriteString[str62,
"c Generated by AutoDipole\n",
"c Kouhei Hasegawa, Sven Moch, and Peter Uwer, 2009\n",
"c Filename:checkPK.f\n",
"c Program: checkPK evaluates P and K terms on 10 randomly chosen phase space points\n",
"c\n",
"c input  :10 randomly chosen phase space points in inputmLO.h\n",
"c output :the values of P and K terms\n",
"c \n"];
WriteString[str62,
"      program checkPK\n",
"      implicit none\n\n",
"      double precision p(0:3,1:",nfieldPKuni,"),SumP,SumK,x\n",
"      integer i\n",
"      double precision msqLO,AL,pi,ALmsqLO,ratio,acc,mt,mb\n"];
If[model===mssm,
 WriteString[str62,"      double precision msg,msul,msur,msdl,msdr,mssl,mssr,mscl,mscr\n"];
 WriteString[str62,"      double precision mst1,mst2,msb1,msb2\n"];
];
WriteString[str62,
"      common /INPUTMPK/ p\n",
"      common /usedalpha/ AL\n",
"      common /MASS/ mt,mb\n"];
If[model===mssm,
 WriteString[str62,"      common /SUSYMASS/ msg,msul,msur,msdl,msdr,mssl,mssr,mscl,mscr,\n"];
 WriteString[str62,"     &mst1,mst2,msb1,msb2\n"];
];
WriteString[str62,
"      include 'coupl.inc'\n",
"      include 'nexternal.inc'\n",
"      call setpara('param_card.dat',.true.)\n",
"      pi=3.141592653589793238d0\n",
"      AL=g**2*(4.d0*pi)**(-1)\n",
"      mt=tmass\n",
"      mb=bmass\n"];
If[model===mssm,
 WriteString[str62,"      msg=mgo\n"];
 WriteString[str62,"      msul=mul\n"];
 WriteString[str62,"      msur=mur\n"];
 WriteString[str62,"      msdl=mdl\n"];
 WriteString[str62,"      msdr=mdr\n"];
 WriteString[str62,"      mssl=msl\n"];
 WriteString[str62,"      mssr=msr\n"];
 WriteString[str62,"      mscl=mcl\n"];
 WriteString[str62,"      mscr=mcr\n"];
 WriteString[str62,"      mst1=mt1\n"];
 WriteString[str62,"      mst2=mt2\n"];
 WriteString[str62,"      msb1=mb1\n"];
 WriteString[str62,"      msb2=mb2\n"];
];
WriteString[str62,
"      x=0.25d0\n",
"      call printframePK\n"];
If[ pkinfo[1]==1, 
WriteString[str62,
"      write(*,*) '[Leg1]'\n",
"      do i=1,10\n",
"       call readmomenta2\n",
"       call PKterm1(p,x,SumP,SumK)\n",
"       call printresultPK(i,SumP,SumK)\n",
"      enddo\n"];
];
If[ pkinfo[2]==1, 
WriteString[str62,
"      write(*,*) ''\n",
"      write(*,*) '[Leg2]'\n",
"      do i=1,10\n",
"       call readmomenta2\n",
"       call PKterm2(p,x,SumP,SumK)\n",
"       call printresultPK(i,SumP,SumK)\n",
"      enddo\n"];
];
WriteString[str62,
"      end\n",
"       \n",
"       \n",
"      subroutine readmomenta2\n",
"      implicit none\n",
"      integer idy1\n",
"      double precision dummy\n",
"      double precision p(0:3,1:",nfield,")\n",
"      common /INPUTMPK/ p\n",
"       \n",
"      open (unit=11, file ='inputmLO.h', status = 'old')\n"
];
Do[WriteString[str62,
"      read  (11,*) idy1, p(0,",i,"), p(1,",i,"), p(2,",i,"), p(3,",i,")\n"
],{i,1,nfield}];
WriteString[str62,"      read  (11,*) dummy",
"  \n\n",
"      return\n",
"      end\n",
"       \n",
"      double precision function dot(p1,p2) \n",
"      implicit none\n",
"      double precision p1(0:3),p2(0:3)\n",
"      dot=p1(0)*p2(0)-p1(1)*p2(1)-p1(2)*p2(2)-p1(3)*p2(3)\n",
"      end\n",
"       \n",
"\n",
"      subroutine printframePK\n",
"      implicit none\n",
"      \n",
"      write(*,*) '          SumP                       SumK'\n",
"      \n",
"      return\n",
"      end\n",
"      \n",
"      subroutine printresultPK(i,SumP,SumK)\n",
"      implicit none\n",
"      \n",
"      integer i\n",
"      double precision SumP,SumK\n",
"      \n",
"      write(*,'(1x,i3,1x,2e27.15)') i,SumP,SumK\n",
"      \n",
"      return\n",
"      end\n",
"\n"]
]


writenexternalPK:=Module[{},
WriteString[str63,
"      integer    nexternal \n",
"      parameter (nexternal=  ",nfieldPKuni,") \n",
"      integer    nincoming \n",
"      parameter (nincoming=  2) \n"];
]
