#!/bin/sh
#
# AutoDipole package by Kouhei Hasegawa, Sven Moch, and Peter Uwer, 2009
#
# Collection of shell scripts to be used during run
#
# $Modified: Thu Sep 17 11:45:50 2009 by uwer $
# TEMPLATES -- location where the templates are stored
# PATCHEDMG_ME -- Location of the patched MG_ME version

echo 'Current directory'
echo `pwd`
WORKPATH=`pwd`
echo $WORKPATH
cd ../../../
echo 'Package directory'
echo `pwd`
PACKAGEPATH=`pwd`
echo $PACKAGEPATH
PATCHEDMG_ME=$PACKAGEPATH/patch
TEMPLATES=$PACKAGEPATH/lib/patch/templates
PROCESSPATH=$PACKAGEPATH/process
cd $WORKPATH
echo 'I return to working directory'
echo $WORKPATH

# functions used in getamplitude.sh

#
# replace_input_amp
#
function replace_input_amp {
cp -f $TEMPLATES/proc_card_input.dat $PATCHEDMG_ME/MyProcDir/Cards/proc_card.dat
ed $PATCHEDMG_ME/MyProcDir/Cards/proc_card.dat <<EOF
,s/inputproc/$1/g
wq
EOF
}

#
# replace_driver_amp
#
function replace_driver_amp {
rm -f $PATCHEDMG_ME/MadGraphII/driver.f
cp -f $TEMPLATES/driver.f $PATCHEDMG_ME/MadGraphII/driver.f
ed $PATCHEDMG_ME/MadGraphII/driver.f << EOF
,s/DIPOLESWITCH/.true./g
,s/COLORSWITCH/.false./g
,s/HELICITYSWITCH/$1/g
,s/EMITTERLEG/3/g
,s/EMITTERKIND/1/g
,s/EMITTERFININI/1/g
,s/SPECTATORLEG/4/g
,s/SPECTATORKIND/2/g
,s/SPECTATORFININI/1/g
wq
EOF
}

#
# replace_driver_normal
#
function replace_driver_normal {
rm -f $PATCHEDMG_ME/MadGraphII/driver.f
cp -f $TEMPLATES/driver.f $PATCHEDMG_ME/MadGraphII/driver.f
ed $PATCHEDMG_ME/MadGraphII/driver.f << EOF
,s/DIPOLESWITCH/.false./g
,s/COLORSWITCH/.false./g
,s/HELICITYSWITCH/.false./g
,s/EMITTERLEG/3/g
,s/EMITTERKIND/1/g
,s/EMITTERFININI/1/g
,s/SPECTATORLEG/4/g
,s/SPECTATORKIND/2/g
,s/SPECTATORFININI/1/g
wq
EOF
}


#
# ampmake
#
function ampmake {

oldpath=`pwd`
cd $PATCHEDMG_ME/MadGraphII/
make mg2_sa 
cd ../MyProcDir/
./bin/newprocess

if [ -e ./SubProcesses/noborn ]
then
echo 'Born does not exist'
rm ./SubProcesses/noborn
cd $oldpath
rm -f errorborn

cp -f $TEMPLATES/errorborn ./errorborn
ed errorborn << EOF
,s/dummy/$3/g
wq
EOF

else
cp -f ./SubProcesses/"$1"/matrix.f $oldpath/"$2"
cd $oldpath
fi

}

#
# cmatriximod
#
function cmatriximod {

echo $1
echo "$2"
echo "$3"
cp $1 $4
ed $4 <<EOF
,s/CMATRIX/$2/g
,s/(P1,ANS)/(P1,k,ANS)/g
,s/allcolor.inc/allcolor$3.inc/g
,s/,JC(1))/,JC(1),k)/g
,s/(P,NHEL,IC)/(P,NHEL,IC,k)/g
,s/MATRIX/$3/g
wq
EOF
}

#
# cmatrixidhmod
#
function cmatrixidhmod {

echo $1
echo "$2"
echo "$3"

cp $1 $4
ed $4 <<EOF
,s/CMATRIX/$2/g
,s/(P1,ANS/(P1,k,ANS/g
,s/allcolor.inc/allcolor$5.inc/g
,s/(P ,NHEL(1,IHEL)/(P,k,NHEL(1,IHEL)/g
,s/MATRIXDH/$3/g
,s/MATRIX/$3/g
wq
EOF

}

# getinputm.csh
function getinputm {
oldpath=`pwd`
cd $PATCHEDMG_ME/MyProcDir/SubProcesses/"$1"/
make
./check > inputm.h
cp inputm.h pmass.inc matrix.ps $oldpath
cd $oldpath
}


#getLO.csh 
function getLO {
oldpath=`pwd`
cd $PATCHEDMG_ME/MadGraphII
make mg2_sa 
cd ../MyProcDir/
./bin/newprocess

if [ -3 ./SubProcesses/noborn ]
then
echo 'Born does not exist'
rm ./SubProcesses/noborn
cd $oldpath
rm -f errorborn
cp -f $TEMPLATES/errorborn ./errorborn
ed errorborn << EOF
,s/dummy/LO/g
wq
EOF

else
cp ./SubProcesses/"$1"/matrix.f $oldpath/"$2"
cd ./SubProcesses/"$1"/
if [ -f $oldpath/inputmLO.h ]
then
echo 'inputmLO already exists'
else
make
./check > inputmLO.h
cp inputmLO.h $oldpath
cp pmass.inc $oldpath/pmassLO.inc
cd $oldpath
fi
fi
}


# functions used in getallcolor.sh

#
# replace_input
#
function replace_input {
cp -f $TEMPLATES/proc_card_input.dat $PATCHEDMG_ME/MyProcDir/Cards/proc_card.dat
ed $PATCHEDMG_ME/MyProcDir/Cards/proc_card.dat <<EOF
,s/inputproc/$1/g
wq
EOF
}

#
# replace
#
function replace {
rm -f $PATCHEDMG_ME/MadGraphII/driver.f
cp -f $TEMPLATES/driver.f $PATCHEDMG_ME/MadGraphII/driver.f
ed $PATCHEDMG_ME/MadGraphII/driver.f << EOF
,s/DIPOLESWITCH/.true./g
,s/COLORSWITCH/.true./g
,s/HELICITYSWITCH/.false./g
,s/EMITTERLEG/$1/g
,s/EMITTERKIND/$2/g
,s/EMITTERFININI/$3/g
,s/SPECTATORLEG/$4/g
,s/SPECTATORKIND/$5/g
,s/SPECTATORFININI/$6/g
wq
EOF
}

#
# colormake
#
function colormake {
oldpath=`pwd`
cd $PATCHEDMG_ME/MadGraphII/
make mg2_sa 
cd ../MyProcDir/
bin/newprocess
cp -f ./SubProcesses/colormatrix.data $oldpath/
cd $oldpath
}

#
# modcolormatrix
#
function modcolormatrix {
dipn=$1
mv -f colormatrix.data color$dipn
ed color$dipn <<EOF
,s/)\//,$dipn)\//g
,s/),/,$dipn),/g
,s/CF/CL/g
,s/Denom/Denol/g
,s/\/   /\//g
wq
EOF
ed color$dipn <<EOF
,s/\, /\,/g
,s/\, /\,/g
wq
EOF
}


#
# SUSY extension
#

#
# replace_input_amp_susy
#
function replace_input_amp_susy {
cp -f $TEMPLATES/proc_card_input.dat $PATCHEDMG_ME/MyProcDir/Cards/proc_card.dat
ed $PATCHEDMG_ME/MyProcDir/Cards/proc_card.dat <<EOF
,s/inputproc/$1/g
,s/sm      /mssm/g
wq
EOF
}

#
# replace_input_susy
#
function replace_input_susy {
cp -f $TEMPLATES/proc_card_input.dat $PATCHEDMG_ME/MyProcDir/Cards/proc_card.dat
ed $PATCHEDMG_ME/MyProcDir/Cards/proc_card.dat <<EOF
,s/inputproc/$1/g
,s/sm      /mssm/g
wq
EOF
}





