#!/bin/sh
#
# AutoDipole package by Kouhei Hasegawa, Sven Moch, and Peter Uwer, 2009
#
# Shell script to check five standard candle processes on the user machine

echo 'Check is starting'
HOMEPATH=`pwd`
echo 'Package home'
echo $HOMEPATH
LIBPATH=$HOMEPATH/lib
echo 'lib directory'
echo $LIBPATH
PROCESSPATH=$HOMEPATH/process
echo 'process directory'
echo $PROCESSPATH

MadVersion=MadEvent

sleep 2
echo ' '
echo 'Run of the generated fortran code'
echo ' '
rm -f $PROCESSPATH/res_check
touch -f $PROCESSPATH/res_check

cp -f $LIBPATH/check/parameter.m $HOMEPATH/parameter.m
cp -f $LIBPATH/check/interactions.dat $HOMEPATH/patch/Models/sm/
cp -f $LIBPATH/check/param_card.dat $HOMEPATH/patch/Models/sm/

echo 'Start check'
echo '1.[Proc_e-e+_uuxg]'
echo '2.[Proc_e-u_e-ug]'
echo ' '
cd $HOMEPATH
math << EOF
<<driver_user.m
GenerateAll[{e,ebar},{u,ubar,g}]
Quit
EOF
echo ' '
echo '1.[Proc_e-e+_uuxg]'
echo ' '
cd $PROCESSPATH/Proc_e-e+_uuxg
rm -f param_card.dat
ln -s $LIBPATH/check/param_card.dat .
cp -f $LIBPATH/check/check_std.f ./
cp -f $LIBPATH/check/check1_e-e+_uuxg/inputm_e-e+_uuxg.h ./inputm_std.h
ed check_std.f << EOF
,s/NDIP/2/g
,s/NLEG/5/g
,s/PROCESS/1.e-e+_uuxg/g
wq
EOF
make runD_std
./runD_std >| res_std
more res_std
cd ./Virtual
rm -f param_card.dat
ln -s ../param_card.dat .
cp -f $LIBPATH/check/checkVirt_std.f ./
cp -f $LIBPATH/check/check1_e-e+_uuxg/inputmLO_e-e+_uuxg.h ./inputmLO_std.h
ed checkVirt_std.f << EOF
,s/NI/2/g
,s/NLEG/4/g
wq
EOF
make runI_std
./runI_std >| resI_std
more resI_std

echo ' '
echo '2.[Proc_e-u_e-ug]'
echo ' '
cd $HOMEPATH
cp -f $LIBPATH/check/check2_e-u_e-ug/parameter.m $HOMEPATH/
math << EOF
<<driver_user.m
GenerateAll[{e,u},{e,u,g}]
Quit
EOF
cd $PROCESSPATH/Proc_e-u_e-ug
rm -f param_card.dat
ln -s $LIBPATH/check/param_card.dat .
cp -f $LIBPATH/check/check_std.f ./
cp -f $LIBPATH/check/check2_e-u_e-ug/inputm_e-u_e-ug.h ./inputm_std.h
ed check_std.f << EOF
,s/NDIP/2/g
,s/NLEG/5/g
,s/PROCESS/2.e-u_e-ug/g
wq
EOF
make runD_std
./runD_std >| res_std
more res_std
cd ./Virtual
rm -f param_card.dat
ln -s ../param_card.dat .
cp -f $LIBPATH/check/checkVirt_std.f ./
cp -f $LIBPATH/check/check2_e-u_e-ug/inputmLO_e-u_e-ug.h ./inputmLO_std.h
ed checkVirt_std.f << EOF
,s/NI/2/g
,s/NLEG/4/g
wq
EOF
make runI_std
./runI_std >| resI_std
more resI_std
cp -f $LIBPATH/check/parameter.m $HOMEPATH/parameter.m
echo 'End check'
echo '1.[Proc_e-e+_uuxg]'
echo '2.[Proc_e-u_e-ug]'
echo ' '


echo 'Start check'
echo '3.[Proc_gg_ttxgg]'
echo '4.[Proc_ug_ttxug]'
echo ' '
cd $HOMEPATH
math << EOF
<<driver_user.m
GenerateAll[{g,g},{t,tbar,g,g}]
GenerateAll[{u,g},{t,tbar,u,g}]
Quit
EOF
echo ' '
echo '3.[Proc_gg_ttxgg]'
echo ' '
cd $PROCESSPATH/Proc_gg_ttxgg
rm -f param_card.dat
ln -s $LIBPATH/check/param_card.dat .
cp -f $LIBPATH/check/check_std.f ./
cp -f $LIBPATH/check/check3_gg_ttxgg/inputm_gg_ttxgg.h ./inputm_std.h
ed check_std.f << EOF
,s/NDIP/36/g
,s/NLEG/6/g
,s/PROCESS/3.gg_ttxgg/g
wq
EOF
make runD_std
./runD_std >| res_std
more res_std
cd ./Virtual
rm -f param_card.dat
ln -s ../param_card.dat .
cp -f $LIBPATH/check/checkVirt_std.f ./
cp -f $LIBPATH/check/check3_gg_ttxgg/inputmLO_gg_ttxgg.h ./inputmLO_std.h
ed checkVirt_std.f << EOF
,s/NI/20/g
,s/NLEG/5/g
wq
EOF
make runI_std
./runI_std >| resI_std
more resI_std

echo ' '
echo '4.[Proc_ug_ttxug]'
echo ' '
cd $PROCESSPATH/Proc_ug_ttxug
rm -f param_card.dat
ln -s $LIBPATH/check/param_card.dat .
cp -f $LIBPATH/check/check_std.f ./
cp -f $LIBPATH/check/check4_ug_ttxug/inputm_ug_ttxug.h ./inputm_std.h
ed check_std.f << EOF
,s/NDIP/28/g
,s/NLEG/6/g
,s/PROCESS/4.ug_ttxug/g
wq
EOF
make runD_std
./runD_std >| res_std
more res_std
cd ./Virtual
rm -f param_card.dat
ln -s ../param_card.dat .
cp -f $LIBPATH/check/checkVirt_std.f ./
cp -f $LIBPATH/check/check4_ug_ttxug/inputmLO_ug_ttxug.h ./inputmLO_std.h
ed checkVirt_std.f << EOF
,s/NI/20/g
,s/NLEG/5/g
wq
EOF
make runI_std
./runI_std >| resI_std
more resI_std
cp -f $HOMEPATH/$MadVersion/Models/sm/interactions.dat $HOMEPATH/patch/Models/sm/interactions.dat
cp -f $HOMEPATH/$MadVersion/Models/sm/param_card.dat $HOMEPATH/patch/Models/sm/param_card.dat
echo 'End check'
echo '3.[Proc_gg_ttxgg]'
echo '4.[Proc_ug_ttxug]'
echo ' '

echo 'Start check'
echo '5.[Proc_uux_w+w-gg]'
echo ' '
cp -f $LIBPATH/check/check5_uux_w+w-gg/param_card.dat $HOMEPATH/patch/Models/sm/
cp -f $LIBPATH/check/check5_uux_w+w-gg/parameter.m $HOMEPATH/
cd $HOMEPATH
math << EOF
<<driver_user.m
GenerateAll[{u,ubar},{Wp,Wm,g,g}]
Quit
EOF
cd $PROCESSPATH/Proc_uux_w+w-gg
rm -f param_card.dat
ln -s $LIBPATH/check/check5_uux_w+w-gg/param_card.dat .
cp -f $LIBPATH/check/check_std.f ./
cp -f $LIBPATH/check/check5_uux_w+w-gg/inputm_uux_w+w-gg.h ./inputm_std.h
ed check_std.f << EOF
,s/NDIP/10/g
,s/NLEG/6/g
,s/PROCESS/5.uux_w+w-gg/g
wq
EOF
make runD_std
./runD_std >| res_std
more res_std

cd ./Virtual
rm -f param_card.dat
ln -s ../param_card.dat .
cp -f $LIBPATH/check/checkVirt_std.f ./
cp -f $LIBPATH/check/check5_uux_w+w-gg/inputmLO_uux_w+w-gg.h ./inputmLO_std.h
ed checkVirt_std.f << EOF
,s/NI/6/g
,s/NLEG/5/g
wq
EOF
make runI_std
./runI_std >| resI_std
more resI_std

cp -f $HOMEPATH/$MadVersion/Models/sm/param_card.dat $HOMEPATH/patch/Models/sm/param_card.dat
echo 'End check'
echo '5.[Proc_uux_w+w-gg]'
echo ' '

cp -f $HOMEPATH/$MadVersion/Models/sm/interactions.dat $HOMEPATH/patch/Models/sm/interactions.dat
cp -f $HOMEPATH/$MadVersion/Models/sm/param_card.dat $HOMEPATH/patch/Models/sm/param_card.dat
cp -f $LIBPATH/math/parameter_default.m $HOMEPATH/parameter.m

echo '********************************'
echo 'Check results'
more $PROCESSPATH/res_check
echo 'End'
echo '********************************'

