(* ::Package:: *)

(* AutoDipole - Package of an automated dipole subtraction by
Kouhei Hasegawa, Sven Moch, and Peter Uwer, 2009 *)


(* SuperAutoDipole - MSSM extension by Kouhei Hasegawa, 2010 *)


(* Filename:dipole.m  :creation of dipole terms *)


(* [Code to pdoduce all dipole terms (massless and massive cases)]
Outline
1. Identify inputted process
2. Create dipoles
3. Functions to be called                         *)


(* Input *)


Dipole[ilist_,flist_]:=Module[{},identify[ilist,flist];create;]


(* 1. Identify inputted process and fields species *)


identify[ilist_,flist_]:=Module[{},assign[ilist,flist];countp[ilist,flist];
                                   plist;process;masslist;dicountset;correset]


assign[ilist_,flist_]:=Module[{},ilistm=ilist;flistm=flist;A[1]=Part[ilist,1];
              A[2]=Part[ilist,2];nfinal=Length[flist];Do[X[i]=Part[flist,i],{i,1,nfinal}];
              If[ FreeQ[{sm,mssm},model],Print["Availbale models are {sm,mssm}."];
                  Print["Please specify one at parameter.m"];Abort[]];
              quarks={u,ubar,d,dbar,s,sbar,c,cbar,b,bbar,t,tbar};
              anquarks={u,d,s,c,b,t};anantiquarks={ubar,dbar,sbar,cbar,bbar,tbar};
              others={e,ebar,muon,muonbar,tau,taubar,
                      nue,numu,nutau,nuebar,numubar,nutaubar,gamma,Wp,Wm,Z,h};
              If[ model===sm, availablefilelds=Join[quarks,{g},others];
                  If[ massiveb == 0, masses={mt};zquark={u,ubar,d,dbar,s,sbar,c,cbar,b,bbar};
                                                 mquark={t,tbar}];
                  If[ massiveb == 1, masses={mb,mt};zquark={u,ubar,d,dbar,s,sbar,c,cbar};
                                                    mquark={b,bbar,t,tbar}];
                ];
              If[ model===mssm,
                squarks={sul,sur,sdl,sdr,ssl,ssr,scl,scr,sb1,sb2,st1,st2,
                         sulbar,surbar,sdlbar,sdrbar,sslbar,ssrbar,sclbar,
                         scrbar,sb1bar,sb2bar,st1bar,st2bar};
                ansquarks={sul,sur,sdl,sdr,ssl,ssr,scl,scr,sb1,sb2,st1,st2};
                anantisquarks={sulbar,surbar,sdlbar,sdrbar,sslbar,ssrbar,sclbar,
                         scrbar,sb1bar,sb2bar,st1bar,st2bar};
                sleptons={sel,ser,snuel,smul,smur,snumul,stau1,stau2,snutaul,
                          selbar,serbar,snuelbar,smulbar,smurbar,snumulbar,stau1bar,stau2bar,snutaulbar};
                neutralinos={sN1,sN2,sN3,sN4};chargino={sC1p,sC1m,sC2p,sC2m};
                mssmhiggs={H0,A0,Hp,Hm};
                others=Flatten[{others,sleptons,neutralinos,chargino,mssmhiggs}];
                availablefilelds=Join[quarks,{g},squarks,{sg},others];
                  If[ massiveb == 0, 
                  masses={mt,msg,msul,msur,msdl,msdr,mssl,mssr,mscl,mscr,mst1,mst1,msb1,msb2};
                  zquark={u,ubar,d,dbar,s,sbar,c,cbar,b,bbar};
                  mquark=Join[{t,tbar},squarks]];
                  If[ massiveb == 1, 
                  masses={mb,mt,msg,msul,msur,msdl,msdr,mssl,mssr,mscl,mscr,mst1,mst1,msb1,msb2};
                  zquark={u,ubar,d,dbar,s,sbar,c,cbar};
                  mquark=Join[{b,bbar,t,tbar},squarks]];
                ];
              If[ FreeQ[availablefilelds,A[1]],PrintNon[a];Abort[]];
              If[ FreeQ[availablefilelds,A[2]],PrintNon[b];Abort[]];
              Do[If[ FreeQ[availablefilelds,X[i]],PrintNon[i];Abort[]];,{i,1,nfinal}];
              If[ MemberQ[mquark,A[1]] || A[1] == sg || MemberQ[mquark,A[2]] || A[2] == sg,
                 If[model==sm,Print["The massive colored fileds ", mquark," are forbidden."]];
                 If[model==mssm,Print["The massive colored fileds ", Join[mquark,{sg}]," are forbidden."]];
                Abort[];
                ];
              ]


PrintNon[i_]:=Module[{},Print["Field, ",i," ,is not available"];
                       Print["Available fields are :",availablefilelds];]                      


countp[ilist_,flist_]:=Module[{},lg=Count[ilist,g];
                    lu=Count[ilist,u];lubar=Count[ilist,ubar];
                    ld=Count[ilist,d];ldbar=Count[ilist,dbar];
                    ls=Count[ilist,s];lsbar=Count[ilist,sbar];
                    lc=Count[ilist,c];lcbar=Count[ilist,cbar];
                    lb=Count[ilist,b];lbbar=Count[ilist,bbar];
                    le=Count[ilist,e];lebar=Count[ilist,ebar];lp=Count[ilist,p];
                    ng=Count[flist,g];nu=Count[flist,u];nubar=Count[flist,ubar];
                    nd=Count[flist,d];ndbar=Count[flist,dbar];
                    ns=Count[flist,s];nsbar=Count[flist,sbar];
                    nc=Count[flist,c];ncbar=Count[flist,cbar];
                    lb=Count[ilist,b];lbbar=Count[ilist,bbar];
                    lt=Count[ilist,t];ltbar=Count[ilist,tbar];
                    nb=Count[flist,b];nbbar=Count[flist,bbar];
                    nt=Count[flist,t];ntbar=Count[flist,tbar];
                    lgamma=Count[ilist,gamma];ngamma=Count[flist,gamma];
                    lwp=Count[ilist,Wp];nwp=Count[flist,Wp];
                    lwm=Count[ilist,Wm];nwm=Count[flist,Wm];
                    lz=Count[ilist,Z];nz=Count[flist,Z];
                    lparton=lg+lu+lubar+ld+ldbar+ls+lsbar+lc+lcbar+lb+lbbar+lt+ltbar;]


plist:=Module[{},glist={};ulist={};ubarlist={};dlist={};dbarlist={};
                          slist={};sbarlist={};clist={};cbarlist={};
                          blist={};bbarlist={};tlist={};tbarlist={};
                 Do[If[X[i]===g,AppendTo[glist,i],Null],{i,1,nfinal}];
                 Do[If[X[i]===u,AppendTo[ulist,i]],{i,1,nfinal}];
                 Do[If[X[i]===ubar,AppendTo[ubarlist,i]],{i,1,nfinal}];
                 Do[If[X[i]===d,AppendTo[dlist,i]],{i,1,nfinal}];
                 Do[If[X[i]===dbar,AppendTo[dbarlist,i]],{i,1,nfinal}];
                 Do[If[X[i]===s ,AppendTo[slist,i]],{i,1,nfinal}];
                 Do[If[X[i]===sbar,AppendTo[sbarlist,i]],{i,1,nfinal}];
                 Do[If[X[i]===c, AppendTo[clist,i]],{i,1,nfinal}];
                 Do[If[X[i]===cbar, AppendTo[cbarlist,i]],{i,1,nfinal}];
                 Do[If[X[i]===b,AppendTo[blist,i]],{i,1,nfinal}];
                 Do[If[X[i]===bbar,AppendTo[bbarlist,i]],{i,1,nfinal}];
                 Do[If[X[i]===t,AppendTo[tlist,i]],{i,1,nfinal}];
                 Do[If[X[i]===tbar,AppendTo[tbarlist,i]],{i,1,nfinal}];
                 nborn=nfinal+1;rmom={};Do[AppendTo[rmom,ptil[j]],{j,3,nborn}];
                 alist={a,b};]


process:=Module[{},tfinal=Table[{X[i],p[i]},{i,1,nfinal}];
                 Print["NLO: ",{{A[1],pa},{A[2],pb}}," --> ", tfinal];]


masslist:=Module[{},mlist={};Do[
          If[X[i]===g||X[i]===u||X[i]===ubar||X[i]===d||X[i]===dbar||
                   X[i]===s||X[i]===sbar||X[i]===c||X[i]===cbar||
                   X[i]===e||X[i]===ebar||X[i]===muon||X[i]===muonbar||
                   X[i]===gamma,M[i]=0];
                massasign[t,tbar,mt];
                massasign[tau,taubar,mtau];
                massasign[Wp,Wm,mw];massasignsi[Z,mz];massasignsi[h,mh];
                If[ massiveb == 0 && (X[i]===b || X[i]===bbar), M[i]=0];
                If[ massiveb == 1 && (X[i]===b || X[i]===bbar), M[i]=mb];
             If[model===mssm,
                massasignsi[sg,msg];
                massasign[sul,sulbar,msul];massasign[sur,surbar,msur];
                massasign[sdl,sdlbar,msdl];massasign[sdr,sdrbar,msdr];
                massasign[ssl,sslbar,mssl];massasign[ssr,ssrbar,mssr];
                massasign[scl,sclbar,mscl];massasign[scr,scrbar,mscr];
                massasign[st1,st1bar,mst1];massasign[st2,st2bar,mst2];
                massasign[sb1,sb1bar,msb1];massasign[sb2,sb2bar,msb2];
                massasign[sel,selbar,msel];massasign[ser,serbar,mser];
                massasign[snuel,snuelbar,msnuel];
                massasign[smul,smulbar,msmul];massasign[smur,ssmur,msmur];
                massasign[snumul,snumulbar,msnumul];
                massasign[stau1,stau1bar,mstau1];massasign[stau2,stau2bar,mstau2];
                massasign[snutaul,snutaulbar,msnutaul];
                massasignsi[sN1,msN1];massasignsi[sN2,msN2];
                massasignsi[sN3,msN3];massasignsi[sN4,msN4];
                massasign[sC1p,sC1m,msC1];massasign[sC2p,sC2m,msC2];
                massasignsi[H0,mH0];massasignsi[A0,mA0];
                massasign[Hp,Hm,mHH];
                ];
               AppendTo[mlist,M[i]];
                ,{i,1,nfinal}];
                Print["Masses: {0,0} --> ", mlist];M[a]=0;M[b]=0;
               ]


massasign[p_,ap_,m_]:=Module[{},If[X[i]===p||X[i]===ap,M[i]=m]]


massasignsi[p_,m_]:=Module[{},If[X[i]===p,M[i]=m]]


dicountset:=Module[{},co=0;Do[dc[n]=0;dMc[n]=0;ds[n]=0;dss[n]=0;dMss[n]=0;,{n,1,200}];
If[model===mssm,Do[dMSUSYc[n]=0;ds[n]=0;dss[n]=0;dMss[n]=0;,{n,1,200}]]
]


correset:=Module[{},Do[Do[cor[co,ib]=0,{ib,1,10}],{co,1,200}];
Do[emit[co]=0;spec[co]=0;dinin[co]=0;less[co]=0,{co,1,200}];
Do[Do[gluonemit[co,id]=0,{id,1,4}],{co,1,200}];]


(* 2. Create dipoles and print results *)


create:=Module[{},If[ng >= 1,If[ FreeQ[skipdipole,1],dipole1,Print["Dipole 1 is skipped"]]];
                  If[(nu >= 1 && nubar >= 1) || (nd >= 1 && ndbar >= 1)||
                     (ns >= 1 && nsbar >= 1) || (nc >= 1 && ncbar >= 1)||
                     (nb >= 1 && nbbar >= 1) || (nt >= 1 && ntbar >= 1),dipole2]; 
                  If[(lu >= 1 && nu >= 1) || (lubar >= 1 && nubar >= 1) || 
                     (ld >= 1 && nd >= 1) || (ldbar >= 1 && ndbar >= 1) ||
                     (ls >= 1 && ns >= 1) || (lsbar >= 1 && nsbar >= 1) ||
                     (lc >= 1 && nc >= 1) || (lcbar >= 1 && ncbar >= 1) ||
                     (lb >= 1 && nb >= 1) || (lbbar >= 1 && nbbar >= 1) ,dipole3];
                  If[ lg >= 1 && 
                   (nu >= 1 || nubar >= 1 || nd >= 1 || ndbar >= 1 || 
                    ns >= 1 || nsbar >= 1 || nc >= 1 || ncbar >= 1 || 
                    nb >= 1 || nbbar >= 1),
                    dipole4];
                  If[model===mssm && ng >= 1, dipoleSUSY];
                  dicount;collprint;softprint;messageforIPK;
                  ]


(* Dipole 1 *)


dipole1:=Module[{}, 
     Print["-------------------------------------------------------------------------"];
     Print["Dipole 1"];showB1;dipole1ijfg;dipole1ijgg;dipole1aifg;dipole1aigg;
     Print["*************************************************************************"];]


showB1:=Module[{},A1={};Do[If[i!=Last[glist],AppendTo[A1,X[i]]],
                 {i,1,nfinal}];Print["M0=B1:           ",{A[1],A[2]}," --> ", A1];
Print["Reduced momenta: ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V1[ib]=Part[A1,ib-2],{ib,3,nborn}];
]


dipole1ijfg:=Module[{},Print["{Splitting (1):(i,j)=(f,g)}"];
Print["[1.(ij,k)=(fg,k): Dij,k]"];dipole1fgkcr;
Print["[2.(ij,a)=(fg,a): Dij^a]"];dipole1fgUacr;]


dipole1ijgg:=Module[{},If[ng >= 2,Print["{Splitting (2):(i,j)=(g,g)}"];
Print["[3.(ij,k)=(gg,k): Dij,k]"];dipole1ggkcr;
Print["[4.(ij,a)=(gg,a): Dij^a]"];dipole1ggUacr;]]


dipole1aifg:=Module[{},If[lparton >= 1,Print["{Splitting (3):(a,i)=(f,g)}"];
Print["[5.(ai,k)=(fg,k): D^ai,k]"];dipole1fgDkcr;
Print["[6.(ai,b)=(fg,b): D^ai,b]"];dipole1fgbcr;]]


dipole1aigg:=Module[{},If[lparton >= 1,Print["{Splitting (4):(a,i)=(g,g)}"];
Print["[7.(ai,k)=(gg,k): D^ai,k]"];dipole1ggDkcr;
Print["[8.(ai,b)=(gg,b): D^ai,b]"];dipole1ggbcr;]]


(*[1.(ij,k)=(fg,k): Dij,k]*)


dipole1fgkcr:=Do[
               Do[If[MemberQ[quarks,X[i]],
                 Do[If[k != glist[[j]] && k!=i && FreeQ[others,X[k]],
         co=co+1;
Print[" "];
Print["--Dip(",co,")--"];
   If[M[i]==0 && M[k]==0,
         dc[1]=dc[1]+1;
         Print["Dijkfgk(",i,glist[[j]],k,")=",Dijkfgk[i,glist[[j]],k]];
         Print["     pij(",i,glist[[j]],k,")=",pij[i,glist[[j]],k]];
         Print["     pk(",i,glist[[j]],k,")=",pk[i,glist[[j]],k]];

         dip[co]=Dijkfgk[i,glist[[j]],k];
         dipS[co]=Dijkfgk[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;

         pem[co]=pij[i,glist[[j]],k];
         pemS[co]=pij[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;
        (* Print["pemS(",co,")=",pemS[co]]; *)
         pemS[co]=pemS[co]/.repmom[i,glist[[j]],k]//Simplify;

         psp[co]=pk[i,glist[[j]],k];
         pspS[co]=pk[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[i,glist[[j]],k]//Simplify;
      ];

   If[MemberQ[masses,M[i]] || MemberQ[masses,M[k]],
         dMc[1]=dMc[1]+1;
         Print["DMijkfgk(",i,glist[[j]],k,")=",DMijkfgk[i,glist[[j]],k]];
         Print["     pMij1(",i,glist[[j]],k,")=",pMij1[i,glist[[j]],k]];
         Print["     pMk1(",i,glist[[j]],k,")=",pMk1[i,glist[[j]],k]];

         dip[co]=DMijkfgk[i,glist[[j]],k];
         dipS[co]=DMijkfgk[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;

         pemR[co]=pMij1[i,glist[[j]],k];
         pemS[co]=pMij1[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[i,glist[[j]],k]//Simplify;

         pspR[co]=pMk1[i,glist[[j]],k];
         pspS[co]=pMk1[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[i,glist[[j]],k]//Simplify;
      ];

Do[If[V1[ib]==X[i],emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V1[ib]==X[k],spec[co]=ib;Break[]];,{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != i && io != glist[[j]] && io != k && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
   ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",i,glist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",i,glist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
collinearset[co,i,glist[[j]]];

                    ],{k,1,nfinal}]
                  ],{i,1,nfinal}]
              ,{j,1,ng}]


(* [2.(ij,a)=(fg,a): Dij^a] *)


dipole1fgUacr:=Do[
                Do[If[MemberQ[quarks,X[i]],
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
                    co=co+1;Print[" "];Print["--Dip(",co,")--"];
  If[M[i]==0,
         dc[2]=dc[2]+1;
         Print["DijUafgUa(",i,glist[[j]],alist[[c]],")=",DijUafgUa[i,glist[[j]],alist[[c]]]];
         Print["     pij(",i,glist[[j]],alist[[c]],")=",pija[i,glist[[j]],alist[[c]]]];
         Print["     pa(",i,glist[[j]],alist[[c]],")=",pa[i,glist[[j]],alist[[c]]]];

         dip[co]=DijUafgUa[i,glist[[j]],alist[[c]]];
         dipS[co]=DijUafgUa[i,glist[[j]],alist[[c]]]/.
                                           replist1[i,glist[[j]],alist[[c]]]//Simplify;

          pemR[co]=pija[i,glist[[j]],alist[[c]]];
          pemS[co]=pija[i,glist[[j]],alist[[c]]]/.replist1[i,glist[[j]],alist[[c]]]//Simplify;
          pemS[co]=pemS[co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2],
                                            p[alist[[c]]]->p[r,c]}//Simplify;

          pspR[co]=pa[i,glist[[j]],alist[[c]]];
          pspS[co]=pa[i,glist[[j]],alist[[c]]]/.replist1[i,glist[[j]],alist[[c]]]//Simplify;
          pspS[co]=pspS[co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2],
                                            p[alist[[c]]]->p[r,c]}//Simplify;
     ];

  If[MemberQ[masses,M[i]],
         dMc[2]=dMc[2]+1;
         Print["DMijUafgUa(",i,glist[[j]],alist[[c]],")=",DMijUafgUa[i,glist[[j]],alist[[c]]]];
         Print["     pMij2(",i,glist[[j]],alist[[c]],")=",pija[i,glist[[j]],alist[[c]]]];
         Print["     pMa2(",i,glist[[j]],alist[[c]],")=",pa[i,glist[[j]],alist[[c]]]];

         dip[co]=DMijUafgUa[i,glist[[j]],alist[[c]]];
         dipS[co]=DMijUafgUa[i,glist[[j]],alist[[c]]]/.
                                           replist1[i,glist[[j]],alist[[c]]]//Simplify;

         pemR[co]=pija[i,glist[[j]],alist[[c]]];
         pemS[co]=pija[i,glist[[j]],alist[[c]]]/.replist1[i,glist[[j]],alist[[c]]]//Simplify;
         (*Print["pemS(",co,")=",pemS[co]];*)
         pemS[co]=pemS[co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2],
                                         p[alist[[c]]]->p[r,c]}//Simplify;
         (*Print["pemS(",co,")=",pemS[co]];*)

         pspR[co]=pija[i,glist[[j]],alist[[c]]];
         pspS[co]=pa[i,glist[[j]],alist[[c]]]/.replist1[i,glist[[j]],alist[[c]]]//Simplify;
         (*Print["pspS(",co,")=",pspS[co]];*)
         pspS[co]=pspS[co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2],
                         p[alist[[c]]]->p[r,c]}//Simplify;
         (*Print["pspS(",co,")=",pspS[co]];*)
     ];

spec[co]=c;
Do[If[V1[ib]==X[i],emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != i && io != glist[[j]] && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",i,glist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",i,glist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
collinearset[co,i,glist[[j]]];

                    ],{c,1,2}]
                  ],{i,1,nfinal}]
              ,{j,1,ng}]


(* [3.(ij,k)=(gg,k): Dij,k] *)


dipole1ggkcr:=Do[
               Do[If[i>j,
                 Do[If[k != glist[[j]] && k!=glist[[i]] && FreeQ[others,X[k]],
         co=co+1;gluonemit[co,1]=1;Print[" "];Print["--Dip(",co,")--"];
  If[M[k]==0,
    dc[3]=dc[3]+1;
    Print["Dijkggk(",glist[[i]],glist[[j]],k,")=",Dijkggk[glist[[i]],glist[[j]],k]];
    Print["     pij(",glist[[i]],glist[[j]],k,")=",pij[glist[[i]],glist[[j]],k]];
    Print["     pk(",glist[[i]],glist[[j]],k,")=",pk[glist[[i]],glist[[j]],k]];
    Print["     Eijk(",glist[[i]],glist[[j]],k,")=",Eijk[glist[[i]],glist[[j]],k]];

        dip[co]=Dijkggk[glist[[i]],glist[[j]],k];
        dipS[co]=Dijkggk[glist[[i]],glist[[j]],k]/.
                                        replist1[glist[[i]],glist[[j]],k]//Simplify;

        ehR[co]=Eijk[glist[[i]],glist[[j]],k];
        ehS[co]=Eijk[glist[[i]],glist[[j]],k]/.
                         replist1[glist[[i]],glist[[j]],k]//Simplify;
        ehS[co]=ehS[co]/.repmom3[glist[[i]],glist[[j]],k]//Simplify;

        pemR[co]=pij[glist[[i]],glist[[j]],k];
        pemS[co]=pij[glist[[i]],glist[[j]],k]/.replist1[glist[[i]],glist[[j]],k]//Simplify;
        (*Print["pemS(",co,")=",pemS[co]];*)
        pemS[co]=pemS[co]/.repmom[glist[[i]],glist[[j]],k]//Simplify;
        (*Print["pemS(",co,")=",pemS[co]];*)

        psp[co]=pk[glist[[i]],glist[[j]],k];
        pspS[co]=pk[glist[[i]],glist[[j]],k]/.replist1[glist[[i]],glist[[j]],k]//Simplify;
        (*Print["pspS(",co,")=",pspS[co]];*)
        pspS[co]=pspS[co]/.repmom[glist[[i]],glist[[j]],k]//Simplify;
        (*Print["pspS(",co,")=",pspS[co]];*)
    ];

  If[MemberQ[masses,M[k]],
    dMc[3]=dMc[3]+1;
    Print["DMijkggk(",glist[[i]],glist[[j]],k,")=",DMijkggk[glist[[i]],glist[[j]],k]];
    Print["     pMij3(",glist[[i]],glist[[j]],k,")=",pMij3[glist[[i]],glist[[j]],k]];
    Print["     pMk3(",glist[[i]],glist[[j]],k,")=",pMk3[glist[[i]],glist[[j]],k]];
    Print["     EMijk(",glist[[i]],glist[[j]],k,")=",EMijk[glist[[i]],glist[[j]],k]];

        dip[co]=DMijkggk[glist[[i]],glist[[j]],k];
        dipS[co]=DMijkggk[glist[[i]],glist[[j]],k]/.
                                        replist1[glist[[i]],glist[[j]],k]//Simplify;

        ehR[co]=EMijk[glist[[i]],glist[[j]],k];
        ehS[co]=EMijk[glist[[i]],glist[[j]],k]/.
                         replist1[glist[[i]],glist[[j]],k]//Simplify;
        ehS[co]=ehS[co]/.repmom3[glist[[i]],glist[[j]],k];

        pemR[co]=pMij3[glist[[i]],glist[[j]],k];
        pemS[co]=pMij3[glist[[i]],glist[[j]],k]/.replist1[glist[[i]],glist[[j]],k]//Simplify;
        (*Print["pemS(",co,")=",pemS[co]];*)
        pemS[co]=pemS[co]/.repmom[glist[[i]],glist[[j]],k]//Simplify;
        (*Print["pemS(",co,")=",pemS[co]];*)

        psp[co]=pMk3[glist[[i]],glist[[j]],k];
        pspS[co]=pMk3[glist[[i]],glist[[j]],k]/.replist1[glist[[i]],glist[[j]],k]//Simplify;
        (*Print["pspS(",co,")=",pspS[co]];*)
        pspS[co]=pspS[co]/.repmom[glist[[i]],glist[[j]],k]//Simplify;
        (*Print["pspS(",co,")=",pspS[co]];*)
    ];

Do[If[V1[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V1[ib]==X[k],spec[co]=ib;Break[]],{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
 Do[
   If[ib != emit[co] && ib!= spec[co],
     Do[
       If[io != glist[[i]] && io != glist[[j]] && io != k && FreeQ[templist,io],
         If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
       ]
     ,{io,1,nfinal}]
    ]
 ,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",glist[[i]],glist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",glist[[i]],glist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,glist[[i]],glist[[j]]];

                    ],{k,1,nfinal}]
                  ],{i,1,ng}]
              ,{j,1,ng}]


(* [4.(ij,a)=(gg,a): Dij^a]  *)


dipole1ggUacr:=Do[
               Do[If[i>j,
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;gluonemit[co,1]=1;Print[" "];Print["--Dip(",co,")--"];
dc[4]=dc[4]+1;
Print["DijUaggUa(",glist[[i]],glist[[j]],alist[[c]],")=",
                        DijUaggUa[glist[[i]],glist[[j]],alist[[c]]]];

Print["     pij(",glist[[i]],glist[[j]],alist[[c]],")=",pija[glist[[i]],glist[[j]],alist[[c]]]];
Print["     pa(",glist[[i]],glist[[j]],alist[[c]],")=",pa[glist[[i]],glist[[j]],alist[[c]]]];
Print["     Eija(",glist[[i]],glist[[j]],alist[[c]],")=",Eija[glist[[i]],glist[[j]],alist[[c]]]];

      dip[co]=DijUaggUa[glist[[i]],glist[[j]],alist[[c]]];
      dipS[co]=DijUaggUa[glist[[i]],glist[[j]],
                   alist[[c]]]/.replist1[glist[[i]],glist[[j]],alist[[c]]]//Simplify;

      ehR[co]=Eija[glist[[i]],glist[[j]],alist[[c]]];
      ehS[co]=Eija[glist[[i]],glist[[j]],alist[[c]]]/.
      replist1[glist[[i]],glist[[j]],alist[[c]]]//Simplify;
      ehS[co]=ehS[co]/.{p[glist[[i]]]->p[0,glist[[i]]+2],p[glist[[j]]]->p[0,glist[[j]]+2],
                                                           p[alist[[c]]]->p[0,c]};

      pemR[co]=pija[glist[[i]],glist[[j]],alist[[c]]];
      pemS[co]=pija[glist[[i]],glist[[j]],alist[[c]]]/.
            replist1[glist[[i]],glist[[j]],alist[[c]]]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[glist[[i]]]->p[r,glist[[i]]+2],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[alist[[c]]]->p[r,c]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      pspR[co]=pa[glist[[i]],glist[[j]],alist[[c]]];
      pspS[co]=pa[glist[[i]],glist[[j]],alist[[c]]]/.
            replist1[glist[[i]],glist[[j]],alist[[c]]]//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)
      pspS[co]=pspS[co]/.{p[glist[[i]]]->p[r,glist[[i]]+2],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[alist[[c]]]->p[r,c]}//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)

spec[co]=c;
Do[If[V1[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != glist[[i]] && io != glist[[j]] && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",glist[[i]],glist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",glist[[i]],glist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,glist[[i]],glist[[j]]];

                    ],{c,1,2}]
                  ],{i,1,ng}]
              ,{j,1,ng}]


(* [5.(ai,k)=(fg,k): D^ai,k] *)


dipole1fgDkcr:=Do[
                 Do[If[ MemberQ[zquark,A[c]],
                   Do[If[k != glist[[j]] && FreeQ[others,X[k]], 
         co=co+1;Print[" "];Print["--Dip(",co,")--"];
 If[M[k]==0,
   dc[5]=dc[5]+1;
   Print["DaiDkfgDk(",alist[[c]],glist[[j]],k,")=",DaiDkfgDk[alist[[c]],glist[[j]],k]];
   Print["     pai(",alist[[c]],glist[[j]],k,")=",pai[alist[[c]],glist[[j]],k]];
   Print["     pk(",alist[[c]],glist[[j]],k,")=",paikk[alist[[c]],glist[[j]],k]];

      dip[co]=DaiDkfgDk[alist[[c]],glist[[j]],k];
      dipS[co]=DaiDkfgDk[alist[[c]],glist[[j]],k]/.
                                       replist1[alist[[c]],glist[[j]],k]//Simplify;

      pemR[co]=pai[alist[[c]],glist[[j]],k];
      pemS[co]=pai[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[k]->p[r,k+2]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      pspR[co]=paikk[alist[[c]],glist[[j]],k];
      pspS[co]=paikk[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)
      pspS[co]=pspS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[k]->p[r,k+2]}//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)
   ];

 If[MemberQ[masses,M[k]],
   dMc[5]=dMc[5]+1;
   Print["DMaiDkfgDk(",alist[[c]],glist[[j]],k,")=",DMaiDkfgDk[alist[[c]],glist[[j]],k]];
   Print["     pMai(",alist[[c]],glist[[j]],k,")=",pai[alist[[c]],glist[[j]],k]];
   Print["     pMk(",alist[[c]],glist[[j]],k,")=",paikk[alist[[c]],glist[[j]],k]];

      dip[co]=DMaiDkfgDk[alist[[c]],glist[[j]],k];
      dipS[co]=DMaiDkfgDk[alist[[c]],glist[[j]],k]/.
                                       replist1[alist[[c]],glist[[j]],k]//Simplify;

      pemR[co]=pai[alist[[c]],glist[[j]],k];
      pemS[co]=pai[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[k]->p[r,k+2]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      pspR[co]=paikk[alist[[c]],glist[[j]],k];
      pspS[co]=paikk[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)
      pspS[co]=pspS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[k]->p[r,k+2]}//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)
   ];

emit[co]=c;
Do[If[V1[ib]==X[k],spec[co]=ib;Break[]];,{ib,3,nborn}];
Do[If[ib != emit[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != spec[co],
    Do[
      If[io != glist[[j]] && io !=k && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pai(",alist[[c]],glist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",alist[[c]],glist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,alist[[c]],glist[[j]]];

                    ],{k,1,nfinal}]
                  ],{c,1,2}]
                ,{j,1,ng}]


(* [6.(ai,b)=(fg,b): D^ai,b] *)


dipole1fgbcr:=Do[
                 Do[If[ MemberQ[zquark,A[c]],
                   Do[If[d != c && FreeQ[others,A[d]], 
         co=co+1;dinin[co]=1;Print[" "];Print["--Dip(",co,")--"];


Print["Daibfgb(",alist[[c]],glist[[j]],alist[[d]],")=",
                              Daibfgb[alist[[c]],glist[[j]],alist[[d]]]];


Print["     pai(",alist[[c]],glist[[j]],alist[[d]],")=",paibai[alist[[c]],glist[[j]],alist[[d]]]];
Do[If[i != glist[[j]], 
Print["     kj(",i,alist[[c]],glist[[j]],alist[[d]],")=",ptil[i,alist[[c]],glist[[j]],
               alist[[d]]] ] ],{i,1,nfinal}];dc[6]=dc[6]+1;

      dip[co]=DaibfgbF[alist[[c]],glist[[j]],alist[[d]]];
      dipS[co]=Daibfgb[alist[[c]],glist[[j]],
                  alist[[d]]]/.replist1[alist[[c]],glist[[j]],alist[[d]]]//Simplify;

      pemR[co]=paibai[alist[[c]],glist[[j]],alist[[d]]];
      pemS[co]=paibai[alist[[c]],glist[[j]],alist[[d]]]/.replist1[alist[[c]],glist[[j]],
            alist[[d]]]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[alist[[d]]]->p[r,d]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      Do[If[i != glist[[j]], 
      ktilR[i,co]=ptil[i,alist[[c]],glist[[j]],alist[[d]]];
      ktilS[i,co]=ptil[i,alist[[c]],glist[[j]],alist[[d]]]/.replist1[alist[[c]],glist[[j]],
            alist[[d]]]//Simplify;
      Print["ktilS(",i,",",co,")=",ktilS[i,co]];

     Do[
       Do[If[i!=j,
      ktilS[i,co]=ktilS[i,co]/.{p[i].p[j]->t[i,j],p[j].p[i]->t[i,j]}]
        ,{i,1,nfinal}];
      ,{j,1,nfinal}];

      Do[ktilS[i,co]=ktilS[i,co]/.{p[a].p[i]->t[a,i],p[i].p[a]->t[a,i]},{i,1,nfinal}];
      Do[ktilS[i,co]=ktilS[i,co]/.{p[b].p[i]->t[b,i],p[i].p[b]->t[b,i]},{i,1,nfinal}];
      ktilS[i,co]=ktilS[i,co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2]}//Simplify;
      ktilS[i,co]=ktilS[i,co]/.{p[alist[[c]]]->p[r,c],p[alist[[d]]]->p[r,d]}//Simplify;
      Print["ktilS(",i,",",co,")=",ktilS[i,co]];
     ] ,{i,1,nfinal}];  

emit[co]=c;spec[co]=d;cor[co,d]=alist[[d]];
templist={};
Do[
    Do[
       If[io != glist[[j]] && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pai(",alist[[c]],glist[[j]],alist[[d]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=p(",alist[[d]],")"]];
If[ib != emit[co] && ib != spec[co] ,Print["ptil(",co,",",ib,")=kj(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,alist[[c]],glist[[j]]];

                   ],{d,1,2}]
                 ],{c,1,2}]
                ,{j,1,ng}]


(* [7.(ai,k)=(gg,k): D^ai,k] *)


dipole1ggDkcr:=Do[
                 Do[If[A[c]===g,
                   Do[If[k != glist[[j]] && FreeQ[others,X[k]], 
         co=co+1;gluonemit[co,1]=2;Print[" "];Print["--Dip(",co,")--"];
 If[M[k]==0,
dc[7]=dc[7]+1;
      Print["DaiDkggDk(",alist[[c]],glist[[j]],k,")=",DaiDkggDk[alist[[c]],glist[[j]],k]];
      Print["     pai(",alist[[c]],glist[[j]],k,")=",pai[alist[[c]],glist[[j]],k]];
      Print["     pk2(",alist[[c]],glist[[j]],k,")=",paikk[alist[[c]],glist[[j]],k]];
      Print["     Eaik(",alist[[c]],glist[[j]],k,")=",Eaik[alist[[c]],glist[[j]],k]];

      dip[co]=DaiDkggDk[alist[[c]],glist[[j]],k];
      dipS[co]=DaiDkggDk[alist[[c]],glist[[j]],k]/.
                                    replist1[alist[[c]],glist[[j]],k]//Simplify;
      ehR[co]=Eaik[alist[[c]],glist[[j]],k];
      ehS[co]=Eaik[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],
      glist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.{p[alist[[c]]]->p[0,c],p[glist[[j]]]->p[0,glist[[j]]+2],p[k]->p[0,k+2]};

      pemR[co]=pai[alist[[c]],glist[[j]],k];
      pemS[co]=pai[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[k]->p[r,k+2]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      pspR[co]=paikk[alist[[c]],glist[[j]],k];
      pspS[co]=paikk[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)
      pspS[co]=pspS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[k]->p[r,k+2]}//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)
];

 If[MemberQ[masses,M[k]],
dMc[7]=dMc[7]+1;less[co]=1;
Print["DMaiDkggDk(",alist[[c]],glist[[j]],k,")=",DMaiDkggDk[alist[[c]],glist[[j]],k]];
Print["     pMai(",alist[[c]],glist[[j]],k,")=",pai[alist[[c]],glist[[j]],k]];
Print["     pMk2(",alist[[c]],glist[[j]],k,")=",paikk[alist[[c]],glist[[j]],k]];
Print["     EMaik(",alist[[c]],glist[[j]],k,")=",EMaik[alist[[c]],glist[[j]],k]];

      dip[co]=DMaiDkggDk[alist[[c]],glist[[j]],k];
      dipS[co]=DMaiDkggDk[alist[[c]],glist[[j]],k]/.
                                    replist1[alist[[c]],glist[[j]],k]//Simplify;
      ehR[co]=EMaik[alist[[c]],glist[[j]],k];
      ehS[co]=EMaik[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.{p[alist[[c]]]->p[0,c],p[glist[[j]]]->p[0,glist[[j]]+2],p[k]->p[0,k+2]};

      pemR[co]=pai[alist[[c]],glist[[j]],k];
      pemS[co]=pai[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[k]->p[r,k+2]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      pspR[co]=paikk[alist[[c]],glist[[j]],k];
      pspS[co]=paikk[alist[[c]],glist[[j]],k]/.replist1[alist[[c]],glist[[j]],k]//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)
      pspS[co]=pspS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[k]->p[r,k+2]}//Simplify;
      (*Print["pspS(",co,")=",pspS[co]];*)

      plesskR[co]=pless[k];
      plesskS[co]=pless[k]/.{p[k].q[2] -> s[alist[[c]],k]/2}//Simplify;
      Print["plkS(",co,")=",plesskS[co]];
      plesskS[co]=plesskS[co]/.{p[k]->p[r,k+2],q[2]->p[r,c]}//Simplify;
      Print["plkS(",co,")=",plesskS[co]];
 ];

emit[co]=c;
Do[If[V1[ib]==X[k],spec[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != spec[co],
    Do[
      If[io != glist[[j]] && io !=k && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];

Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pai(",alist[[c]],glist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",alist[[c]],glist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,alist[[c]],glist[[j]]];

                    ],{k,1,nfinal}]
                  ],{c,1,2}]
                ,{j,1,ng}]


(* [8.(ai,b)=(gg,b): D^ai,b] *)


dipole1ggbcr:=Do[
                 Do[If[A[c]===g,
                   Do[If[d != c && FreeQ[others,A[d]], 
         co=co+1;dinin[co]=1;gluonemit[co,1]=2;Print[" "];Print["--Dip(",co,")--"];


dc[8]=dc[8]+1;
Print["Daibggb(",alist[[c]],glist[[j]],alist[[d]],")=",
                               Daibggb[alist[[c]],glist[[j]],alist[[d]]]];


Print["     pai(",alist[[c]],glist[[j]],alist[[d]],")=",paibai[alist[[c]],glist[[j]],alist[[d]]]];
Do[If[i != glist[[j]], 
Print["     ptil(",i,alist[[c]],glist[[j]],alist[[d]],")=",ptil[i,alist[[c]],glist[[j]],
               alist[[d]]] ] ],{i,1,nfinal}];
Print["     Eaib(",alist[[c]],glist[[j]],alist[[d]],")=",Eaib[alist[[c]],glist[[j]],alist[[d]]]];

      dip[co]=Daibggb[alist[[c]],glist[[j]],alist[[d]]];
      dipS[co]=Daibggb[alist[[c]],glist[[j]],
                 alist[[d]]]/.replist1[alist[[c]],glist[[j]],alist[[d]]]//Simplify;

      ehR[co]=Eaib[alist[[c]],glist[[j]],alist[[d]]];
      ehS[co]=Eaib[alist[[c]],glist[[j]],alist[[d]]]/.
          replist1[alist[[c]],glist[[j]],alist[[d]]]//Simplify;
      ehS[co]=ehS[co]/.{p[alist[[c]]]->p[0,c],p[glist[[j]]]->p[0,glist[[j]]+2],p[alist[[d]]]->p[0,d]};

      pemR[co]=paibai[alist[[c]],glist[[j]],alist[[d]]];
      pemS[co]=paibai[alist[[c]],glist[[j]],alist[[d]]]/.replist1[alist[[c]],glist[[j]],
            alist[[d]]]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[alist[[c]]]->p[r,c],p[glist[[j]]]->p[r,glist[[j]]+2],
            p[alist[[d]]]->p[r,d]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      Do[If[i != glist[[j]],
      ktilR[i,co]=ptil[i,alist[[c]],glist[[j]],alist[[d]]];
      ktilS[i,co]=ptil[i,alist[[c]],glist[[j]],alist[[d]]]/.replist1[alist[[c]],
            glist[[j]],alist[[d]]]//Simplify;
      Print["ktilS(",i,",",co,")=",ktilS[i,co]];

      Do[
       Do[If[i!=j,
      ktilS[i,co]=ktilS[i,co]/.{p[i].p[j]->t[i,j],p[j].p[i]->t[i,j]}]
        ,{i,1,nfinal}];
      ,{j,1,nfinal}];
      Do[ktilS[i,co]=ktilS[i,co]/.{p[a].p[i]->t[a,i],p[i].p[a]->t[a,i]},{i,1,nfinal}];
      Do[ktilS[i,co]=ktilS[i,co]/.{p[b].p[i]->t[b,i],p[i].p[b]->t[b,i]},{i,1,nfinal}];

      ktilS[i,co]=ktilS[i,co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2]}//Simplify;
      ktilS[i,co]=ktilS[i,co]/.{p[alist[[c]]]->p[r,c],p[alist[[d]]]->p[r,d]}//Simplify;
      Print["ktilS(",i,",",co,")=",ktilS[i,co]];
      ],{i,1,nfinal}];

emit[co]=c;spec[co]=d;cor[co,d]=alist[[d]];
templist={};
Do[
    Do[
      If[io != glist[[j]] && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
,{ib,3,nborn}];

Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pai(",alist[[c]],glist[[j]],alist[[d]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=p(",alist[[d]],")"]];
If[ib != emit[co] && ib != spec[co] ,Print["ptil(",co,",",ib,")=kj(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,alist[[c]],glist[[j]]];

                    ],{d,1,2}]
                  ],{c,1,2}]
                ,{j,1,ng}]


(* Dipole 2 *)


dipole2:=Module[{}, 
     Print["-------------------------------------------------------------------------"];
     Print["Dipole 2"];
     Print["{Splitting (5):(i,j)=(f,fbar)}"];
       If[nu >= 1 && nubar >= 1, If[ FreeQ[skipdipole,2u],showB2u;dipole2uuk;dipole2uuUa, 
                                                        Print["Dipole 2u is skipped"]]];
       If[nd >= 1 && ndbar >= 1, If[ FreeQ[skipdipole,2d],showB2d; dipole2ddk;dipole2ddUa,
                                                        Print["Dipole 2d is skipped"]]];
       If[ns >= 1 && nsbar >= 1, If[ FreeQ[skipdipole,2s],showB2s;dipole2ssk;dipole2ssUa, 
                                                        Print["Dipole 2s is skipped"]]];
       If[nc >= 1 && ncbar >= 1, If[ FreeQ[skipdipole,2c],showB2c; dipole2cck;dipole2ccUa,
                                                        Print["Dipole 2c is skipped"]]];
       If[nb >= 1 && nbbar >= 1, If[ FreeQ[skipdipole,2b],showB2b;
                                        If[ massiveb == 0, dipole2bbkzero;dipole2bbUazero];
                                        If[ massiveb == 1, dipole2bbk;dipole2bbUa];,
                                                        Print["Dipole 2b is skipped"]]];
       If[nt >= 1 && ntbar >= 1, If[ FreeQ[skipdipole,2t],showB2t;dipole2ttk;dipole2ttUa,
                                                        Print["Dipole 2t is skipped"]]];
     Print["*************************************************************************"];]


(* u-ubar splitting *)


showB2u:=Module[{},A2a1={};Do[If[i!=Last[ulist] && i!=Last[ubarlist], 
                  AppendTo[A2a1,X[i]]],{i,1,nfinal}];AppendTo[A2a1,g];
                  Print["{u-ubar splitting}"];
                  Print["M0=B2u:     ",{A[1],A[2]}," --> ", A2a1];
Print["Reduced momenta: ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V2a1[ib]=Part[A2a1,ib-2],{ib,3,nborn}];
]


dipole2uuk:=Module[{},Print["[9-u.(ij,k)=(u ubar,k): Dij,k]"];dipole2uukcr;]


dipole2uukcr:=Do[
               Do[
                Do[If[k != ulist[[i]] && k != ubarlist[[j]], 
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=1;Print[" "];Print["--Dip(",co,")--"];
 If[M[k]==0,
  dc[91]=dc[91]+1;
  Print["Dijkuuk(",ulist[[i]],ubarlist[[j]],k,")=",Dijkffk[ulist[[i]],ubarlist[[j]],k]];
  Print["     pij(",ulist[[i]],ubarlist[[j]],k,")=",pij[ulist[[i]],ubarlist[[j]],k]]; 
  Print["     pk(",ulist[[i]],ubarlist[[j]],k,")=",pk[ulist[[i]],ubarlist[[j]],k]];  
  Print["     Eijk(",ulist[[i]],ubarlist[[j]],k,")=",Eijk[ulist[[i]],ubarlist[[j]],k]];

      dip[co]=Dijkffk[ulist[[i]],ubarlist[[j]],k];
      dipS[co]=Dijkffk[ulist[[i]],ubarlist[[j]],k]
                                 /.replist1[ulist[[i]],ubarlist[[j]],k]//Simplify;

      ehR[co]=Eijk[ulist[[i]],ubarlist[[j]],k];
      ehS[co]=Eijk[ulist[[i]],ubarlist[[j]],k]/.
            replist1[ulist[[i]],ubarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[ulist[[i]],ubarlist[[j]],k];

         pemR[co]=pij[ulist[[i]],ubarlist[[j]],k];
         pemS[co]=pij[ulist[[i]],ubarlist[[j]],k]/.replist1[ulist[[i]],ubarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[ulist[[i]],ubarlist[[j]],k]//Simplify;

         pspR[co]=pk[ulist[[i]],ubarlist[[j]],k];  
         pspS[co]=pk[ulist[[i]],ubarlist[[j]],k]/.replist1[ulist[[i]],ubarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[ulist[[i]],ubarlist[[j]],k]//Simplify;
  ];

 If[MemberQ[masses,M[k]],
  dMc[91]=dMc[91]+1;
  Print["DMijkuuk(",ulist[[i]],ubarlist[[j]],k,")=",DMijkffk[ulist[[i]],ubarlist[[j]],k]];
  Print["     pMij(",ulist[[i]],ubarlist[[j]],k,")=",pMij[ulist[[i]],ubarlist[[j]],k,0]]; 
  Print["     pMk(",ulist[[i]],ubarlist[[j]],k,")=",pMk[ulist[[i]],ubarlist[[j]],k,0]];  
  Print["     EMijk(",ulist[[i]],ubarlist[[j]],k,")=",EMijk[ulist[[i]],ubarlist[[j]],k]];

      dip[co]=DMijkffk[ulist[[i]],ubarlist[[j]],k];
      dipS[co]=DMijkffk[ulist[[i]],ubarlist[[j]],k]
                                 /.replist1[ulist[[i]],ubarlist[[j]],k]//Simplify;

      ehR[co]=EMijk[ulist[[i]],ubarlist[[j]],k];
      ehS[co]=EMijk[ulist[[i]],ubarlist[[j]],k]/.
            replist1[ulist[[i]],ubarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[ulist[[i]],ubarlist[[j]],k];

         pemR[co]=pMij[ulist[[i]],ubarlist[[j]],k,0];
         pemS[co]=pMij[ulist[[i]],ubarlist[[j]],k,0]/.replist1[ulist[[i]],ubarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[ulist[[i]],ubarlist[[j]],k]//Simplify;

         pspR[co]=pMk[ulist[[i]],ubarlist[[j]],k,0];  
         pspS[co]=pMk[ulist[[i]],ubarlist[[j]],k,0]/.replist1[ulist[[i]],ubarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[ulist[[i]],ubarlist[[j]],k]//Simplify;
 ];

Do[If[V2a1[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V2a1[ib]==X[k],spec[co]=ib],{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != ulist[[i]] && io != ubarlist[[j]] && io != k && FreeQ[templist,io],
        If[V2a1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",ulist[[i]],ubarlist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",ulist[[i]],ubarlist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,ulist[[i]],ubarlist[[j]]];

                  ],{k,1,nfinal}]
                ,{j,1,nubar}]
              ,{i,1,nu}]


dipole2uuUa:=Module[{},Print["[10-u.(ij,a)=(u ubar,a): Dij^a]"];dipole2uuUacr;]


dipole2uuUacr:=Do[
                Do[
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=1;Print[" "];Print["--Dip(",co,")--"];

dc[101]=dc[101]+1; 
Print["DijUauuUa(",ulist[[i]],ubarlist[[j]],alist[[c]],")=",
                            DijUaffUa[ulist[[i]],ubarlist[[j]],alist[[c]]]];

Print["     pij(",ulist[[i]],ubarlist[[j]],alist[[c]],")=",pija[ulist[[i]],
                                                  ubarlist[[j]],alist[[c]]]]; 
Print["     pa(",ulist[[i]],ubarlist[[j]],alist[[c]],")=",pa[ulist[[i]],
                                                  ubarlist[[j]],alist[[c]]]]; 
Print["     Eija(",ulist[[i]],ubarlist[[j]],alist[[c]],")=",Eija[ulist[[i]],ubarlist[[j]],alist[[c]]]];

      dip[co]=DijUaffUa[ulist[[i]],ubarlist[[j]],alist[[c]]];
      dipS[co]=DijUaffUa[ulist[[i]],
                   ubarlist[[j]],alist[[c]]]/.replist1[ulist[[i]],ubarlist[[j]],
                                                          alist[[c]]]//Simplify;
      ehR[co]=Eija[ulist[[i]],ubarlist[[j]],alist[[c]]];
      ehS[co]=Eija[ulist[[i]],ubarlist[[j]],alist[[c]]]/.
                 replist1[ulist[[i]],ubarlist[[j]],alist[[c]]]//Simplify;
      ehS[co]=ehS[co]/.{p[ulist[[i]]]->p[0,ulist[[i]]+2],p[ubarlist[[j]]]->p[0,ubarlist[[j]]+2],
                                                           p[alist[[c]]]->p[0,c]};

         pemR[co]=pija[ulist[[i]],ubarlist[[j]],alist[[c]]];
         pemS[co]=pija[ulist[[i]],ubarlist[[j]],alist[[c]]]/.replist1[ulist[[i]],ubarlist[[j]],
                                                          alist[[c]]]//Simplify;
         pemS[co]=pemS[co]/.{p[ulist[[i]]]->p[r,ulist[[i]]+2],p[ubarlist[[j]]]->p[r,ubarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

         pspR[co]=pa[ulist[[i]],ubarlist[[j]],alist[[c]]];  
         pspS[co]=pa[ulist[[i]],ubarlist[[j]],alist[[c]]]/.replist1[ulist[[i]],ubarlist[[j]],alist[[c]]]//Simplify;
         pspS[co]=pspS[co]/.{p[ulist[[i]]]->p[r,ulist[[i]]+2],p[ubarlist[[j]]]->p[r,ubarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

spec[co]=c;
Do[If[V2a1[ib]==g,emit[co]=ib;Break[]];,{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != ulist[[i]] && io != ubarlist[[j]] && FreeQ[templist,io],
        If[V2a1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",ulist[[i]],ubarlist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",ulist[[i]],ubarlist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,ulist[[i]],ubarlist[[j]]];

              ],{c,1,2}]       
           ,{j,1,nubar}]                    
        ,{i,1,nu}]


(* d-dbar splitting *)


showB2d:=Module[{},A2a2={};Do[If[i!=Last[dlist] && i!=Last[dbarlist], 
                  AppendTo[A2a2,X[i]]],{i,1,nfinal}];AppendTo[A2a2,g];
                  Print["{d-dbar splitting}"];
                  Print["M0=B2d:     ",{A[1],A[2]}," --> ", A2a2];
Print["Reduced momenta: ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V2a2[ib]=Part[A2a2,ib-2],{ib,3,nborn}];]


dipole2ddk:=Module[{},Print["[9-d.(ij,k)=(d dbar,k): Dij,k]"];dipole2ddkcr;]


dipole2ddkcr:=Do[
               Do[
                Do[If[k != dlist[[i]] && k != dbarlist[[j]], 
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=2;Print[" "];Print["--Dip(",co,")--"];
 If[M[k]==0,
  dc[93]=dc[93]+1;
  Print["Dijkddk(",dlist[[i]],dbarlist[[j]],k,")=",Dijkffk[dlist[[i]],dbarlist[[j]],k]];
  Print["     pij(",dlist[[i]],dbarlist[[j]],k,")=",pij[dlist[[i]],dbarlist[[j]],k]]; 
  Print["     pk(",dlist[[i]],dbarlist[[j]],k,")=",pk[dlist[[i]],dbarlist[[j]],k]];  
  Print["     Eijk(",dlist[[i]],dbarlist[[j]],k,")=",Eijk[dlist[[i]],dbarlist[[j]],k]];

      dip[co]=Dijkffk[dlist[[i]],dbarlist[[j]],k];
      dipS[co]=Dijkffk[dlist[[i]],dbarlist[[j]],k]
                                 /.replist1[dlist[[i]],dbarlist[[j]],k]//Simplify;

      ehR[co]=Eijk[dlist[[i]],dbarlist[[j]],k];
      ehS[co]=Eijk[dlist[[i]],dbarlist[[j]],k]/.
            replist1[dlist[[i]],dbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[dlist[[i]],dbarlist[[j]],k];

         pemR[co]=pij[dlist[[i]],dbarlist[[j]],k];
         pemS[co]=pij[dlist[[i]],dbarlist[[j]],k]/.replist1[dlist[[i]],dbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[dlist[[i]],dbarlist[[j]],k]//Simplify;

         pspR[co]=pk[dlist[[i]],dbarlist[[j]],k];  
         pspS[co]=pk[dlist[[i]],dbarlist[[j]],k]/.replist1[dlist[[i]],dbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[dlist[[i]],dbarlist[[j]],k]//Simplify;

];
 If[MemberQ[masses,M[k]],
  dMc[93]=dMc[93]+1;
  Print["DMijkddk(",dlist[[i]],dbarlist[[j]],k,")=",DMijkffk[dlist[[i]],dbarlist[[j]],k]];
  Print["     pMij(",dlist[[i]],dbarlist[[j]],k,")=",pMij[dlist[[i]],dbarlist[[j]],k]]; 
  Print["     pMk(",dlist[[i]],dbarlist[[j]],k,")=",pMk[dlist[[i]],dbarlist[[j]],k]];  
  Print["     EMijk(",dlist[[i]],dbarlist[[j]],k,")=",EMijk[dlist[[i]],dbarlist[[j]],k]];

      dip[co]=DMijkffk[dlist[[i]],dbarlist[[j]],k];
      dipS[co]=DMijkffk[dlist[[i]],dbarlist[[j]],k]
                                 /.replist1[dlist[[i]],dbarlist[[j]],k]//Simplify;

      ehR[co]=EMijk[dlist[[i]],dbarlist[[j]],k];
      ehS[co]=EMijk[dlist[[i]],dbarlist[[j]],k]/.
            replist1[dlist[[i]],dbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[dlist[[i]],dbarlist[[j]],k];

         pemR[co]=pMij[dlist[[i]],dbarlist[[j]],k];
         pemS[co]=pMij[dlist[[i]],dbarlist[[j]],k]/.replist1[dlist[[i]],dbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[dlist[[i]],dbarlist[[j]],k]//Simplify;

         pspR[co]=pMk[dlist[[i]],dbarlist[[j]],k];  
         pspS[co]=pMk[dlist[[i]],dbarlist[[j]],k]/.replist1[dlist[[i]],dbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[dlist[[i]],dbarlist[[j]],k]//Simplify;

];
Do[If[V2a2[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V2a2[ib]==X[k],spec[co]=ib],{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != dlist[[i]] && io != dbarlist[[j]] && io != k && FreeQ[templist,io],
        If[V2a2[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",dlist[[i]],dbarlist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",dlist[[i]],dbarlist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,dlist[[i]],dbarlist[[j]]];

                  ],{k,1,nfinal}]
                ,{j,1,ndbar}]
              ,{i,1,nd}]


dipole2ddUa:=Module[{},Print["[10-d.(ij,a)=(d dbar,a): Dij^a]"];dipole2ddUacr;]


dipole2ddUacr:=Do[
                Do[
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=2;Print[" "];Print["--Dip(",co,")--"];

dc[103]=dc[103]+1;
Print["DijUaddUa(",dlist[[i]],dbarlist[[j]],alist[[c]],")=",
                            DijUaffUa[dlist[[i]],dbarlist[[j]],alist[[c]]]];


Print["     pij(",dlist[[i]],dbarlist[[j]],alist[[c]],")=",pija[dlist[[i]],
                                                  dbarlist[[j]],alist[[c]]]]; 
Print["     pa(",dlist[[i]],dbarlist[[j]],alist[[c]],")=",pa[dlist[[i]],
                                                  dbarlist[[j]],alist[[c]]]]; 
Print["     Eija(",dlist[[i]],dbarlist[[j]],alist[[c]],")=",Eija[dlist[[i]],dbarlist[[j]],alist[[c]]]];

      dip[co]=DijUaffUa[dlist[[i]],dbarlist[[j]],alist[[c]]];
      dipS[co]=DijUaffUa[dlist[[i]],
                   dbarlist[[j]],alist[[c]]]/.replist1[dlist[[i]],dbarlist[[j]],
                                                          alist[[c]]]//Simplify;
      ehR[co]=Eija[dlist[[i]],dbarlist[[j]],alist[[c]]];
      ehS[co]=Eija[dlist[[i]],dbarlist[[j]],alist[[c]]]/.
                 replist1[dlist[[i]],dbarlist[[j]],alist[[c]]]//Simplify;
      ehS[co]=ehS[co]/.{p[dlist[[i]]]->p[0,dlist[[i]]+2],p[dbarlist[[j]]]->p[0,dbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[0,c]};

         pemR[co]=pija[dlist[[i]],dbarlist[[j]],alist[[c]]];
         pemS[co]=pija[dlist[[i]],dbarlist[[j]],alist[[c]]]/.replist1[dlist[[i]],dbarlist[[j]],
                                                          alist[[c]]]//Simplify;
         pemS[co]=pemS[co]/.{p[dlist[[i]]]->p[r,dlist[[i]]+2],p[dbarlist[[j]]]->p[r,dbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

         pspR[co]=pa[dlist[[i]],dbarlist[[j]],alist[[c]]];  
         pspS[co]=pa[dlist[[i]],dbarlist[[j]],alist[[c]]]/.replist1[dlist[[i]],dbarlist[[j]],alist[[c]]]//Simplify;
         pspS[co]=pspS[co]/.{p[dlist[[i]]]->p[r,dlist[[i]]+2],p[dbarlist[[j]]]->p[r,dbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

spec[co]=c;
Do[If[V2a2[ib]==g,emit[co]=ib;Break[]];,{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != dlist[[i]] && io != dbarlist[[j]] && FreeQ[templist,io],
        If[V2a2[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",dlist[[i]],dbarlist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",dlist[[i]],dbarlist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,dlist[[i]],dbarlist[[j]]];

                  ],{c,1,2}]
                ,{j,1,ndbar}]
              ,{i,1,nd}]


(* s-sbar splitting *)


showB2s:=Module[{},A2a5={};Do[If[i!=Last[slist] && i!=Last[sbarlist], 
                  AppendTo[A2a5,X[i]]],{i,1,nfinal}];AppendTo[A2a5,g];
                  Print["{s-sbar splitting}"];
                  Print["M0=B2s:     ",{A[1],A[2]}," --> ", A2a5];
Print["Reduced momenta: ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V2a5[ib]=Part[A2a5,ib-2],{ib,3,nborn}];
]


dipole2ssk:=Module[{},Print["[9-s.(ij,k)=(s sbar,k): Dij,k]"];dipole2sskcr;]


dipole2sskcr:=Do[
               Do[
                Do[If[k != slist[[i]] && k != sbarlist[[j]], 
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=5;Print[" "];Print["--Dip(",co,")--"];
 If[M[k]==0,
  dc[94]=dc[94]+1;
  Print["Dijkssk(",slist[[i]],sbarlist[[j]],k,")=",Dijkffk[slist[[i]],sbarlist[[j]],k]];
  Print["     pij(",slist[[i]],sbarlist[[j]],k,")=",pij[slist[[i]],sbarlist[[j]],k]]; 
  Print["     pk(",slist[[i]],sbarlist[[j]],k,")=",pk[slist[[i]],sbarlist[[j]],k]];  
  Print["     Eijk(",slist[[i]],sbarlist[[j]],k,")=",Eijk[slist[[i]],sbarlist[[j]],k]];

      dip[co]=Dijkffk[slist[[i]],sbarlist[[j]],k];
      dipS[co]=Dijkffk[slist[[i]],sbarlist[[j]],k]
                                 /.replist1[slist[[i]],sbarlist[[j]],k]//Simplify;

      ehR[co]=Eijk[slist[[i]],sbarlist[[j]],k];
      ehS[co]=Eijk[slist[[i]],sbarlist[[j]],k]/.
            replist1[slist[[i]],sbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[slist[[i]],sbarlist[[j]],k];

         pemR[co]=pij[slist[[i]],sbarlist[[j]],k];
         pemS[co]=pij[slist[[i]],sbarlist[[j]],k]/.replist1[slist[[i]],sbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[slist[[i]],sbarlist[[j]],k]//Simplify;

         pspR[co]=pk[slist[[i]],sbarlist[[j]],k];  
         pspS[co]=pk[slist[[i]],sbarlist[[j]],k]/.replist1[slist[[i]],sbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[slist[[i]],sbarlist[[j]],k]//Simplify;
  ];

 If[MemberQ[masses,M[k]],
  dMc[94]=dMc[94]+1;
  Print["DMijkssk(",slist[[i]],sbarlist[[j]],k,")=",DMijkffk[slist[[i]],sbarlist[[j]],k]];
  Print["     pMij(",slist[[i]],sbarlist[[j]],k,")=",pMij[slist[[i]],sbarlist[[j]],k,0]]; 
  Print["     pMk(",slist[[i]],sbarlist[[j]],k,")=",pMk[slist[[i]],sbarlist[[j]],k,0]];  
  Print["     EMijk(",slist[[i]],sbarlist[[j]],k,")=",EMijk[slist[[i]],sbarlist[[j]],k]];

      dip[co]=DMijkffk[slist[[i]],sbarlist[[j]],k];
      dipS[co]=DMijkffk[slist[[i]],sbarlist[[j]],k]
                                 /.replist1[slist[[i]],sbarlist[[j]],k]//Simplify;

      ehR[co]=EMijk[slist[[i]],sbarlist[[j]],k];
      ehS[co]=EMijk[slist[[i]],sbarlist[[j]],k]/.
            replist1[slist[[i]],sbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[slist[[i]],sbarlist[[j]],k];

         pemR[co]=pMij[slist[[i]],sbarlist[[j]],k,0];
         pemS[co]=pMij[slist[[i]],sbarlist[[j]],k,0]/.replist1[slist[[i]],sbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[slist[[i]],sbarlist[[j]],k]//Simplify;

         pspR[co]=pMk[slist[[i]],sbarlist[[j]],k,0];  
         pspS[co]=pMk[slist[[i]],sbarlist[[j]],k,0]/.replist1[slist[[i]],sbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[slist[[i]],sbarlist[[j]],k]//Simplify;
 ];

Do[If[V2a5[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V2a5[ib]==X[k],spec[co]=ib],{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != slist[[i]] && io != sbarlist[[j]] && io != k && FreeQ[templist,io],
        If[V2a5[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",slist[[i]],sbarlist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",slist[[i]],sbarlist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,slist[[i]],sbarlist[[j]]];

                  ],{k,1,nfinal}]
                ,{j,1,nsbar}]
              ,{i,1,ns}]


dipole2ssUa:=Module[{},Print["[10-s.(ij,a)=(s sbar,a): Dij^a]"];dipole2ssUacr;]


dipole2ssUacr:=Do[
                Do[
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=5;Print[" "];Print["--Dip(",co,")--"];

dc[104]=dc[104]+1; 
Print["DijUassUa(",slist[[i]],sbarlist[[j]],alist[[c]],")=",
                            DijUaffUa[slist[[i]],sbarlist[[j]],alist[[c]]]];

Print["     pij(",slist[[i]],sbarlist[[j]],alist[[c]],")=",pija[slist[[i]],
                                                  sbarlist[[j]],alist[[c]]]]; 
Print["     pa(",slist[[i]],sbarlist[[j]],alist[[c]],")=",pa[slist[[i]],
                                                  sbarlist[[j]],alist[[c]]]]; 
Print["     Eija(",slist[[i]],sbarlist[[j]],alist[[c]],")=",Eija[slist[[i]],sbarlist[[j]],alist[[c]]]];

      dip[co]=DijUaffUa[slist[[i]],sbarlist[[j]],alist[[c]]];
      dipS[co]=DijUaffUa[slist[[i]],
                   sbarlist[[j]],alist[[c]]]/.replist1[slist[[i]],sbarlist[[j]],
                                                          alist[[c]]]//Simplify;
      ehR[co]=Eija[slist[[i]],sbarlist[[j]],alist[[c]]];
      ehS[co]=Eija[slist[[i]],sbarlist[[j]],alist[[c]]]/.
                 replist1[slist[[i]],sbarlist[[j]],alist[[c]]]//Simplify;
      ehS[co]=ehS[co]/.{p[slist[[i]]]->p[0,slist[[i]]+2],p[sbarlist[[j]]]->p[0,sbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[0,c]};

         pemR[co]=pija[slist[[i]],sbarlist[[j]],alist[[c]]];
         pemS[co]=pija[slist[[i]],sbarlist[[j]],alist[[c]]]/.replist1[slist[[i]],sbarlist[[j]],
                                                          alist[[c]]]//Simplify;
         pemS[co]=pemS[co]/.{p[slist[[i]]]->p[r,slist[[i]]+2],p[sbarlist[[j]]]->p[r,sbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

         pspR[co]=pa[slist[[i]],sbarlist[[j]],alist[[c]]];  
         pspS[co]=pa[slist[[i]],sbarlist[[j]],alist[[c]]]/.replist1[slist[[i]],sbarlist[[j]],alist[[c]]]//Simplify;
         pspS[co]=pspS[co]/.{p[slist[[i]]]->p[r,slist[[i]]+2],p[sbarlist[[j]]]->p[r,sbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

spec[co]=c;
Do[If[V2a5[ib]==g,emit[co]=ib;Break[]];,{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != slist[[i]] && io != sbarlist[[j]] && FreeQ[templist,io],
        If[V2a5[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",slist[[i]],sbarlist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",slist[[i]],sbarlist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,slist[[i]],sbarlist[[j]]];

              ],{c,1,2}]       
           ,{j,1,nsbar}]                    
        ,{i,1,ns}]


(* c-cbar splitting *)


showB2c:=Module[{},A2a6={};Do[If[i!=Last[clist] && i!=Last[cbarlist], 
                  AppendTo[A2a6,X[i]]],{i,1,nfinal}];AppendTo[A2a6,g];
                  Print["{c-cbar splitting}"];
                  Print["M0=B2c:     ",{A[1],A[2]}," --> ", A2a6];
Print["Reduced momenta: ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V2a6[ib]=Part[A2a6,ib-2],{ib,3,nborn}];
]


dipole2cck:=Module[{},Print["[9-c.(ij,k)=(c cbar,k): Dij,k]"];dipole2cckcr;]


dipole2cckcr:=Do[
               Do[
                Do[If[k != clist[[i]] && k != cbarlist[[j]], 
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=6;Print[" "];Print["--Dip(",co,")--"];
 If[M[k]==0,
  dc[95]=dc[95]+1;
  Print["Dijkcck(",clist[[i]],cbarlist[[j]],k,")=",Dijkffk[clist[[i]],cbarlist[[j]],k]];
  Print["     pij(",clist[[i]],cbarlist[[j]],k,")=",pij[clist[[i]],cbarlist[[j]],k]]; 
  Print["     pk(",clist[[i]],cbarlist[[j]],k,")=",pk[clist[[i]],cbarlist[[j]],k]];  
  Print["     Eijk(",clist[[i]],cbarlist[[j]],k,")=",Eijk[clist[[i]],cbarlist[[j]],k]];

      dip[co]=Dijkffk[clist[[i]],cbarlist[[j]],k];
      dipS[co]=Dijkffk[clist[[i]],cbarlist[[j]],k]
                                 /.replist1[clist[[i]],cbarlist[[j]],k]//Simplify;

      ehR[co]=Eijk[clist[[i]],cbarlist[[j]],k];
      ehS[co]=Eijk[clist[[i]],cbarlist[[j]],k]/.
            replist1[clist[[i]],cbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[clist[[i]],cbarlist[[j]],k];

         pemR[co]=pij[clist[[i]],cbarlist[[j]],k];
         pemS[co]=pij[clist[[i]],cbarlist[[j]],k]/.replist1[clist[[i]],cbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[clist[[i]],cbarlist[[j]],k]//Simplify;

         pspR[co]=pk[clist[[i]],cbarlist[[j]],k];  
         pspS[co]=pk[clist[[i]],cbarlist[[j]],k]/.replist1[clist[[i]],cbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[clist[[i]],cbarlist[[j]],k]//Simplify;
  ];

 If[MemberQ[masses,M[k]],
  dMc[95]=dMc[95]+1;
  Print["DMijkssk(",clist[[i]],cbarlist[[j]],k,")=",DMijkffk[clist[[i]],cbarlist[[j]],k]];
  Print["     pMij(",clist[[i]],cbarlist[[j]],k,")=",pMij[clist[[i]],cbarlist[[j]],k,0]]; 
  Print["     pMk(",clist[[i]],cbarlist[[j]],k,")=",pMk[clist[[i]],cbarlist[[j]],k,0]];  
  Print["     EMijk(",clist[[i]],cbarlist[[j]],k,")=",EMijk[clist[[i]],cbarlist[[j]],k]];

      dip[co]=DMijkffk[clist[[i]],cbarlist[[j]],k];
      dipS[co]=DMijkffk[clist[[i]],cbarlist[[j]],k]
                                 /.replist1[clist[[i]],cbarlist[[j]],k]//Simplify;

      ehR[co]=EMijk[clist[[i]],cbarlist[[j]],k];
      ehS[co]=EMijk[clist[[i]],cbarlist[[j]],k]/.
            replist1[clist[[i]],cbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[clist[[i]],cbarlist[[j]],k];

         pemR[co]=pMij[clist[[i]],cbarlist[[j]],k,0];
         pemS[co]=pMij[clist[[i]],cbarlist[[j]],k,0]/.replist1[clist[[i]],cbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[clist[[i]],cbarlist[[j]],k]//Simplify;

         pspR[co]=pMk[clist[[i]],cbarlist[[j]],k,0];  
         pspS[co]=pMk[clist[[i]],cbarlist[[j]],k,0]/.replist1[clist[[i]],cbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[clist[[i]],cbarlist[[j]],k]//Simplify;
 ];

Do[If[V2a6[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V2a6[ib]==X[k],spec[co]=ib],{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != clist[[i]] && io != cbarlist[[j]] && io != k && FreeQ[templist,io],
        If[V2a6[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",clist[[i]],cbarlist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",clist[[i]],cbarlist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,clist[[i]],cbarlist[[j]]];

                  ],{k,1,nfinal}]
                ,{j,1,ncbar}]
              ,{i,1,nc}]


dipole2ccUa:=Module[{},Print["[10-c.(ij,a)=(c cbar,a): Dij^a]"];dipole2ccUacr;]


dipole2ccUacr:=Do[
                Do[
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=6;Print[" "];Print["--Dip(",co,")--"];

dc[105]=dc[105]+1; 
Print["DijUaccUa(",clist[[i]],cbarlist[[j]],alist[[c]],")=",
                            DijUaffUa[clist[[i]],cbarlist[[j]],alist[[c]]]];

Print["     pij(",clist[[i]],cbarlist[[j]],alist[[c]],")=",pija[clist[[i]],
                                                  cbarlist[[j]],alist[[c]]]]; 
Print["     pa(",clist[[i]],cbarlist[[j]],alist[[c]],")=",pa[clist[[i]],
                                                  cbarlist[[j]],alist[[c]]]]; 
Print["     Eija(",clist[[i]],cbarlist[[j]],alist[[c]],")=",Eija[clist[[i]],cbarlist[[j]],alist[[c]]]];

      dip[co]=DijUaffUa[clist[[i]],cbarlist[[j]],alist[[c]]];
      dipS[co]=DijUaffUa[clist[[i]],
                   cbarlist[[j]],alist[[c]]]/.replist1[clist[[i]],cbarlist[[j]],
                                                          alist[[c]]]//Simplify;
      ehR[co]=Eija[clist[[i]],cbarlist[[j]],alist[[c]]];
      ehS[co]=Eija[clist[[i]],cbarlist[[j]],alist[[c]]]/.
                 replist1[clist[[i]],cbarlist[[j]],alist[[c]]]//Simplify;
      ehS[co]=ehS[co]/.{p[clist[[i]]]->p[0,clist[[i]]+2],p[cbarlist[[j]]]->p[0,cbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[0,c]};

         pemR[co]=pija[clist[[i]],cbarlist[[j]],alist[[c]]];
         pemS[co]=pija[clist[[i]],cbarlist[[j]],alist[[c]]]/.replist1[clist[[i]],cbarlist[[j]],
                                                          alist[[c]]]//Simplify;
         pemS[co]=pemS[co]/.{p[clist[[i]]]->p[r,clist[[i]]+2],p[cbarlist[[j]]]->p[r,cbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

         pspR[co]=pa[clist[[i]],cbarlist[[j]],alist[[c]]];  
         pspS[co]=pa[clist[[i]],cbarlist[[j]],alist[[c]]]/.replist1[clist[[i]],cbarlist[[j]],alist[[c]]]//Simplify;
         pspS[co]=pspS[co]/.{p[clist[[i]]]->p[r,clist[[i]]+2],p[cbarlist[[j]]]->p[r,cbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

spec[co]=c;
Do[If[V2a6[ib]==g,emit[co]=ib;Break[]];,{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != clist[[i]] && io != cbarlist[[j]] && FreeQ[templist,io],
        If[V2a6[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",clist[[i]],cbarlist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",clist[[i]],cbarlist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,clist[[i]],cbarlist[[j]]];

              ],{c,1,2}]       
           ,{j,1,ncbar}]                    
        ,{i,1,nc}]


(* b-bbar splitting *)


showB2b:=Module[{},A2a4={};Do[If[i!=Last[blist] && i!=Last[bbarlist], 
                  AppendTo[A2a4,X[i]]],{i,1,nfinal}];AppendTo[A2a4,g];
                  Print["{b-bbar splitting}"];
                  Print["M0=B2b: ",{A[1],A[2]}," --> ", A2a4];
Print["Reduced momenta: ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V2a4[ib]=Part[A2a4,ib-2],{ib,3,nborn}];]


dipole2bbkzero:=Module[{},Print["[9-b.(ij,k)=(b bbar,k): Dij,k (for massless b-quark)]"];
                                                                         dipole2bbkcrzero;]


dipole2bbkcrzero:=Do[
               Do[
                Do[If[k != blist[[i]] && k != bbarlist[[j]], 
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=3;Print[" "];Print["--Dip(",co,")--"];
 If[M[k]==0,
  dc[97]=dc[97]+1;
  Print["Dijkbbk(",blist[[i]],bbarlist[[j]],k,")=",Dijkffk[blist[[i]],bbarlist[[j]],k]];
  Print["     pij(",blist[[i]],bbarlist[[j]],k,")=",pij[blist[[i]],bbarlist[[j]],k]]; 
  Print["     pk(",blist[[i]],bbarlist[[j]],k,")=",pk[blist[[i]],bbarlist[[j]],k]];  
  Print["     Eijk(",blist[[i]],bbarlist[[j]],k,")=",Eijk[blist[[i]],bbarlist[[j]],k]];

      dip[co]=Dijkffk[blist[[i]],bbarlist[[j]],k];
      dipS[co]=Dijkffk[blist[[i]],bbarlist[[j]],k]
                                 /.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;

      ehR[co]=Eijk[blist[[i]],bbarlist[[j]],k];
      ehS[co]=Eijk[blist[[i]],bbarlist[[j]],k]/.
            replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[blist[[i]],bbarlist[[j]],k];

         pemR[co]=pij[blist[[i]],bbarlist[[j]],k];
         pemS[co]=pij[blist[[i]],bbarlist[[j]],k]/.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[blist[[i]],bbarlist[[j]],k]//Simplify;

         pspR[co]=pk[blist[[i]],bbarlist[[j]],k];  
         pspS[co]=pk[blist[[i]],bbarlist[[j]],k]/.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[blist[[i]],bbarlist[[j]],k]//Simplify;
  ];

 If[MemberQ[masses,M[k]],
  dMc[97]=dMc[97]+1;
  Print["DMijkbbk(",blist[[i]],bbarlist[[j]],k,")=",DMijkffk[blist[[i]],bbarlist[[j]],k]];
  Print["     pMij(",blist[[i]],bbarlist[[j]],k,")=",pMij[blist[[i]],bbarlist[[j]],k,0]]; 
  Print["     pMk(",blist[[i]],bbarlist[[j]],k,")=",pMk[blist[[i]],bbarlist[[j]],k,0]];  
  Print["     EMijk(",blist[[i]],bbarlist[[j]],k,")=",EMijk[blist[[i]],bbarlist[[j]],k]];

      dip[co]=DMijkffk[blist[[i]],bbarlist[[j]],k];
      dipS[co]=DMijkffk[blist[[i]],bbarlist[[j]],k]
                                 /.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;

      ehR[co]=EMijk[blist[[i]],bbarlist[[j]],k];
      ehS[co]=EMijk[blist[[i]],bbarlist[[j]],k]/.
            replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[blist[[i]],bbarlist[[j]],k];

         pemR[co]=pMij[blist[[i]],bbarlist[[j]],k,0];
         pemS[co]=pMij[blist[[i]],bbarlist[[j]],k,0]/.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[blist[[i]],bbarlist[[j]],k]//Simplify;

         pspR[co]=pMk[blist[[i]],bbarlist[[j]],k,0];  
         pspS[co]=pMk[blist[[i]],bbarlist[[j]],k,0]/.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[blist[[i]],bbarlist[[j]],k]//Simplify;
 ];

Do[If[V2a4[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V2a4[ib]==X[k],spec[co]=ib],{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != blist[[i]] && io != bbarlist[[j]] && io != k && FreeQ[templist,io],
        If[V2a4[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",blist[[i]],bbarlist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",blist[[i]],bbarlist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,blist[[i]],bbarlist[[j]]];

                  ],{k,1,nfinal}]
                ,{j,1,nbbar}]
              ,{i,1,nb}]


dipole2bbUazero:=Module[{},Print["[10-b.(ij,a)=(b bbar,a): Dij^a (for massless b-quark)]"];
                                                                       dipole2bbUacrzero;]


dipole2bbUacrzero:=Do[
                Do[
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=3;Print[" "];Print["--Dip(",co,")--"];

dc[107]=dc[107]+1; 
Print["DijUabbUa(",blist[[i]],bbarlist[[j]],alist[[c]],")=",
                            DijUaffUa[blist[[i]],bbarlist[[j]],alist[[c]]]];

Print["     pij(",blist[[i]],bbarlist[[j]],alist[[c]],")=",pija[blist[[i]],
                                                  bbarlist[[j]],alist[[c]]]]; 
Print["     pa(",blist[[i]],bbarlist[[j]],alist[[c]],")=",pa[blist[[i]],
                                                  bbarlist[[j]],alist[[c]]]]; 
Print["     Eija(",blist[[i]],bbarlist[[j]],alist[[c]],")=",Eija[blist[[i]],bbarlist[[j]],alist[[c]]]];

      dip[co]=DijUaffUa[blist[[i]],bbarlist[[j]],alist[[c]]];
      dipS[co]=DijUaffUa[blist[[i]],
                   bbarlist[[j]],alist[[c]]]/.replist1[blist[[i]],bbarlist[[j]],
                                                          alist[[c]]]//Simplify;
      ehR[co]=Eija[blist[[i]],bbarlist[[j]],alist[[c]]];
      ehS[co]=Eija[blist[[i]],bbarlist[[j]],alist[[c]]]/.
                 replist1[blist[[i]],bbarlist[[j]],alist[[c]]]//Simplify;
      ehS[co]=ehS[co]/.{p[blist[[i]]]->p[0,blist[[i]]+2],p[bbarlist[[j]]]->p[0,bbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[0,c]};

         pemR[co]=pija[blist[[i]],bbarlist[[j]],alist[[c]]];
         pemS[co]=pija[blist[[i]],bbarlist[[j]],alist[[c]]]/.replist1[blist[[i]],bbarlist[[j]],
                                                          alist[[c]]]//Simplify;
         pemS[co]=pemS[co]/.{p[blist[[i]]]->p[r,blist[[i]]+2],p[bbarlist[[j]]]->p[r,bbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

         pspR[co]=pa[blist[[i]],bbarlist[[j]],alist[[c]]];  
         pspS[co]=pa[blist[[i]],bbarlist[[j]],alist[[c]]]/.replist1[blist[[i]],bbarlist[[j]],alist[[c]]]//Simplify;
         pspS[co]=pspS[co]/.{p[blist[[i]]]->p[r,blist[[i]]+2],p[bbarlist[[j]]]->p[r,bbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

spec[co]=c;
Do[If[V2a4[ib]==g,emit[co]=ib;Break[]];,{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != blist[[i]] && io != bbarlist[[j]] && FreeQ[templist,io],
        If[V2a4[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",blist[[i]],bbarlist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",blist[[i]],bbarlist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,blist[[i]],bbarlist[[j]]];

              ],{c,1,2}]       
           ,{j,1,nbbar}]                    
        ,{i,1,nb}]


dipole2bbk:=Module[{},Print["[9-b.(ij,k)=(b bbar,k): Dij,k]"];dipole2bbkcr;]


dipole2bbkcr:=Do[
               Do[
                Do[If[k != blist[[i]] && k != bbarlist[[j]], 
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=3;Print[" "];Print["--Dip(",co,")--"];
  Print["DMijkbbk(",blist[[i]],bbarlist[[j]],k,")=",DMijkffk[blist[[i]],bbarlist[[j]],k]];
  Print["     pMij(",blist[[i]],bbarlist[[j]],k,")=",pMij[blist[[i]],bbarlist[[j]],k,0]]; 
  Print["     pMk(",blist[[i]],bbarlist[[j]],k,")=",pMk[blist[[i]],bbarlist[[j]],k,0]];  
  Print["     EMijk(",blist[[i]],bbarlist[[j]],k,")=",EMijk[blist[[i]],bbarlist[[j]],k]];

  dMc[97]=dMc[97]+1;

      dip[co]=DMijkffk[blist[[i]],bbarlist[[j]],k];
      dipS[co]=DMijkffk[blist[[i]],bbarlist[[j]],k]
                            /.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;

      ehR[co]=EMijk[blist[[i]],bbarlist[[j]],k];
      ehS[co]=EMijk[blist[[i]],bbarlist[[j]],k]/.
                  replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[blist[[i]],bbarlist[[j]],k];

         pemR[co]=pMij[blist[[i]],bbarlist[[j]],k,0];
         pemS[co]=pMij[blist[[i]],bbarlist[[j]],k,0]/.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[blist[[i]],bbarlist[[j]],k]//Simplify;

         pspR[co]=pMk[blist[[i]],bbarlist[[j]],k,0];  
         pspS[co]=pMk[blist[[i]],bbarlist[[j]],k,0]/.replist1[blist[[i]],bbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[blist[[i]],bbarlist[[j]],k]//Simplify;


Do[If[V2a4[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V2a4[ib]==X[k],spec[co]=ib;Break[]],{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != blist[[i]] && io != bbarlist[[j]] && io != k && FreeQ[templist,io],
        If[V2a4[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",blist[[i]],bbarlist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",blist[[i]],bbarlist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,blist[[i]],bbarlist[[j]]];
                  ],{k,1,nfinal}]
                ,{j,1,nbbar}]
              ,{i,1,nb}]


dipole2bbUa:=Module[{},Print["[10-b.(ij,a)=(b bbar,a): Dij^a]"];dipole2bbUacr;]


dipole2bbUacr:=Do[
                Do[
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=3;Print[" "];Print["--Dip(",co,")--"]; 
  Print["DMijUabbUa(",blist[[i]],bbarlist[[j]],alist[[c]],")=",
                            DMijUaffUa[blist[[i]],bbarlist[[j]],alist[[c]]]];
  Print["     pMija(",blist[[i]],bbarlist[[j]],alist[[c]],")=",pMija[blist[[i]],
                                                  bbarlist[[j]],alist[[c]],0]]; 
  Print["     pMa(",blist[[i]],bbarlist[[j]],alist[[c]],")=",pMa[blist[[i]],
                                                  bbarlist[[j]],alist[[c]],0]]; 
  Print["     EMija(",blist[[i]],bbarlist[[j]],alist[[c]],")=",EMija[blist[[i]],bbarlist[[j]],alist[[c]]]];


 dMc[107]=dMc[107]+1;

      dip[co]=DMijUaffUa[blist[[i]],bbarlist[[j]],alist[[c]]];
      dipS[co]=DMijUaffUa[blist[[i]],
                   bbarlist[[j]],alist[[c]]]/.replist1[blist[[i]],bbarlist[[j]],
                                                          alist[[c]]]//Simplify;

      ehR[co]=EMija[blist[[i]],bbarlist[[j]],alist[[c]]];
      ehS[co]=EMija[blist[[i]],bbarlist[[j]],alist[[c]]]/.
           replist1[blist[[i]],bbarlist[[j]],alist[[c]]]//Simplify;
      ehS[co]=ehS[co]/.{p[blist[[i]]]->p[0,blist[[i]]+2],p[bbarlist[[j]]]->p[0,bbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[0,c]};

         pemR[co]=pMija[blist[[i]],bbarlist[[j]],alist[[c]],0];
         pemS[co]=pMija[blist[[i]],bbarlist[[j]],alist[[c]],0]/.replist1[blist[[i]],bbarlist[[j]],
                                                          alist[[c]]]//Simplify;
         pemS[co]=pemS[co]/.{p[blist[[i]]]->p[r,blist[[i]]+2],p[bbarlist[[j]]]->p[r,bbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

         pspR[co]=pMa[blist[[i]],bbarlist[[j]],alist[[c]],0];  
         pspS[co]=pMa[blist[[i]],bbarlist[[j]],alist[[c]],0]/.replist1[blist[[i]],bbarlist[[j]],alist[[c]]]//Simplify;
         pspS[co]=pspS[co]/.{p[blist[[i]]]->p[r,blist[[i]]+2],p[bbarlist[[j]]]->p[r,bbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

spec[co]=c;
Do[If[V2a4[ib]==g,emit[co]=ib;Break[]];,{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != blist[[i]] && io != bbarlist[[j]] && FreeQ[templist,io],
        If[V2a4[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",blist[[i]],bbarlist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",blist[[i]],bbarlist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,blist[[i]],bbarlist[[j]]];
              ],{c,1,2}]       
           ,{j,1,nbbar}]                    
        ,{i,1,nb}]


(* t-tbar splitting *)


showB2t:=Module[{},A2a3={};Do[If[i!=Last[tlist] && i!=Last[tbarlist], 
                  AppendTo[A2a3,X[i]]],{i,1,nfinal}];AppendTo[A2a3,g];
                  Print["{t-tbar splitting}"];
                  Print["M0=B2t: ",{A[1],A[2]}," --> ", A2a3];
Print["Reduced momenta: ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V2a3[ib]=Part[A2a3,ib-2],{ib,3,nborn}];]


dipole2ttk:=Module[{},Print["[9-t.(ij,k)=(t tbar,k): Dij,k]"];dipole2ttkcr;]


dipole2ttkcr:=Do[
               Do[
                Do[If[k != tlist[[i]] && k != tbarlist[[j]], 
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=4;Print[" "];Print["--Dip(",co,")--"];
  Print["DMijkttk(",tlist[[i]],tbarlist[[j]],k,")=",DMijkffk[tlist[[i]],tbarlist[[j]],k]];
  Print["     pMij(",tlist[[i]],tbarlist[[j]],k,")=",pMij[tlist[[i]],tbarlist[[j]],k,0]]; 
  Print["     pMk(",tlist[[i]],tbarlist[[j]],k,")=",pMk[tlist[[i]],tbarlist[[j]],k,0]];  
  Print["     EMijk(",tlist[[i]],tbarlist[[j]],k,")=",EMijk[tlist[[i]],tbarlist[[j]],k]];


  dMc[98]=dMc[98]+1;

      dip[co]=DMijkffk[tlist[[i]],tbarlist[[j]],k];
      dipS[co]=DMijkffk[tlist[[i]],tbarlist[[j]],k]
                               /.replist1[tlist[[i]],tbarlist[[j]],k]//Simplify;

      ehR[co]=EMijk[tlist[[i]],tbarlist[[j]],k];
      ehS[co]=EMijk[tlist[[i]],tbarlist[[j]],k]/.
           replist1[tlist[[i]],tbarlist[[j]],k]//Simplify;
      ehS[co]=ehS[co]/.repmom3[tlist[[i]],tbarlist[[j]],k];

         pemR[co]=pMij[tlist[[i]],tbarlist[[j]],k,0];
         pemS[co]=pMij[tlist[[i]],tbarlist[[j]],k,0]/.replist1[tlist[[i]],tbarlist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[tlist[[i]],tbarlist[[j]],k]//Simplify;

         pspR[co]=pMk[tlist[[i]],tbarlist[[j]],k,0];  
         pspS[co]=pMk[tlist[[i]],tbarlist[[j]],k,0]/.replist1[tlist[[i]],tbarlist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[tlist[[i]],tbarlist[[j]],k]//Simplify;

Do[If[V2a3[ib]==g,emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V2a3[ib]==X[k],spec[co]=ib;Break[]],{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != tlist[[i]] && io != tbarlist[[j]] && io != k && FreeQ[templist,io],
        If[V2a3[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",tlist[[i]],tbarlist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",tlist[[i]],tbarlist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,tlist[[i]],tbarlist[[j]]];
                  ],{k,1,nfinal}]
                ,{j,1,ntbar}]
              ,{i,1,nt}]


dipole2ttUa:=Module[{},Print["[10-t.(ij,a)=(t tbar,a): Dij^a]"];dipole2ttUacr;]


dipole2ttUacr:=Do[
                Do[
                 Do[If[ MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;gluonemit[co,2]=1;speciesdip2[co]=4;Print[" "];Print["--Dip(",co,")--"];
  Print["DMijUattUa(",tlist[[i]],tbarlist[[j]],alist[[c]],")=",
                            DMijUaffUa[tlist[[i]],tbarlist[[j]],alist[[c]]]];
  Print["     pMija(",tlist[[i]],tbarlist[[j]],alist[[c]],")=",pMija[tlist[[i]],
                                                  tbarlist[[j]],alist[[c]],0]]; 
  Print["     pMa(",tlist[[i]],tbarlist[[j]],alist[[c]],")=",pMa[tlist[[i]],
                                                  tbarlist[[j]],alist[[c]],0]]; 
  Print["     EMija(",tlist[[i]],tbarlist[[j]],alist[[c]],")=",EMija[tlist[[i]],tbarlist[[j]],alist[[c]]]];


 dMc[108]=dMc[108]+1;

      dip[co]=DMijUaffUa[tlist[[i]],tbarlist[[j]],alist[[c]]];
      dipS[co]=DMijUaffUa[tlist[[i]],tbarlist[[j]],alist[[c]]]/.
               replist1[tlist[[i]],tbarlist[[j]],alist[[c]]]//Simplify;

      ehR[co]=EMija[tlist[[i]],tbarlist[[j]],alist[[c]]];
      ehS[co]=EMija[tlist[[i]],tbarlist[[j]],alist[[c]]]/.
            replist1[tlist[[i]],tbarlist[[j]],alist[[c]]]//Simplify;
      ehS[co]=ehS[co]/.{p[tlist[[i]]]->p[0,tlist[[i]]+2],p[tbarlist[[j]]]->p[0,tbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[0,c]};

         pemR[co]=pMija[tlist[[i]],tbarlist[[j]],alist[[c]],0];
         pemS[co]=pMija[tlist[[i]],tbarlist[[j]],alist[[c]],0]/.replist1[tlist[[i]],tbarlist[[j]],
                                                          alist[[c]]]//Simplify;
         pemS[co]=pemS[co]/.{p[tlist[[i]]]->p[r,tlist[[i]]+2],p[tbarlist[[j]]]->p[r,tbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;

         pspR[co]=pMa[tlist[[i]],tbarlist[[j]],alist[[c]],0];  
         pspS[co]=pMa[tlist[[i]],tbarlist[[j]],alist[[c]],0]/.replist1[tlist[[i]],tbarlist[[j]],alist[[c]]]//Simplify;
         pspS[co]=pspS[co]/.{p[tlist[[i]]]->p[r,tlist[[i]]+2],p[tbarlist[[j]]]->p[r,tbarlist[[j]]+2],
                                                           p[alist[[c]]]->p[r,c]}//Simplify;
spec[co]=c;
Do[If[V2a3[ib]==g,emit[co]=ib;Break[]];,{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != tlist[[i]] && io != tbarlist[[j]] && FreeQ[templist,io],
        If[V2a3[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",tlist[[i]],tbarlist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",tlist[[i]],tbarlist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,tlist[[i]],tbarlist[[j]]];
              ],{c,1,2}]       
           ,{j,1,ntbar}]                    
        ,{i,1,nt}]


(* Dipole 3 *)


dipole3:=Module[{}, 
     Print["-------------------------------------------------------------------------"];
     Print["Dipole 3"];
     Print["{Splitting (6):(a,i)=(f,f) or (fbar,fbar)}"];
       If[lu >= 1 && nu >= 1, If[ FreeQ[skipdipole,3u],showB3u;dipole3uuDk;dipole3uub;,
                                                        Print["Dipole 3u is skipped"]]];
       If[lubar >= 1 && nubar >= 1, If[ FreeQ[skipdipole,3ubar],
         showB3ubar;dipole3ubarubarDk;dipole3ubarubarb;,Print["Dipole 3ubar is skipped"]]];
       If[ld >= 1 && nd >= 1, If[ FreeQ[skipdipole,3d],showB3d;dipole3ddDk;dipole3ddb,
                                                        Print["Dipole 3d is skipped"]]];
       If[ldbar >= 1 && ndbar >= 1, If[ FreeQ[skipdipole,3dbar],
          showB3dbar;dipole3dbardbarDk;dipole3dbardbarb;,Print["Dipole 3dbar is skipped"]]];
       If[ls >= 1 && ns >= 1, If[ FreeQ[skipdipole,3s],showB3s;dipole3ssDk;dipole3ssb;,
                                                        Print["Dipole 3s is skipped"]]];
       If[lsbar >= 1 && nsbar >= 1, If[ FreeQ[skipdipole,3sbar],
         showB3sbar;dipole3sbarsbarDk;dipole3sbarsbarb;,Print["Dipole 3sbar is skipped"]]];
       If[lc >= 1 && nc >= 1, If[ FreeQ[skipdipole,3c],showB3c;dipole3ccDk;dipole3ccb;,
                                                        Print["Dipole 3c is skipped"]]];
       If[lcbar >= 1 && ncbar >= 1, If[ FreeQ[skipdipole,3cbar],
         showB3cbar;dipole3cbarcbarDk;dipole3cbarcbarb;,Print["Dipole 3cbar is skipped"]]];
       If[lb >= 1 && nb >= 1 && massiveb == 0, 
                  If[ FreeQ[skipdipole,3b],showB3b;dipole3bbDk;dipole3bbb;,
                                                        Print["Dipole 3b is skipped"]]];
       If[lbbar >= 1 && nbbar >= 1 && massiveb == 0, 
                  If[ FreeQ[skipdipole,3bbar],showB3bbar;dipole3bbarbbarDk;dipole3bbarbbarb;,
                                                        Print["Dipole 3bbar is skipped"]]];
     Print["*************************************************************************"];]


(* (a,i)=(u,u) splitting *)


showB3u:=Module[{},A3a1={};Do[If[i!=Last[ulist], AppendTo[A3a1,X[i]]],{i,1,nfinal}];
                          If[A[1]==u,A3a1in={g,A[2]}];If[A[2]==u,A3a1in={A[1],g}];
                          Print["M0=B3u: ",A3a1in," --> ", A3a1];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a1[ib]=Part[A3a1in,ib],{ib,1,2}];Do[V3a1[ib]=Part[A3a1,ib-2],{ib,3,nborn}];]


dipole3uuDk:=Module[{},Print["[11-u.(ai,k)=(uu,k): D^ai,k]"];
dipole3ffDkcr[ulist,u,V3a1,nu,21,111];]


dipole3uub:=Module[{},If[lparton==2,Print["[12-u.(ai,b)=(uu,b): D^aib]"];
dipole3ffbcr[ulist,u,V3a1,nu,21,121]]]


(* (a,i)=(ubar,ubar) splitting *)


showB3ubar:=Module[{},A3a2={};Do[If[i!=Last[ubarlist], AppendTo[A3a2,X[i]]],{i,1,nfinal}];
                          If[A[1]==ubar,A3a2in={g,A[2]}];If[A[2]==ubar,A3a2in={A[1],g}];
                          Print["M0=B3ubar: ",A3a2in," --> ", A3a2];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a2[ib]=Part[A3a2in,ib],{ib,1,2}];Do[V3a2[ib]=Part[A3a2,ib-2],{ib,3,nborn}];]


dipole3ubarubarDk:=Module[{},Print["[11-ubar.(ai,k)=(ubar ubar,k): D^ai,k]"];
dipole3ffDkcr[ubarlist,ubar,V3a2,nubar,22,112];]


dipole3ubarubarb:=Module[{},If[lparton==2,Print["[12-ubar.(ai,b)=(ubar ubar,b): D^aib"];
dipole3ffbcr[ubarlist,ubar,V3a2,nubar,22,122]]]


(* (a,i)=(d,d) splitting *)


showB3d:=Module[{},A3a3={};Do[If[i!=Last[dlist], AppendTo[A3a3,X[i]]],{i,1,nfinal}];
                          If[A[1]==d,A3a3in={g,A[2]}];If[A[2]==d,A3a3in={A[1],g}];
                          Print["M0=B3d: ",A3a3in," --> ", A3a3];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a3[ib]=Part[A3a3in,ib],{ib,1,2}];Do[V3a3[ib]=Part[A3a3,ib-2],{ib,3,nborn}];]


dipole3ddDk:=Module[{},Print["[11-d.(ai,k)=(dd,k): D^ai,k]"];dipole3ffDkcr[dlist,d,V3a3,nd,23,113];]


dipole3ddb:=Module[{},If[lparton==2,Print["[12-d.(ai,k)=(dd,b): D^aib]"];
dipole3ffbcr[dlist,d,V3a3,nd,23,123]]]


(* (a,i)=(dbar,dbar) splitting *)


showB3dbar:=Module[{},A3a4={};Do[If[i!=Last[dbarlist], AppendTo[A3a4,X[i]]],{i,1,nfinal}];
                          If[A[1]==dbar,A3a4in={g,A[2]}];If[A[2]==dbar,A3a4in={A[1],g}];
                          Print["M0=B3dbar: ",A3a4in," --> ", A3a4];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a4[ib]=Part[A3a4in,ib],{ib,1,2}];Do[V3a4[ib]=Part[A3a4,ib-2],{ib,3,nborn}];]


dipole3dbardbarDk:=Module[{},Print["[11-d.(ai,k)=(dd,k): D^ai,k]"];
dipole3ffDkcr[dbarlist,dbar,V3a4,ndbar,24,114];]


dipole3dbardbarb:=Module[{},If[lparton==2,Print["[12-dbar.(ai,b)=(dbar dbar,b): D^aib]"];
dipole3ffbcr[dbarlist,dbar,V3a4,ndbar,24,124]]]


(* (a,i)=(s,s) splitting *)


showB3s:=Module[{},A3a5={};Do[If[i!=Last[slist], AppendTo[A3a5,X[i]]],{i,1,nfinal}];
                          If[A[1]=== s,A3a5in={g,A[2]}];If[A[2]=== s,A3a5in={A[1],g}];
                          Print["M0=B3s: ",A3a5in," --> ", A3a5];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a5[ib]=Part[A3a5in,ib],{ib,1,2}];Do[V3a5[ib]=Part[A3a5,ib-2],{ib,3,nborn}];]


dipole3ssDk:=Module[{},Print["[11-s.(ai,k)=(ss,k): D^ai,k]"];
dipole3ffDkcr[slist,s,V3a5,ns,25,115];]


dipole3ssb:=Module[{},If[lparton==2,Print["[12-s.(ai,b)=(ss,b): D^aib]"];
dipole3ffbcr[slist,s,V3a5,ns,25,125]]]


(* (a,i)=(sbar,sbar) splitting *)


showB3sbar:=Module[{},A3a6={};Do[If[i!=Last[sbarlist], AppendTo[A3a6,X[i]]],{i,1,nfinal}];
                          If[A[1]=== sbar,A3a6in={g,A[2]}];If[A[2]=== sbar,A3a6in={A[1],g}];
                          Print["M0=B3sbar: ",A3a6in," --> ", A3a6];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a6[ib]=Part[A3a6in,ib],{ib,1,2}];Do[V3a6[ib]=Part[A3a6,ib-2],{ib,3,nborn}];]


dipole3sbarsbarDk:=Module[{},Print["[11-sbar.(ai,k)=(sbar sbar,k): D^ai,k]"];
dipole3ffDkcr[sbarlist,sbar,V3a6,nsbar,26,116];]


dipole3sbarsbarb:=Module[{},If[lparton==2,Print["[12-sbar.(ai,b)=(sbar sbar,b): D^aib]"];
dipole3ffbcr[sbarlist,sbar,V3a6,nsbar,26,126]]]


(* (a,i)=(c,c) splitting *)


showB3c:=Module[{},A3a7={};Do[If[i!=Last[clist], AppendTo[A3a7,X[i]]],{i,1,nfinal}];
                          If[A[1]=== c,A3a7in={g,A[2]}];If[A[2]=== c,A3a7in={A[1],g}];
                          Print["M0=B3c: ",A3a7in," --> ", A3a7];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a7[ib]=Part[A3a7in,ib],{ib,1,2}];Do[V3a7[ib]=Part[A3a7,ib-2],{ib,3,nborn}];]


dipole3ccDk:=Module[{},Print["[11-c.(ai,k)=(cc,k): D^ai,k]"];
dipole3ffDkcr[clist,c,V3a7,nc,27,117];]


dipole3ccb:=Module[{},If[lparton==2,Print["[12-c.(ai,b)=(cc,b): D^aib]"];
dipole3ffbcr[clist,c,V3a7,nc,27,127]]]


(* (a,i)=(cbar,cbar) splitting *)


showB3cbar:=Module[{},A3a8={};Do[If[i!=Last[cbarlist], AppendTo[A3a8,X[i]]],{i,1,nfinal}];
                          If[A[1]=== cbar,A3a8in={g,A[2]}];If[A[2]=== cbar,A3a8in={A[1],g}];
                          Print["M0=B3cbar: ",A3a8in," --> ", A3a8];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a8[ib]=Part[A3a8in,ib],{ib,1,2}];Do[V3a8[ib]=Part[A3a8,ib-2],{ib,3,nborn}];]


dipole3cbarcbarDk:=Module[{},Print["[11-cbar.(ai,k)=(cbar cbar,k): D^ai,k]"];
dipole3ffDkcr[cbarlist,cbar,V3a8,ncbar,28,118];]


dipole3cbarcbarb:=Module[{},If[lparton==2,Print["[12-cbar.(ai,b)=(cbar cbar,b): D^aib]"];
dipole3ffbcr[cbarlist,cbar,V3a8,ncbar,28,128]]]


(* (a,i)=(b,b) splitting *)


showB3b:=Module[{},A3a9={};Do[If[i!=Last[blist], AppendTo[A3a9,X[i]]],{i,1,nfinal}];
                          If[A[1]==b,A3a9in={g,A[2]}];If[A[2]==b,A3a9in={A[1],g}];
                          Print["M0=B3b: ",A3a9in," --> ", A3a9];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a9[ib]=Part[A3a9in,ib],{ib,1,2}];Do[V3a9[ib]=Part[A3a9,ib-2],{ib,3,nborn}];]


dipole3bbDk:=Module[{},Print["[11-b.(ai,k)=(bb,k): D^ai,k]"];
dipole3ffDkcr[blist,b,V3a9,nb,29,119];]


dipole3bbb:=Module[{},If[lparton==2,Print["[12-b.(ai,b)=(bb,b): D^aib]"];
dipole3ffbcr[blist,b,V3a9,nb,29,129]]]


(* (a,i)=(bbar,bbar) splitting *)


showB3bbar:=Module[{},A3a10={};Do[If[i!=Last[bbarlist], AppendTo[A3a10,X[i]]],{i,1,nfinal}];
                          If[A[1]==bbar,A3a10in={g,A[2]}];If[A[2]==bbar,A3a10in={A[1],g}];
                          Print["M0=B3bbar: ",A3a10in," --> ", A3a10];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V3a10[ib]=Part[A3a10in,ib],{ib,1,2}];Do[V3a10[ib]=Part[A3a10,ib-2],{ib,3,nborn}];]


dipole3bbarbbarDk:=Module[{},Print["[11-bbar.(ai,k)=(bbarbbar,k): D^ai,k]"];
dipole3ffDkcr[bbarlist,bbar,V3a10,nbbar,30,120];]


dipole3bbarbbarb:=Module[{},If[lparton==2,Print["[12-bbar.(ai,b)=(bbarbbar,b): D^aib]"];
dipole3ffbcr[bbarlist,bbar,V3a10,nbbar,30,130]]]


(* Module for dipole 3.(ai)=(ff)*)


dipole3ffDkcr[ulist_,u_,V3a1_,nu_,gluemit_,cnum_]:=Do[(*Print["I am first loop c=",c];*)
                     If[A[ci]===u, 
                 Do[
                   Do[If[k != ulist[[i]] && FreeQ[others,X[k]],
         co=co+1;gluonemit[co,3]=gluemit;Print[" "];Print["--Dip(",co,")--"];
  If[M[k]==0,
   dc[cnum]=dc[cnum]+1;
   Print["DaiDkffDk(",alist[[ci]],ulist[[i]],k,")=",
                               DaiDkffDk[alist[[ci]],ulist[[i]],k]];
   Print["     pai(",alist[[ci]],ulist[[i]],k,")=",pai[alist[[ci]],ulist[[i]],k]];
   Print["     pk(",alist[[ci]],ulist[[i]],k,")=",paikk[alist[[ci]],ulist[[i]],k]];
   Print["     Eaik(",alist[[ci]],ulist[[i]],k,")=",Eaik[alist[[ci]],ulist[[i]],k]];

      dip[co]=DaiDkffDk[alist[[ci]],ulist[[i]],k];
      dipS[co]=DaiDkffDk[alist[[ci]],ulist[[i]],k]
                            /.replist1[alist[[ci]],ulist[[i]],k]//Simplify;

      ehR[co]=Eaik[alist[[ci]],ulist[[i]],k];
      ehS[co]=Eaik[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
      ehS[co]=ehS[co]/.{p[alist[[ci]]]->p[0,ci],p[ulist[[i]]]->p[0,ulist[[i]]+2],p[k]->p[0,k+2]};

         pemR[co]=pai[alist[[ci]],ulist[[i]],k];
         pemS[co]=pai[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
         pemS[co]=pemS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],     
                                p[k]->p[r,k+2]}//Simplify;

         pspR[co]=paikk[alist[[ci]],ulist[[i]],k];  
         pspS[co]=paikk[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
         pspS[co]=pspS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],     
                                p[k]->p[r,k+2]}//Simplify;
  ];

 If[MemberQ[masses,M[k]],
   dMc[cnum]=dMc[cnum]+1;less[co]=1;
   Print["DMaiDkffDk(",alist[[ci]],ulist[[i]],k,")=",
                               DMaiDkffDk[alist[[ci]],ulist[[i]],k]];
   Print["     pMai(",alist[[ci]],ulist[[i]],k,")=",pai[alist[[ci]],ulist[[i]],k]];
   Print["     pMk(",alist[[ci]],ulist[[i]],k,")=",paikk[alist[[ci]],ulist[[i]],k]];
   Print["     EMaik(",alist[[ci]],ulist[[i]],k,")=",EMaik[alist[[ci]],ulist[[i]],k]];

      dip[co]=DMaiDkffDk[alist[[ci]],ulist[[i]],k];
      dipS[co]=DMaiDkffDk[alist[[ci]],ulist[[i]],k]
                            /.replist1[alist[[ci]],ulist[[i]],k]//Simplify;

      ehR[co]=EMaik[alist[[ci]],ulist[[i]],k];
      ehS[co]=EMaik[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
      ehS[co]=ehS[co]/.{p[alist[[ci]]]->p[0,ci],p[ulist[[i]]]->p[0,ulist[[i]]+2],p[k]->p[0,k+2]};

         pemR[co]=pai[alist[[ci]],ulist[[i]],k];
         pemS[co]=pai[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
         pemS[co]=pemS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],     
                                p[k]->p[r,k+2]}//Simplify;

         pspR[co]=paikk[alist[[ci]],ulist[[i]],k];  
         pspS[co]=paikk[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
         pspS[co]=pspS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],     
                                p[k]->p[r,k+2]}//Simplify;

      plesskR[co]=pless[k];
      plesskS[co]=pless[k]/.{p[k].q[2] -> s[alist[[ci]],k]/2}//Simplify;
      Print["plkS(",co,")=",plesskS[co]];
      plesskS[co]=plesskS[co]/.{p[k]->p[r,k+2],q[2]->p[r,ci]}//Simplify;
      Print["plkS(",co,")=",plesskS[co]];

  ];



Do[If[V3a1[ib]==g,emit[co]=ib;Break[]],{ib,1,2}];
Do[If[V3a1[ib]==X[k],spec[co]=ib;Break[]],{ib,3,nborn}];
Do[
If[ib != emit[co]\[NonBreakingSpace]&& ci==1,cor[co,ib]=b];
If[ib != emit[co]\[NonBreakingSpace]&& ci==2,cor[co,ib]=a];
,{ib,1,2}];
templist={};
Do[
  If[ib != spec[co],
    Do[
      If[io != ulist[[i]] && io !=k && FreeQ[templist,io],
        If[V3a1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];

Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pai(",alist[[ci]],ulist[[i]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",alist[[ci]],ulist[[i]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,alist[[ci]],ulist[[i]]];
                    ],{k,1,nfinal}]
                ,{i,1,nu}]
                ],{ci,1,2}]


dipole3ffbcr[ulist_,u_,V3a1_,nu_,gluemit_,cnum_]:=
Do[If[A[ci]===u,
                 Do[
                   Do[If[di != ci, 
         co=co+1;dinin[co]=1;gluonemit[co,3]=gluemit;Print[" "];Print["--Dip(",co,")--"];


Print["Daibffb(",alist[[ci]],ulist[[i]],alist[[di]],")=",
                               Daibffb[alist[[ci]],ulist[[i]],alist[[di]]]];


Print["     pai(",alist[[ci]],ulist[[i]],alist[[di]],")=",paibai[alist[[ci]],ulist[[i]],alist[[di]]]];
Do[If[j != ulist[[i]], 
Print["     ptil(",j,alist[[ci]],ulist[[i]],alist[[di]],")=",ptil[j,alist[[ci]],ulist[[i]],
alist[[di]]] ] ],{j,1,nfinal}];
Print["     Eaib(",alist[[ci]],ulist[[i]],alist[[di]],")=",Eaib[alist[[ci]],ulist[[i]],alist[[di]]]];
dc[cnum]=dc[cnum]+1;

      dip[co]=Daibffb[alist[[ci]],ulist[[i]],alist[[di]]];
      dipS[co]=Daibffb[alist[[ci]],ulist[[i]],alist[[di]]]/.replist1[alist[[ci]],ulist[[i]],
                                                     alist[[di]]]//Simplify;

      ehR[co]=Eaib[alist[[ci]],ulist[[i]],alist[[di]]];
      ehS[co]=Eaib[alist[[ci]],ulist[[i]],alist[[di]]]/.
            replist1[alist[[ci]],ulist[[i]],alist[[di]]]//Simplify;
      ehS[co]=ehS[co]/.{p[alist[[ci]]]->p[0,ci],p[ulist[[i]]]->p[0,ulist[[i]]+2],p[alist[[di]]]->p[0,di]};

      pemR[co]=paibai[alist[[ci]],ulist[[i]],alist[[di]]];
      pemS[co]=paibai[alist[[ci]],ulist[[i]],alist[[di]]]/.replist1[alist[[ci]],ulist[[i]],
            alist[[di]]]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],
            p[alist[[di]]]->p[r,di]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      Do[If[j != ulist[[i]],
        ktilR[j,co]=ptil[j,alist[[ci]],ulist[[i]],alist[[di]]];
        ktilS[j,co]=ptil[j,alist[[ci]],ulist[[i]],alist[[di]]]/.replist1[alist[[ci]],
            ulist[[i]],alist[[di]]]//Simplify;
        Do[
          Do[If[r2!=r1,
          ktilS[j,co]=ktilS[j,co]/.{p[r1].p[r2]->t[r1,r2],p[r2].p[r1]->t[r1,r2]}]
          ,{r2,1,nfinal}];
        ,{r1,1,nfinal}]; 
        Do[ktilS[j,co]=ktilS[j,co]/.{p[a].p[j]->t[a,j],p[l].p[a]->t[a,l]},{l,1,nfinal}];
        Do[ktilS[j,co]=ktilS[j,co]/.{p[b].p[j]->t[b,j],p[l].p[b]->t[b,l]},{l,1,nfinal}];

        ktilS[j,co]=ktilS[j,co]/.{p[j]->p[r,j+2],p[ulist[[i]]]->p[r,ulist[[i]]+2]}//Simplify;
        ktilS[j,co]=ktilS[j,co]/.{p[alist[[ci]]]->p[r,ci],p[alist[[di]]]->p[r,di]}//Simplify;
         Print["ktilS(",j,",",co,")=",ktilS[j,co]];
      ],{j,1,nfinal}];

templist={};
Do[If[V3a1[ib]==g,emit[co]=ib;Break[]],{ib,1,2}];
Do[If[ib2 != emit[co],spec[co]=ib2;cor[co,ib2]=alist[[di]];Break[]],{ib2,1,2}];
(*Do[If[V3a1[ib]==g,emit[co]=ib;Break[]],{ib,1,2}];spec[co]=d;*)
Do[
    Do[
      If[io != ulist[[i]]  && FreeQ[templist,io],
        If[V3a1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pai(",alist[[ci]],ulist[[i]],alist[[di]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=p(",alist[[di]],")"]];
If[ib != emit[co] && ib != spec[co] ,Print["ptil(",co,",",ib,")=kj(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,alist[[ci]],ulist[[i]]];
                    ],{di,1,2}]
                  ,{i,1,nu}]
                ],{ci,1,2}]


(* Dipole 4 *)


dipole4:=Module[{}, 
     Print["-------------------------------------------------------------------------"];
     Print["Dipole 4"];
     Print["{Splitting (7):(a,i)=(g,f) or (g,fbar)}"];
       If[nu >= 1, If[ FreeQ[skipdipole,4u],showB4u;dipole4guDk;dipole4gub,
                                                        Print["Dipole 4u is skipped"]]];
       If[nubar >= 1, If[ FreeQ[skipdipole,4ubar],showB4ubar;dipole4gubarDk;dipole4gubarb,
                                                        Print["Dipole 4ubar is skipped"]]];
       If[nd >= 1, If[ FreeQ[skipdipole,4d],showB4d;dipole4gdDk;dipole4gdb,
                                                        Print["Dipole 4d is skipped"]]];
       If[ndbar >= 1, If[ FreeQ[skipdipole,4dbar],showB4dbar;dipole4gdbarDk;dipole4gdbarb,
                                                        Print["Dipole 4dbar is skipped"]]];
       If[ns >= 1, If[ FreeQ[skipdipole,4s],showB4s;dipole4gsDk;dipole4gsb,
                                                        Print["Dipole 4s is skipped"]]];
       If[nsbar >= 1, If[ FreeQ[skipdipole,4sbar],showB4sbar;dipole4gsbarDk;dipole4gsbarb,
                                                        Print["Dipole 4sbar is skipped"]]];
       If[nc >= 1, If[ FreeQ[skipdipole,4c],showB4c;dipole4gcDk;dipole4gcb,
                                                        Print["Dipole 4c is skipped"]]];
       If[ncbar >= 1, If[ FreeQ[skipdipole,4cbar],showB4cbar;dipole4gcbarDk;dipole4gcbarb,
                                                        Print["Dipole 4cbar is skipped"]]];
       If[nb >= 1 && massiveb == 0, If[ FreeQ[skipdipole,4b],showB4b;dipole4gbDk;dipole4gbb,
                                                        Print["Dipole 4b is skipped"]]];
       If[nbbar >= 1 && massiveb == 0, If[ FreeQ[skipdipole,4bbar],
                                                  showB4bbar;dipole4gbbarDk;dipole4gbbarb,
                                                        Print["Dipole 4bbar is skipped"]]];
     Print["*************************************************************************"];]


(* (a,i)=(g,u) splitting *)


showB4u:=Module[{},A4a1={};Do[If[i!=Last[ulist], AppendTo[A4a1,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a1in={ubar,A[2]}];If[A[2]==g,A4a1in={A[1],ubar}];
                          Print["M0=B4u: ",A4a1in," --> ", A4a1];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a1[ib]=Part[A4a1in,ib],{ib,1,2}];Do[V4a1[ib]=Part[A4a1,ib-2],{ib,3,nborn}];]


dipole4guDk:=Module[{},Print["[13.(ai,k)=(gu,k): D^ai,k]"];
dipole4gfDkcr[ulist,ubar,V4a1,nu,1,131];]


dipole4gub:=Module[{},If[lparton==2,Print["[14.(ai,b)=(gu,b): D^aib]"];
dipole4gfbcr[ulist,ubar,V4a1,nu,1,141];
]]


(* (a,i)=(g,ubar) splitting *)


showB4ubar:=Module[{},A4a2={};Do[If[i!=Last[ubarlist], AppendTo[A4a2,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a2in={u,A[2]}];If[A[2]==g,A4a2in={A[1],u}];
                          Print["M0=B4ubar: ",A4a2in," --> ", A4a2];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a2[ib]=Part[A4a2in,ib],{ib,1,2}];Do[V4a2[ib]=Part[A4a2,ib-2],{ib,3,nborn}];]


dipole4gubarDk:=Module[{},Print["[13-ubar.(ai,k)=(g ubar,k): D^ai,k]"];
dipole4gfDkcr[ubarlist,u,V4a2,nubar,2,132];]


dipole4gubarb:=Module[{},If[lparton==2,Print["[14-ubar.(ai,b)=(g ubar,b): D^aib]"];
dipole4gfbcr[ubarlist,u,V4a2,nubar,2,142];]]


(* (a,i)=(g,d) splitting *)


showB4d:=Module[{},A4a3={};Do[If[i!=Last[dlist], AppendTo[A4a3,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a3in={dbar,A[2]}];If[A[2]==g,A4a3in={A[1],dbar}];
                          Print["M0=B4d: ",A4a3in," --> ", A4a3];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a3[ib]=Part[A4a3in,ib],{ib,1,2}];Do[V4a3[ib]=Part[A4a3,ib-2],{ib,3,nborn}];]


dipole4gdDk:=Module[{},Print["[13-d.(ai,k)=(gd,k): D^ai,k]"];
dipole4gfDkcr[dlist,dbar,V4a3,nd,3,133];
]


dipole4gdb:=Module[{},If[lparton==2,Print["[14-d.(ai,b)=(gd,b): D^aib]"];
dipole4gfbcr[dlist,dbar,V4a3,nd,3,143];]]


(* (a,i)=(g,dbar) splitting *)


showB4dbar:=Module[{},A4a4={};Do[If[i!=Last[dbarlist], AppendTo[A4a4,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a4in={d,A[2]}];If[A[2]==g,A4a4in={A[1],d}];
                          Print["M0=B4dbar: ",A4a4in," --> ", A4a4];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a4[ib]=Part[A4a4in,ib],{ib,1,2}];Do[V4a4[ib]=Part[A4a4,ib-2],{ib,3,nborn}];]


dipole4gdbarDk:=Module[{},Print["[13-dbar.(ai,k)=(g dbar,k): D^ai,k]"];
dipole4gfDkcr[dbarlist,d,V4a4,ndbar,4,134];]


dipole4gdbarb:=Module[{},If[lparton==2,Print["[14-dbar.(ai,b)=(g dbar,b): D^aib]"];
dipole4gfbcr[dbarlist,d,V4a4,ndbar,4,144];]]


(* (a,i)=(g,s) splitting *)


showB4s:=Module[{},A4a5={};Do[If[i!=Last[slist], AppendTo[A4a5,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a5in={sbar,A[2]}];If[A[2]==g,A4a5in={A[1],sbar}];
                          Print["M0=B4s: ",A4a5in," --> ", A4a5];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a5[ib]=Part[A4a5in,ib],{ib,1,2}];Do[V4a5[ib]=Part[A4a5,ib-2],{ib,3,nborn}];]


dipole4gsDk:=Module[{},Print["[13.(ai,k)=(gs,k): D^ai,k]"];
dipole4gfDkcr[slist,sbar,V4a5,ns,5,135];]


dipole4gsb:=Module[{},If[lparton==2,Print["[14.(ai,b)=(gs,b): D^aib]"];
dipole4gfbcr[slist,sbar,V4a5,ns,5,145];
]]


(* (a,i)=(g,sbar) splitting *)


showB4sbar:=Module[{},A4a6={};Do[If[i!=Last[sbarlist], AppendTo[A4a6,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a6in={s,A[2]}];If[A[2]==g,A4a6in={A[1],s}];
                          Print["M0=B4sbar: ",A4a6in," --> ", A4a6];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a6[ib]=Part[A4a6in,ib],{ib,1,2}];Do[V4a6[ib]=Part[A4a6,ib-2],{ib,3,nborn}];]


dipole4gsbarDk:=Module[{},Print["[13-sbar.(ai,k)=(g sbar,k): D^ai,k]"];
dipole4gfDkcr[sbarlist,s,V4a6,nsbar,6,136];]


dipole4gsbarb:=Module[{},If[lparton==2,Print["[14-sbar.(ai,b)=(g sbar,b): D^aib]"];
dipole4gfbcr[sbarlist,s,V4a6,nsbar,6,146];]]


(* (a,i)=(g,c) splitting *)


showB4c:=Module[{},A4a7={};Do[If[i!=Last[clist], AppendTo[A4a7,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a7in={cbar,A[2]}];If[A[2]==g,A4a7in={A[1],cbar}];
                          Print["M0=B4c: ",A4a7in," --> ", A4a7];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a7[ib]=Part[A4a7in,ib],{ib,1,2}];Do[V4a7[ib]=Part[A4a7,ib-2],{ib,3,nborn}];]


dipole4gcDk:=Module[{},Print["[13.(ai,k)=(gc,k): D^ai,k]"];
dipole4gfDkcr[clist,cbar,V4a7,nc,7,137];]


dipole4gcb:=Module[{},If[lparton==2,Print["[14.(ai,b)=(gc,b): D^aib]"];
dipole4gfbcr[clist,cbar,V4a7,nc,7,147];
]]


(* (a,i)=(g,cbar) splitting *)


showB4cbar:=Module[{},A4a8={};Do[If[i!=Last[cbarlist], AppendTo[A4a8,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a8in={c,A[2]}];If[A[2]==g,A4a8in={A[1],c}];
                          Print["M0=B4cbar: ",A4a8in," --> ", A4a8];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a8[ib]=Part[A4a8in,ib],{ib,1,2}];Do[V4a8[ib]=Part[A4a8,ib-2],{ib,3,nborn}];]


dipole4gcbarDk:=Module[{},Print["[13-cbar.(ai,k)=(g cbar,k): D^ai,k]"];
dipole4gfDkcr[cbarlist,c,V4a8,ncbar,8,138];]


dipole4gcbarb:=Module[{},If[lparton==2,Print["[14-cbar.(ai,b)=(g cbar,b): D^aib]"];
dipole4gfbcr[cbarlist,c,V4a8,ncbar,8,148];]]


(* (a,i)=(g,b) splitting *)


showB4b:=Module[{},A4a9={};Do[If[i!=Last[blist], AppendTo[A4a9,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a9in={bbar,A[2]}];If[A[2]==g,A4a9in={A[1],bbar}];
                          Print["M0=B4b: ",A4a9in," --> ", A4a9];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a9[ib]=Part[A4a9in,ib],{ib,1,2}];Do[V4a9[ib]=Part[A4a9,ib-2],{ib,3,nborn}];]


dipole4gbDk:=Module[{},Print["[13-b.(ai,k)=(gb,k): D^ai,k]"];
dipole4gfDkcr[blist,bbar,V4a9,nb,9,139];]


dipole4gbb:=Module[{},If[lparton==2,Print["[14-b.(ai,b)=(gb,b): D^aib]"];
Print["Before dc[149]=",dc[149]];
dipole4gfbcr[blist,bbar,V4a9,nb,9,149];
Print["After dc[149]=",dc[149]];
]]


(* (a,i)=(g,bbar) splitting *)


showB4bbar:=Module[{},A4a10={};Do[If[i!=Last[bbarlist], AppendTo[A4a10,X[i]]],{i,1,nfinal}];
                          If[A[1]==g,A4a10in={b,A[2]}];If[A[2]==g,A4a10in={A[1],b}];
                          Print["M0=B4bbar: ",A4a10in," --> ", A4a10];
Print["Reduced momenta:     ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V4a10[ib]=Part[A4a10in,ib],{ib,1,2}];Do[V4a10[ib]=Part[A4a10,ib-2],{ib,3,nborn}];]


dipole4gbbarDk:=Module[{},Print["[13-bbar.(ai,k)=(g bbar,k): D^ai,k]"];
dipole4gfDkcr[bbarlist,b,V4a10,nbbar,10,140];]


dipole4gbbarb:=Module[{},If[lparton==2,Print["[14-bbar.(ai,b)=(g bbar,b): D^aib]"];
dipole4gfbcr[bbarlist,b,V4a10,nbbar,10,150];]]


(* Module for dipole 4.(ai)=(gf)*)


dipole4gfDkcr[ulist_,ubar_,V4a1_,nu_,special_,cnum_]:=
             Do[If[A[ci]===g,
                 Do[
                   Do[If[k != ulist[[i]] && FreeQ[others,X[k]], 
         co=co+1;speciesdip4[co]=special;Print[" "];Print["--Dip(",co,")--"];
  If[M[k]==0,
   dc[cnum]=dc[cnum]+1;
   Print["DaiDkgfDk(",alist[[ci]],ulist[[i]],k,")=",
                               DaiDkgfDk[alist[[ci]],ulist[[i]],k]];
   Print["     pai(",alist[[ci]],ulist[[i]],k,")=",pai[alist[[ci]],ulist[[i]],k]];
   Print["     pk(",alist[[ci]],ulist[[i]],k,")=",paikk[alist[[ci]],ulist[[i]],k]];

      dip[co]=DaiDkgfDk[alist[[ci]],ulist[[i]],k];
      dipS[co]=DaiDkgfDk[alist[[ci]],ulist[[i]],k]/.
                      replist1[alist[[ci]],ulist[[i]],k]//Simplify;

      pemR[co]=pai[alist[[ci]],ulist[[i]],k];
      pemS[co]=pai[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
      pemS[co]=pemS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],     
                                p[k]->p[r,k+2]}//Simplify;

      pspR[co]=paikk[alist[[ci]],ulist[[i]],k];  
      pspS[co]=paikk[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
      pspS[co]=pspS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],     
                                p[k]->p[r,k+2]}//Simplify;

   ];
  If[MemberQ[masses,M[k]],
   dMc[cnum]=dMc[cnum]+1;
   Print["DMaiDkguDk(",alist[[ci]],ulist[[i]],k,")=",
                               DMaiDkgfDk[alist[[ci]],ulist[[i]],k]];
   Print["     pMai(",alist[[ci]],ulist[[i]],k,")=",pai[alist[[ci]],ulist[[i]],k]];
   Print["     pMk(",alist[[ci]],ulist[[i]],k,")=",paikk[alist[[ci]],ulist[[i]],k]];

      dip[co]=DMaiDkgfDk[alist[[ci]],ulist[[i]],k];
      dipS[co]=DMaiDkgfDk[alist[[ci]],ulist[[i]],k]/.
                      replist1[alist[[ci]],ulist[[i]],k]//Simplify;

      pemR[co]=pai[alist[[ci]],ulist[[i]],k];
      pemS[co]=pai[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
      pemS[co]=pemS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],     
                                p[k]->p[r,k+2]}//Simplify;

      pspR[co]=paikk[alist[[ci]],ulist[[i]],k];  
      pspS[co]=paikk[alist[[ci]],ulist[[i]],k]/.replist1[alist[[ci]],ulist[[i]],k]//Simplify;
      pspS[co]=pspS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],     
                                p[k]->p[r,k+2]}//Simplify;
   ];


Do[If[V4a1[ib]==ubar,emit[co]=ib;Break[]],{ib,1,2}];
Do[If[V4a1[ib]==X[k],spec[co]=ib;Break[]],{ib,3,nborn}];
Do[
If[ib != emit[co]\[NonBreakingSpace]&& ci==1,cor[co,ib]=b];
If[ib != emit[co]\[NonBreakingSpace]&& ci==2,cor[co,ib]=a];
,{ib,1,2}];
templist={};
Do[
  If[ib != spec[co],
    Do[
      If[io != ulist[[i]] && io !=k && FreeQ[templist,io],
        If[V4a1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pai(",alist[[ci]],ulist[[i]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",alist[[ci]],ulist[[i]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,alist[[ci]],ulist[[i]]];
                    ],{k,1,nfinal}]
                  ,{i,1,nu}]
                ],{ci,1,2}]


dipole4gfbcr[ulist_,ubar_,V4a1_,nu_,special_,cnum_]:=
             Do[If[A[ci]===g,
                 Do[
                   Do[If[di != ci,
         co=co+1;dinin[co]=1;speciesdip4[co]=special;Print[" "];Print["--Dip(",co,")--"];


Print["Daibgfb(",alist[[ci]],ulist[[i]],alist[[di]],")=",
                               Daibgfb[alist[[ci]],ulist[[i]],alist[[di]]]];


Print["     pai(",alist[[ci]],ulist[[i]],alist[[di]],")=",paibai[alist[[ci]],ulist[[i]],alist[[di]]]];
Do[If[j != ulist[[i]], 
Print["     ptil(",j,alist[[ci]],ulist[[i]],alist[[di]],")=",ptil[j,alist[[ci]],ulist[[i]],
alist[[di]]] ] ],{j,1,nfinal}];
dc[cnum]=dc[cnum]+1;
Print["I am in dipole4gfbcr co=",co,"cnum=",cnum];

      dip[co]=Daibgfb[alist[[ci]],ulist[[i]],alist[[di]]];
      dipS[co]=Daibgfb[alist[[ci]],ulist[[i]],alist[[di]]]/.replist1[alist[[ci]],ulist[[i]],
                                                        alist[[di]]]//Simplify;

      pemR[co]=paibai[alist[[ci]],ulist[[i]],alist[[di]]];
      pemS[co]=paibai[alist[[ci]],ulist[[i]],alist[[di]]]/.replist1[alist[[ci]],ulist[[i]],
            alist[[di]]]//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)
      pemS[co]=pemS[co]/.{p[alist[[ci]]]->p[r,ci],p[ulist[[i]]]->p[r,ulist[[i]]+2],
            p[alist[[di]]]->p[r,di]}//Simplify;
      (*Print["pemS(",co,")=",pemS[co]];*)

      Do[If[j != ulist[[i]],
        ktilR[j,co]=ptil[j,alist[[ci]],ulist[[i]],alist[[di]]];
        ktilS[j,co]=ptil[j,alist[[ci]],ulist[[i]],alist[[di]]]/.replist1[alist[[ci]],
            ulist[[i]],alist[[di]]]//Simplify;
        Do[
          Do[If[r2!=r1,
          ktilS[j,co]=ktilS[j,co]/.{p[r1].p[r2]->t[r1,r2],p[r2].p[r1]->t[r1,r2]}]
          ,{r2,1,nfinal}];
        ,{r1,1,nfinal}]; 
        Do[ktilS[j,co]=ktilS[j,co]/.{p[a].p[j]->t[a,j],p[l].p[a]->t[a,l]},{l,1,nfinal}];
        Do[ktilS[j,co]=ktilS[j,co]/.{p[b].p[j]->t[b,j],p[l].p[b]->t[b,l]},{l,1,nfinal}];

        ktilS[j,co]=ktilS[j,co]/.{p[j]->p[r,j+2],p[ulist[[i]]]->p[r,ulist[[i]]+2]}//Simplify;
        ktilS[j,co]=ktilS[j,co]/.{p[alist[[ci]]]->p[r,ci],p[alist[[di]]]->p[r,di]}//Simplify;
         Print["ktilS(",j,",",co,")=",ktilS[j,co]];
      ],{j,1,nfinal}];

templist={};
Do[If[V4a1[ib]==ubar,emit[co]=ib;Break[]],{ib,1,2}];
Do[If[ib2 != emit[co],spec[co]=ib2;cor[co,ib2]=alist[[di]];Break[]],{ib2,1,2}];
Do[
    Do[
      If[io != ulist[[i]]  && FreeQ[templist,io],
        If[V4a1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pai(",alist[[ci]],ulist[[i]],alist[[di]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=p(",alist[[di]],")"]];
If[ib != emit[co] && ib != spec[co] ,Print["ptil(",co,",",ib,")=kj(",cor[co,ib],")"]];
,{ib,1,nborn}];
    collinearset[co,alist[[ci]],ulist[[i]]];
                    ],{di,1,2}]
                  ,{i,1,nu}]
                ],{ci,1,2}]


(* Dipole SUSY *)


dipoleSUSY:=Module[{}, 
     Print["-------------------------------------------------------------------------"];
     Print["Dipole SUSY"];showB1SUSY;dipolesusy1;dipolesusy2;
     Print["*************************************************************************"];]


showB1SUSY:=Module[{},A1={};Do[If[i!=Last[glist],AppendTo[A1,X[i]]],
                 {i,1,nfinal}];Print["M0=B1:           ",{A[1],A[2]}," --> ", A1];
Print["Reduced momenta: ",{ptil[1],ptil[2]}," --> ",rmom];
Do[V1[ib]=Part[A1,ib-2],{ib,3,nborn}];
]


dipolesusy1:=Module[{},Print["{Splitting SUSY(1):(i,j)=(squark,g)}"];
Print["[SUSY1.(ij,k)=(squark,g,k): Dij,k]"];dipolesusy1kcr;
Print["[SUSY2.(ij,a)=(squark,g,a): Dij^a]"];dipolesusy1acr;]


(*[SUSY1.(ij,k)=(squark,g,k): Dij,k]*)


dipolesusy1kcr:=Do[
                 Do[If[MemberQ[squarks,X[i]],
                   Do[If[k != glist[[j]] && k!=i && FreeQ[others,X[k]],
         co=co+1;
Print[" "];
Print["--Dip(",co,")--"];
   If[MemberQ[masses,M[i]],
         dMSUSYc[1]=dMSUSYc[1]+1;
         Print["DMSijksfgk(",i,glist[[j]],k,")=",DMSijksfgk[i,glist[[j]],k]];
         Print["     pMij1(",i,glist[[j]],k,")=",pMij1[i,glist[[j]],k]];
         Print["     pMk1(",i,glist[[j]],k,")=",pMk1[i,glist[[j]],k]];

         dip[co]=DMSijksfgk[i,glist[[j]],k];
         dipS[co]=DMSijksfgk[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;

         pemR[co]=pMij1[i,glist[[j]],k];
         pemS[co]=pMij1[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[i,glist[[j]],k]//Simplify;

         pspR[co]=pMk1[i,glist[[j]],k];
         pspS[co]=pMk1[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[i,glist[[j]],k]//Simplify;
      ];
Do[If[V1[ib]==X[i],emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V1[ib]==X[k],spec[co]=ib;Break[]];,{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != i && io != glist[[j]] && io != k && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
   ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",i,glist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",i,glist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
collinearset[co,i,glist[[j]]];
                    ],{k,1,nfinal}]
                  ],{i,1,nfinal}]
              ,{j,1,ng}]


(*[SUSY2.(ij,a)=(squark,g,a): Dij^a]*)


dipolesusy1acr:=Do[
                Do[If[MemberQ[squarks,X[i]],
                 Do[If[MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;Print[" "];Print["--Dip(",co,")--"];
  If[MemberQ[masses,M[i]],
         dMSUSYc[2]=dMSUSYc[2]+1;
         Print["DMSijasfga(",i,glist[[j]],alist[[c]],")=",DMSijasfga[i,glist[[j]],alist[[c]]]];
         Print["     pMij2(",i,glist[[j]],alist[[c]],")=",pija[i,glist[[j]],alist[[c]]]];
         Print["     pMa2(",i,glist[[j]],alist[[c]],")=",pa[i,glist[[j]],alist[[c]]]];

         dip[co]=DMSijasfga[i,glist[[j]],alist[[c]]];
         dipS[co]=DMSijasfga[i,glist[[j]],alist[[c]]]/.
                                           replist1[i,glist[[j]],alist[[c]]]//Simplify;

         pemR[co]=pija[i,glist[[j]],alist[[c]]];
         pemS[co]=pija[i,glist[[j]],alist[[c]]]/.replist1[i,glist[[j]],alist[[c]]]//Simplify;
         pemS[co]=pemS[co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2],
                                         p[alist[[c]]]->p[r,c]}//Simplify;

         pspR[co]=pija[i,glist[[j]],alist[[c]]];
         pspS[co]=pa[i,glist[[j]],alist[[c]]]/.replist1[i,glist[[j]],alist[[c]]]//Simplify;
         pspS[co]=pspS[co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2],
                         p[alist[[c]]]->p[r,c]}//Simplify;
     ];
spec[co]=c;
Do[If[V1[ib]==X[i],emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != i && io != glist[[j]] && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",i,glist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",i,glist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
collinearset[co,i,glist[[j]]];
                    ],{c,1,2}]
                  ],{i,1,nfinal}]
              ,{j,1,ng}]


dipolesusy2:=Module[{},If[ng >= 1,Print["{Splitting SUSY(2):(i,j)=(gluino,g)}"];
Print["[SUSY3.(ij,k)=(gluino,g,k): Dij,k]"];dipolesusy2kcr;
Print["[SUSY4.(ij,a)=(gluino,g,a): Dij^a]"];dipolesusy2acr;]]


(*[SUSY3.(ij,k)=(gluino,g,k): Dij,k]*)


dipolesusy2kcr:=Do[
                 Do[If[ X[i]=== sg,
                   Do[If[k != glist[[j]] && k!=i && FreeQ[others,X[k]],
         co=co+1;
Print[" "];
Print["--Dip(",co,")--"];
         dMSUSYc[3]=dMSUSYc[3]+1;
         Print["DMSijkgluinogk(",i,glist[[j]],k,")=",DMijkfgk[i,glist[[j]],k]];
         Print["     pMij1(",i,glist[[j]],k,")=",pMij1[i,glist[[j]],k]];
         Print["     pMk1(",i,glist[[j]],k,")=",pMk1[i,glist[[j]],k]];

         dip[co]=DMijkfgk[i,glist[[j]],k];
         dipS[co]=DMijkfgk[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;

         pemR[co]=pMij1[i,glist[[j]],k];
         pemS[co]=pMij1[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;
         pemS[co]=pemS[co]/.repmom[i,glist[[j]],k]//Simplify;

         pspR[co]=pMk1[i,glist[[j]],k];
         pspS[co]=pMk1[i,glist[[j]],k]/.replist1[i,glist[[j]],k]//Simplify;
         pspS[co]=pspS[co]/.repmom[i,glist[[j]],k]//Simplify;

Do[If[V1[ib]==X[i],emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != emit[co] && V1[ib]==X[k],spec[co]=ib;Break[]];,{ib,3,nborn}];
cor[co,1]=a;cor[co,2]=b;
templist={};
Do[
  If[ib != emit[co] && ib!= spec[co],
    Do[
      If[io != i && io != glist[[j]] && io != k && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
   ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",i,glist[[j]],k,")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pk(",i,glist[[j]],k,")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
collinearset[co,i,glist[[j]]];
                    ],{k,1,nfinal}]
                  ],{i,1,nfinal}]
              ,{j,1,ng}]


(*[SUSY4.(ij,a)=(gluino,g,a): Dij^a]*)


dipolesusy2acr:=Do[
                Do[If[ X[i]=== sg,
                 Do[If[MemberQ[zquark,A[c]] || A[c] === g,
         co=co+1;Print[" "];Print["--Dip(",co,")--"];

         dMSUSYc[2]=dMSUSYc[2]+1;
         Print["DMSijbgluinogb(",i,glist[[j]],alist[[c]],")=",DMijUafgUa[i,glist[[j]],alist[[c]]]];
         Print["     pMij2(",i,glist[[j]],alist[[c]],")=",pija[i,glist[[j]],alist[[c]]]];
         Print["     pMa2(",i,glist[[j]],alist[[c]],")=",pa[i,glist[[j]],alist[[c]]]];

         dip[co]=DMijUafgUa[i,glist[[j]],alist[[c]]];
         dipS[co]=DMijUafgUa[i,glist[[j]],alist[[c]]]/.
                                           replist1[i,glist[[j]],alist[[c]]]//Simplify;

         pemR[co]=pija[i,glist[[j]],alist[[c]]];
         pemS[co]=pija[i,glist[[j]],alist[[c]]]/.replist1[i,glist[[j]],alist[[c]]]//Simplify;
         (*Print["pemS(",co,")=",pemS[co]];*)
         pemS[co]=pemS[co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2],
                                         p[alist[[c]]]->p[r,c]}//Simplify;
         (*Print["pemS(",co,")=",pemS[co]];*)

         pspR[co]=pija[i,glist[[j]],alist[[c]]];
         pspS[co]=pa[i,glist[[j]],alist[[c]]]/.replist1[i,glist[[j]],alist[[c]]]//Simplify;
         (*Print["pspS(",co,")=",pspS[co]];*)
         pspS[co]=pspS[co]/.{p[i]->p[r,i+2],p[glist[[j]]]->p[r,glist[[j]]+2],
                         p[alist[[c]]]->p[r,c]}//Simplify;
         (*Print["pspS(",co,")=",pspS[co]];*)

spec[co]=c;
Do[If[V1[ib]==X[i],emit[co]=ib;Break[]],{ib,3,nborn}];
Do[If[ib != spec[co],cor[co,ib]=alist[[ib]];Break[]],{ib,1,2}];
templist={};
Do[
  If[ib != emit[co],
    Do[
      If[io != i && io != glist[[j]] && FreeQ[templist,io],
        If[V1[ib]==X[io],cor[co,ib]=io;AppendTo[templist,{io}];Break[]]
      ]
    ,{io,1,nfinal}]
   ]
,{ib,3,nborn}];
Do[
If[ib==emit[co],Print["ptil(",co,",",ib,")=pij(",i,glist[[j]],alist[[c]],")"]];
If[ib==spec[co],Print["ptil(",co,",",ib,")=pa(",i,glist[[j]],alist[[c]],")"]];
If[ib != emit[co] && ib!= spec[co],Print["ptil(",co,",",ib,")=p(",cor[co,ib],")"]];
,{ib,1,nborn}];
collinearset[co,i,glist[[j]]];

                    ],{c,1,2}]
                  ],{i,1,nfinal}]
              ,{j,1,ng}]


(* Here is end of each dipole creation *)


dicount:=Module[{},disums;diprint;]


disums:=Module[{},
(* Sum of massless and massive dipoles *)
Do[ds[n]=dc[n]+dMc[n];,{n,1,200}];
(* Sum of dipoles in each splitting *)
dss[1]=ds[1]+ds[2];dss[2]=ds[3]+ds[4];dss[3]=ds[5]+ds[6];dss[4]=ds[7]+ds[8];

dss[51]=ds[91]+ds[101];dss[53]=ds[93]+ds[103];
dss[54]=ds[94]+ds[104];dss[55]=ds[95]+ds[105];
dss[57]=ds[97]+ds[107];dss[58]=ds[98]+ds[108];

dss[61]=ds[111]+ds[121];dss[62]=ds[112]+ds[122];
dss[63]=ds[113]+ds[123];dss[64]=ds[114]+ds[124];
dss[65]=ds[115]+ds[125];dss[66]=ds[116]+ds[126];
dss[67]=ds[117]+ds[127];dss[68]=ds[118]+ds[128];
dss[69]=ds[119]+ds[129];dss[70]=ds[120]+ds[130];

dss[71]=ds[131]+ds[141];dss[72]=ds[132]+ds[142];
dss[73]=ds[133]+ds[143];dss[74]=ds[134]+ds[144];
dss[75]=ds[135]+ds[145];dss[76]=ds[136]+ds[146];
dss[77]=ds[137]+ds[147];dss[78]=ds[138]+ds[148];
dss[79]=ds[139]+ds[149];dss[80]=ds[140]+ds[150];

(* Sum of massive dipoles in each splitting *)
dMss[1]=dMc[1]+dMc[2];dMss[2]=dMc[3]+dMc[4];dMss[3]=dMc[5]+dMc[6];dMss[4]=dMc[7]+dMc[8];

dMss[51]=dMc[91]+dMc[101];dMss[53]=dMc[93]+dMc[103];
dMss[54]=dMc[94]+dMc[104];dMss[55]=dMc[95]+dMc[105];
dMss[57]=dMc[97]+dMc[107];dMss[58]=dMc[98]+dMc[108];

dMss[61]=dMc[111]+dMc[121];dMss[62]=dMc[112]+dMc[122];
dMss[63]=dMc[113]+dMc[123];dMss[64]=dMc[114]+dMc[124];
dMss[65]=dMc[115]+dMc[125];dMss[66]=dMc[116]+dMc[126];
dMss[67]=dMc[117]+dMc[127];dMss[68]=dMc[118]+dMc[128];
dMss[69]=dMc[119]+dMc[129];dMss[70]=dMc[120]+dMc[130];

dMss[71]=dMc[131]+dMc[141];dMss[72]=dMc[132]+dMc[142];
dMss[73]=dMc[133]+dMc[143];dMss[74]=dMc[134]+dMc[144];
dMss[75]=dMc[135]+dMc[145];dMss[76]=dMc[136]+dMc[146];
dMss[77]=dMc[137]+dMc[147];dMss[78]=dMc[138]+dMc[148];
dMss[79]=dMc[139]+dMc[149];dMss[80]=dMc[140]+dMc[150];

(* Sum of dipoles A, B, C, D *)
dAs=0;dBs=0;dCs=0;dDs=0;
dAs=dss[1]+dss[2]+dss[3]+dss[4];
dBs=dss[51]+dss[53]+dss[54]+dss[55]+dss[57]+dss[58];
dCs=dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66]+dss[67]+dss[68]+dss[69]+dss[70];
dDs=dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76]+dss[77]+dss[78]+dss[79]+dss[80];
dAstotal=dAs;
(* Sum of massive dipoles A, B, C, D *)
dMAs=0;dMBs=0;dMCs=0;dMDs=0;
dMAs=dMss[1]+dMss[2]+dMss[3]+dMss[4];
dMBs=dMss[51]+dMss[53]+dMss[54]+dMss[55]+dMss[57]+dMss[58];
dMCs=dMss[61]+dMss[62]+dMss[63]+dMss[64]+dMss[65]+dMss[66]+dMss[67]+dMss[68]+dMss[69]+dMss[70];
dMDs=dMss[71]+dMss[72]+dMss[73]+dMss[74]+dMss[75]+dMss[76]+dMss[77]+dMss[78]+dMss[79]+dMss[80];
(* Sum of all dipoles *)
dtotal=0;dtotal=dAs+dBs+dCs+dDs;
dMtotal=0;dMtotal=dMAs+dMBs+dMCs+dMDs;
(* Separation counter*)
Do[
sepD1final[j]=0;
sepD1initial[j]=0;
sepD3u[j]=0;
sepD3ubar[j]=0;
sepD3d[j]=0;
sepD3dbar[j]=0;
sepD3s[j]=0;
sepD3sbar[j]=0;
sepD3c[j]=0;
sepD3cbar[j]=0;
sepD3b[j]=0;
sepD3bbar[j]=0;
sepD4u[j]=0;
sepD4ubar[j]=0;
sepD4d[j]=0;
sepD4dbar[j]=0;
sepD4s[j]=0;
sepD4sbar[j]=0;
sepD4c[j]=0;
sepD4cbar[j]=0;
sepD4b[j]=0;
sepD4bbar[j]=0;
,{j,1,2}];
Do[Do[emitlist[i,j]={};,{j,1,4}];,{i,3,4}];

If[ dss[1]+dss[2] >=1,
sepD1final[1]=1;
sepD1final[2]=dss[1]+dss[2];
];
If[ dss[3]+dss[4] >=1,
sepD1initial[1]=dss[1]+dss[2]+1;
sepD1initial[2]=dAs;
];
temp3=dAs+dBs;
If[ dss[61] >=1,
sepD3u[1]=temp3+1;
sepD3u[2]=temp3+dss[61];
];
If[ dss[62] >=1,
sepD3ubar[1]=temp3+dss[61]+1;
sepD3ubar[2]=temp3+dss[61]+dss[62];
];
If[ dss[63] >=1,
sepD3d[1]=temp3+dss[61]+dss[62]+1;
sepD3d[2]=temp3+dss[61]+dss[62]+dss[63];
];
If[ dss[64] >=1,
sepD3dbar[1]=temp3+dss[61]+dss[62]+dss[63]+1;
sepD3dbar[2]=temp3+dss[61]+dss[62]+dss[63]+dss[64];
];
If[ dss[65] >=1,
sepD3s[1]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+1;
sepD3s[2]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65];
];
If[ dss[66] >=1,
sepD3sbar[1]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+1;
sepD3sbar[2]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66];
];
If[ dss[67] >=1,
sepD3c[1]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66]+1;
sepD3c[2]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66]+dss[67];
];
If[ dss[68] >=1,
sepD3cbar[1]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66]+dss[67]+1;
sepD3cbar[2]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66]+dss[67]+dss[68];
];
If[ dss[69] >=1,
sepD3b[1]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66]+dss[67]+dss[68]+1;
sepD3b[2]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66]+dss[67]+dss[68]+dss[69];
];
If[ dss[70] >=1,
sepD3bbar[1]=temp3+dss[61]+dss[62]+dss[63]+dss[64]+dss[65]+dss[66]+dss[67]+dss[68]+dss[69]+1;
sepD3bbar[2]=temp3+dCs;
];

temp4=dAs+dBs+dCs;
If[ dss[71] >=1,
sepD4u[1]=temp4+1;
sepD4u[2]=temp4+dss[71];
];
If[ dss[72] >=1,
sepD4ubar[1]=temp4+dss[71]+1;
sepD4ubar[2]=temp4+dss[71]+dss[72];
];
If[ dss[73] >=1,
sepD4d[1]=temp4+dss[71]+dss[72]+1;
sepD4d[2]=temp4+dss[71]+dss[72]+dss[73];
];
If[ dss[74] >=1,
sepD4dbar[1]=temp4+dss[71]+dss[72]+dss[73]+1;
sepD4dbar[2]=temp4+dss[71]+dss[72]+dss[73]+dss[74];
];
If[ dss[75] >=1,
sepD4s[1]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+1;
sepD4s[2]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75];
];
If[ dss[76] >=1,
sepD4sbar[1]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+1;
sepD4sbar[2]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76];
];
If[ dss[77] >=1,
sepD4c[1]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76]+1;
sepD4c[2]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76]+dss[77];
];
If[ dss[78] >=1,
sepD4cbar[1]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76]+dss[77]+1;
sepD4cbar[2]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76]+dss[77]+dss[78];
];
If[ dss[79] >=1,
sepD4b[1]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76]+dss[77]+dss[78]+1;
sepD4b[2]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76]+dss[77]+dss[78]+dss[79];
];
If[ dss[80] >=1,
sepD4bbar[1]=temp4+dss[71]+dss[72]+dss[73]+dss[74]+dss[75]+dss[76]+dss[77]+dss[78]+dss[79]+1;
sepD4bbar[2]=temp4+dDs;
];
]


makeemitlist[split_,flaver_,initial_,final_]:=Module[{},
Do[AppendTo[emitlist[split,flaver],emit[i]],{i,initial,final}];
emitlist[split,flaver]=Union[emitlist[split,flaver]];
]


diprint:=Module[{},Print["Number of dipoles"];
 (* Dipole 1*)
       If[ng >= 1, Print["[Dipole1] : ",dAs];
Print[" B1 : ",dAs];
Print["{Splitting (1):(i,j)=(f,g)}:  ", dss[1], " (", dMss[1],")"];
Print["               [1.(ij,k)=(fg,k): Dij,k]  ", ds[1], " (", dMc[1],")"];
Print["               [2.(ij,a)=(fg,a): Dij^a]  ", ds[2], " (", dMc[2],")"];
Print["{Splitting (2):(i,j)=(g,g)}:  ", dss[2]," (", dMss[2],")"];
Print["               [3.(ij,k)=(gg,k): Dij,k]  ", ds[3], " (", dMc[3],")"];
Print["               [4.(ij,a)=(gg,a): Dij^a]  ", ds[4], " (", dMc[4],")"];
Print["{Splitting (3):(a,i)=(f,g)}:  ", dss[3]," (", dMss[3],")"];
Print["               [5.(ai,k)=(fg,k): D^ai,k]  ", ds[5], " (", dMc[5],")"];
Print["               [6.(ai,b)=(fg,b): D^ai,b]  ", ds[6], " (", dMc[6],")"];
Print["{Splitting (4):(a,i)=(g,g)}:  ", dss[4]," (", dMss[4],")"];
Print["               [7.(ai,k)=(gg,k): D^ai,k]  ", ds[7], " (", dMc[7],")"];
Print["               [8.(ai,b)=(gg,b): D^ai,b]  ", ds[8], " (", dMc[8],")"];
Print["-------------------"];
         ];
 (* Dipole 2*)
       If[(nu >= 1 && nubar >= 1) || (nd >= 1 && ndbar >= 1)||
          (ns >= 1 && nsbar >= 1) || (nc >= 1 && ncbar >= 1)||
          (nb >= 1 && nbbar >= 1) || (nt >= 1 && ntbar >= 1),Print["[Dipole2] : ",dBs];
Print["{Splitting (5):(i,j)=(f,fbar)}"];
Print["  (u-ubar splitting) B2u : ",dss[51]];
Print["               [9-u.(ij,k)=(u ubar,k): Dij,k]  ", ds[91], " (", dMc[91],")"];
Print["               [10-u.(ij,a)=(u ubar,a): Dij^a]  ", ds[101], " (", dMc[101],")"];
Print["  (d-dbar splitting) B2d : ",dss[53]];
Print["               [9-d.(ij,k)=(u ubar,k): Dij,k]  ", ds[93], " (", dMc[93],")"];
Print["               [10-d.(ij,a)=(u ubar,a): Dij^a]  ", ds[103], " (", dMc[103],")"];
Print["  (s-sbar splitting) B2s : ",dss[54]];
Print["               [9-s.(ij,k)=(s sbar,k): Dij,k]  ", ds[94], " (", dMc[94],")"];
Print["               [10-s.(ij,a)=(s sbar,a): Dij^a]  ", ds[104], " (", dMc[104],")"];
Print["  (c-cbar splitting) B2c : ",dss[55]];
Print["               [9-c.(ij,k)=(c cbar,k): Dij,k]  ", ds[95], " (", dMc[95],")"];
Print["               [10-c.(ij,a)=(c cbar,a): Dij^a]  ", ds[105], " (", dMc[105],")"];
Print["  (b-bbar splitting) B2b : ",dss[57]];
Print["               [9-b.(ij,k)=(u ubar,k): Dij,k]  ", ds[97], " (", dMc[97],")"];
Print["               [10-b.(ij,a)=(u ubar,a): Dij^a]  ", ds[107], " (", dMc[107],")"];
Print["  (t-tbar splitting) B2t : ",dss[58]];
Print["               [9-t.(ij,k)=(u ubar,k): Dij,k]  ", ds[98], " (", dMc[98],")"];
Print["               [10-t.(ij,a)=(u ubar,a): Dij^a]  ", ds[108], " (", dMc[108],")"];
Print["-------------------"];
         ];
 (* Dipole 3*)
       If[(lu >= 1 && nu >= 1) || (lubar >= 1 && nubar >= 1) || 
          (ld >= 1 && nd >= 1) || (ldbar >= 1 && ndbar >= 1) ||
          (lc >= 1 && nc >= 1) || (lcbar >= 1 && ncbar >= 1) ||
          (ls >= 1 && ns >= 1) || (lsbar >= 1 && nsbar >= 1) ||
          (lb >= 1 && nb >= 1) || (lbbar >= 1 && nbbar >= 1) ,Print["[Dipole3] : ",dCs];
Print["{Splitting (6):(a,i)=(f,f) or (fbar,fbar)}"];
Print[" ((a,i)=(u,u) splitting)  B3u : ",dss[61]];
Print["               [11-u.(ai,k)=(uu,k): D^ai,k]  ", ds[111], " (", dMc[111],")"];
Print["               [12-u.(ai,b)=(uu,b): D^aib]  ", ds[121], " (", dMc[121],")"];
Print[" ((a,i)=(ubar,ubar) splitting)   B3ubar : ",dss[62]];
Print["               [11-ubar.(ai,k)=(ubar ubar,k): D^ai,k]  ", ds[112], " (", dMc[112],")"];
Print["               [12-ubar.(ai,b)=(ubar ubar,b): D^aib]  ", ds[122], " (", dMc[122],")"];
Print[" ((a,i)=(d,d) splitting) B3d : ",dss[63]];
Print["               [11-d.(ai,k)=(dd,k): D^ai,k]  ", ds[113], " (", dMc[113],")"];
Print["               [12-d.(ai,b)=(dd,b): D^aib]  ", ds[123], " (", dMc[123],")"];
Print[" ((a,i)=(dbar,dbar) splitting) B3dbar : ",dss[64]];
Print["               [11-dbar.(ai,k)=(dbar dbar,k): D^ai,k]  ", ds[114], " (", dMc[114],")"];
Print["               [12-dbar.(ai,b)=(dbar dbar,b): D^aib]  ", ds[124], " (", dMc[124],")"];
Print[" ((a,i)=(s,s) splitting)  B3s : ",dss[65]];
Print["               [11-s.(ai,k)=(ss,k): D^ai,k]  ", ds[115], " (", dMc[115],")"];
Print["               [12-s.(ai,b)=(ss,b): D^aib]  ", ds[125], " (", dMc[125],")"];
Print[" ((a,i)=(sbar,sbar) splitting)   B3sbar : ",dss[66]];
Print["               [11-sbar.(ai,k)=(sbar sbar,k): D^ai,k]  ", ds[116], " (", dMc[116],")"];
Print["               [12-sbar.(ai,b)=(sbar sbar,b): D^aib]  ", ds[126], " (", dMc[126],")"];
Print[" ((a,i)=(c,c) splitting)  B3c : ",dss[67]];
Print["               [11-c.(ai,k)=(cc,k): D^ai,k]  ", ds[117], " (", dMc[117],")"];
Print["               [12-c.(ai,b)=(cc,b): D^aib]  ", ds[127], " (", dMc[127],")"];
Print[" ((a,i)=(cbar,cbar) splitting)   B3cbar : ",dss[68]];
Print["               [11-cbar.(ai,k)=(cbar cbar,k): D^ai,k]  ", ds[118], " (", dMc[118],")"];
Print["               [12-cbar.(ai,b)=(cbar cbar,b): D^aib]  ", ds[128], " (", dMc[128],")"];
Print[" ((a,i)=(b,b) splitting)  B3b : ",dss[69]];
Print["               [11-b.(ai,k)=(bb,k): D^ai,k]  ", ds[119], " (", dMc[119],")"];
Print["               [12-b.(ai,b)=(bb,b): D^aib]  ", ds[129], " (", dMc[129],")"];
Print[" ((a,i)=(bbar,bbar) splitting)   B3bbar : ",dss[70]];
Print["               [11-bbar.(ai,k)=(bbar bbar,k): D^ai,k]  ", ds[120], " (", dMc[120],")"];
Print["               [12-bbar.(ai,b)=(bbar bbar,b): D^aib]  ", ds[130], " (", dMc[130],")"];
Print["-------------------"];
        ];
 (* Dipole 4*)
       If[ lg >= 1 && 
         (nu >= 1 || nubar >= 1 || nd >= 1 || ndbar >= 1 || 
          ns >= 1 || nsbar >= 1 || nc >= 1 || ncbar >= 1 || 
          nb >= 1 || nbbar >= 1),
       Print["[Dipole4] : ",dDs];
Print["{Splitting (7):(a,i)=(g,f) or (g,fbar)}"];
Print[" ((a,i)=(g,u) splitting)  B4u : ",dss[71]];
Print["               [13-u.(ai,k)=(gu,k): D^ai,k]  ", ds[131], " (", dMc[131],")"];
Print["               [14-u.(ai,b)=(gu,b): D^aib]  ", ds[141], " (", dMc[141],")"];
Print[" ((a,i)=(g,ubar) splitting)   B4ubar : ",dss[72]];
Print["               [13-ubar.(ai,k)=(g ubar,k): D^ai,k]  ", ds[132], " (", dMc[132],")"];
Print["               [14-ubar.(ai,b)=(g ubar,b): D^aib]  ", ds[142], " (", dMc[142],")"];
Print[" ((a,i)=(g,d) splitting) B4d : ",dss[73]];
Print["               [13-d.(ai,k)=(gd,k): D^ai,k]  ", ds[133], " (", dMc[133],")"];
Print["               [14-d.(ai,b)=(gd,b): D^aib]  ", ds[143], " (", dMc[143],")"];
Print[" ((a,i)=(g,dbar) splitting) B4dbar : ",dss[74]];
Print["               [13-dbar.(ai,k)=(g ubar,k): D^ai,k]  ", ds[134], " (", dMc[134],")"];
Print["               [14-dbar.(ai,b)=(g ubar,b): D^aib]  ", ds[144], " (", dMc[144],")"];
Print[" ((a,i)=(g,s) splitting)  B4s : ",dss[75]];
Print["               [13-s.(ai,k)=(gs,k): D^ai,k]  ", ds[135], " (", dMc[135],")"];
Print["               [14-s.(ai,b)=(gs,b): D^aib]  ", ds[145], " (", dMc[145],")"];
Print[" ((a,i)=(g,sbar) splitting)   B4sbar : ",dss[76]];
Print["               [13-sbar.(ai,k)=(g sbar,k): D^ai,k]  ", ds[136], " (", dMc[136],")"];
Print["               [14-sbar.(ai,b)=(g sbar,b): D^aib]  ", ds[146], " (", dMc[146],")"];
Print[" ((a,i)=(g,c) splitting)  B4c : ",dss[77]];
Print["               [13-c.(ai,k)=(gc,k): D^ai,k]  ", ds[137], " (", dMc[137],")"];
Print["               [14-c.(ai,b)=(gc,b): D^aib]  ", ds[147], " (", dMc[147],")"];
Print[" ((a,i)=(g,cbar) splitting)   B4cbar : ",dss[78]];
Print["               [13-cbar.(ai,k)=(g cbar,k): D^ai,k]  ", ds[138], " (", dMc[138],")"];
Print["               [14-cbar.(ai,b)=(g cbar,b): D^aib]  ", ds[148], " (", dMc[148],")"];
Print[" ((a,i)=(g,b) splitting)  B4b : ",dss[79]];
Print["               [13-b.(ai,k)=(gb,k): D^ai,k]  ", ds[139], " (", dMc[139],")"];
Print["               [14-b.(ai,b)=(gb,b): D^aib]  ", ds[149], " (", dMc[149],")"];
Print[" ((a,i)=(g,bbar) splitting)   B4bbar : ",dss[80]];
Print["               [13-bbar.(ai,k)=(g bbar,k): D^ai,k]  ", ds[140], " (", dMc[140],")"];
Print["               [14-bbar.(ai,b)=(g bbar,b): D^aib]  ", ds[150], " (", dMc[150],")"];
Print["-------------------"];
        ];
If[ model === mssm,
  If[ng >= 1,
   dMSUSYcsum[1]=dMSUSYc[1]+dMSUSYc[2];dMSUSYcsum[2]=dMSUSYc[3]+dMSUSYc[4];
   dAsSUSY=dMSUSYcsum[1]+dMSUSYcsum[2];
   Print["[SUSY Dipole] B1S: ",dAsSUSY];
   Print["{Splitting SUSY(1):(i,j)=(squark,g)}:  (", dMSUSYcsum[1],")"];
   Print["               [SUSY1.(ij,k)=(squark,g,k): Dij,k]  (", dMSUSYc[1],")"];
   Print["               [SUSY2.(ij,a)=(squark,g,a): Dij^a]  (", dMSUSYc[2],")"];
   Print["{Splitting SUSY(2):(i,j)=(gluino,g)}:  (", dMSUSYcsum[2],")"];
   Print["               [SUSY3.(ij,k)=(gluino,g,k): Dij,k]  (", dMSUSYc[3],")"];
   Print["               [SUSY4.(ij,a)=(gluino,g,a): Dij^a]  (", dMSUSYc[4],")"];
   Print["-------------------"];
   dsusyfinalbe=0;dsusyfinalfi=0;dsusyinitialbe=0;dsusyinitialfi=0;dtotalSM=dtotal;
   If[ dMSUSYcsum[1] >=1,dsusyfinalbe=dtotal+1;dsusyfinalfi=dtotal+dMSUSYcsum[1]];
   If[ dMSUSYcsum[2] >=1,dsusyinitialbe=dsusyfinalfi+1;dsusyinitialfi=dsusyfinalfi+dMSUSYcsum[2]];
   dtotal=dtotal+dAsSUSY;dAstotal=dAs+dAsSUSY;dMtotal=dMtotal+dAsSUSY];
];
 (* Total*)
If[dtotal==co,Print["[Total] : ",dtotal];,Print["Count error"];];
Print[" (Massive dipoles : ",dMtotal,")"];
If[ model === mssm,Print[" (SUSY dipoles : ",dAsSUSY,")"]];
Print["Dipole 1 final-emitter:    ",sepD1final[1],"-",sepD1final[2]];
Print["Dipole 1 initial-emitter:  ",sepD1initial[1],"-",sepD1initial[2]];
Print["Dipole 3u:                 ",sepD3u[1],"-",sepD3u[2]];
Print["Dipole 3ubar:              ",sepD3ubar[1],"-",sepD3ubar[2]];
Print["Dipole 3d:                 ",sepD3d[1],"-",sepD3d[2]];
Print["Dipole 3dbar:              ",sepD3dbar[1],"-",sepD3dbar[2]];
Print["Dipole 3s:                 ",sepD3s[1],"-",sepD3s[2]];
Print["Dipole 3sbar:              ",sepD3sbar[1],"-",sepD3sbar[2]];
Print["Dipole 3c:                 ",sepD3c[1],"-",sepD3c[2]];
Print["Dipole 3cbar:              ",sepD3cbar[1],"-",sepD3cbar[2]];
Print["Dipole 3b:                 ",sepD3b[1],"-",sepD3b[2]];
Print["Dipole 3bbar:              ",sepD3bbar[1],"-",sepD3bbar[2]];
Print["Dipole 4u:                 ",sepD4u[1],"-",sepD4u[2]];
Print["Dipole 4ubar:              ",sepD4ubar[1],"-",sepD4ubar[2]];
Print["Dipole 4d:                 ",sepD4d[1],"-",sepD4d[2]];
Print["Dipole 4dbar:              ",sepD4dbar[1],"-",sepD4dbar[2]];
Print["Dipole 4s:                 ",sepD4s[1],"-",sepD4s[2]];
Print["Dipole 4sbar:              ",sepD4sbar[1],"-",sepD4sbar[2]];
Print["Dipole 4c:                 ",sepD4c[1],"-",sepD4c[2]];
Print["Dipole 4cbar:              ",sepD4cbar[1],"-",sepD4cbar[2]];
Print["Dipole 4b:                 ",sepD4b[1],"-",sepD4b[2]];
Print["Dipole 4bbar:              ",sepD4bbar[1],"-",sepD4bbar[2]];
If[ model === mssm,
Print["SUSY Dipole final-emitter:    ",dsusyfinalbe,"-",dsusyfinalfi];
Print["SUSY Dipole initial-emitter:  ",dsusyinitialbe,"-",dsusyinitialfi];
];
Print["-------------------"];
Print["END"];
]


collprint:=Module[{},
Print["*************************************************************************"];
Print["The collinear and soft limits and the corresponding dipoles"];
tfinal2=Table[{X[i],p[i+2]},{i,1,nfinal}];
Print["NLO: ",{{A[1],p[1]},{A[2],p[2]}}," --> ", tfinal2];
Print["-------------------"];
Print["Collinear pairs       Corresponding dipoles"];
collinearall={};
Do[
If[FreeQ[collinearall,emitpair[jj]],
   AppendTo[collinearall,emitpair[jj]]
]
,{jj,1,dtotal}];
ncoll=Length[collinearall];
Do[collinear[kk]=Part[collinearall,kk],{kk,1,ncoll}];
Do[collineardipoles[kk]={},{kk,1,ncoll}];
Do[
 Do[
   If[collinear[kk]==emitpair[ii],AppendTo[collineardipoles[kk],ii]]
 ,{ii,1,dtotal}];
,{kk,1,ncoll}];
Do[
Print[kk,". ",collinear[kk],"              ",collineardipoles[kk]]
,{kk,1,ncoll}];
collinearmassive={};
Do[
 If[ Part[collinear[kk],1] >= 3,
  If[ MemberQ[masses,M[Part[collinear[kk],1]-2]] || MemberQ[masses,M[Part[collinear[kk],2]-2]],
  AppendTo[collinearmassive,kk] ]
 ];
 If[ Part[collinear[kk],1] <= 2 && MemberQ[masses,M[Part[collinear[kk],2]-2]],
  AppendTo[collinearmassive,kk] ];
,{kk,1,ncoll}];
If[Length[collinearmassive] >= 1,
 Print["Collinear pairs "];
 Do[
  Print[Part[collinearmassive,jj],". "]
  ,{jj,1,Length[collinearmassive]}];
 Print["include a massive quark"]
];
Print["-------------------"];
]


softprint:=Module[{},
nsoft=Length[glist];
Do[softassemble[i]={};softdipoles[i]={};,{i,1,nsoft}];
Do[
  Do[
   soft[i]=Part[glist,i]+2;
   If[MemberQ[collinear[k],soft[i]],
       AppendTo[softassemble[i],k];
       AppendTo[softdipoles[i],collineardipoles[k]]
     ]
   ,{k,1,ncoll}];
,{i,1,nsoft}];
Do[softdipoles[i]=Flatten[softdipoles[i]];
softdipoles[i]=Sort[softdipoles[i]];,{i,1,nsoft}];
Print["Soft gluon   Collinear assemble    Corresponding dipoles"];
Do[
Print[i,". {",soft[i],"}       ",softassemble[i],"         ",softdipoles[i]]
,{i,1,nsoft}];
Print["-------------------"];
Print["END"];
];


(* 3. Universal functions to be called *)


(* 3-1. Real part *)


(* Dipole 1 call *)


(* Splitting (1) (i,j)=(f,g) or (fbar,g) *)


(* [1.(ij,k)=(fg,k): Dij,k]  *)


Dijkfgk[i_,j_,k_]:=-(2*p[i].p[j])^(-1)*Vijkfgk[i,j,k]*B1[co]//Simplify


Vijkfgk[i_,j_,k_]:=8*Pi*MU^(2*ep)*AL*(2*(1-zi[i,j,k]*(1-yijk[i,j,k]))^(-1) 
                    -(1+zi[i,j,k])-ep*(1-zi[i,j,k]))//Simplify


     (* Massive case*)


DMijkfgk[i_,j_,k_]:=-(2*p[i].p[j])^(-1)*VMijkfgk[i,j,k]*B1[co]//Simplify


VMijkfgk[i_,j_,k_]:=8*Pi*MU^(2*ep)*AL*(
              2*(1-zi[i,j,k]*(1-yijk[i,j,k]))^(-1) 
              -vtildijk1[i,j,k]*(vijk[i,j,k])^(-1)*(1+zi[i,j,k]+M[i]^(2)*(p[i].p[j])^(-1) 
                                                        - ep*(1-zi[i,j,k])))//Simplify


vtildijk1[i_,j_,k_]:=Sqrt[lamb[Qsq[i,j,k],M[i]^2,M[k]^2]]/(2*s[i,j,k])


pMij1[i_,j_,k_]:=-(Sqrt[lamb[Qsq[i,j,k],M[i]^2,M[k]^2]]/Sqrt[lamb[Qsq[i,j,k],M[i]^2+
                  2*p[i].p[j],M[k]^2]])*
          (p[k] - (p[i].p[k] + p[j].p[k] + M[k]^2)/Qsq[i,j,k]*(p[i]+p[j]+p[k]))+
          ((M[i]^2 + s[i,j,k])/Qsq[i,j,k])*(p[i]+p[j]+p[k])//Simplify


pMk1[i_,j_,k_]:=p[i]+p[j]+p[k] - pMij1[i,j,k]//Simplify


(* [2.(ij,a)=(fg,a): Dij^a]  *)


DijUafgUa[i_,j_,a_]:=-(2*p[i].p[j])^(-1)*xija[i,j,a]^(-1)*VijUafgUa[i,j,a]*
                                                  B1[co] //Simplify


VijUafgUa[i_,j_,a_]:=8*Pi*MU^(2*ep)*AL*(2*(1-zi[i,j,a] + (1-xija[i,j,a]))^(-1) - 
                                         (1+zi[i,j,a])-ep*(1-zi[i,j,a]))//Simplify


     (* Massive case*)


DMijUafgUa[i_,j_,a_]:=-(2*p[i].p[j])^(-1)*xija[i,j,a]^(-1)*VMijUafgUa[i,j,a]*
                                                  B1[co] //Simplify


VMijUafgUa[i_,j_,a_]:=8*Pi*MU^(2*ep)*AL*(2*(2-zi[i,j,a] -xija[i,j,a])^(-1) - 
                      (1+zi[i,j,a]) - M[i]^2/p[i].p[j] -ep*(1-zi[i,j,a]))//Simplify


(* Splitting (2):(i,j)=(g,g) *)


(* [3.(ij,k)=(gg,k): Dij,k]  *)


Dijkggk[i_,j_,k_]:=-(2*p[i].p[j])^(-1)*16*Pi*MU^(2*ep)*AL*((C1ijkggk[i,j,k]+
                    C2ijkggk[i,j,k]*cdabs[eh[co]]^(2))*B1[co]
                   -2*C2ijkggk[i,j,k]*dreal[eh[co]^(2)*B1dh[co]]) //Simplify 


C1ijkggk[i_,j_,k_]:=(1-zi[i,j,k]*(1-yijk[i,j,k]))^(-1)+(1-zj[i,j,k]*(1-yijk[i,j,k]))^(-1)-2//Simplify


C2ijkggk[i_,j_,k_]:=(1 - ep)*(p[i].p[j])^(-1)


     (* Massive case*)


DMijkggk[i_,j_,k_]:=-(2*p[i].p[j])^(-1)*16*Pi*MU^(2*ep)*AL*((C1Mijkggk[i,j,k]+
                    C2Mijkggk[i,j,k]*cdabs[eh[co]]^(2))*B1[co]
                   -2*C2Mijkggk[i,j,k]*dreal[eh[co]^(2)*B1dh[co]]) //Simplify 


C1Mijkggk[i_,j_,k_]:=(1-zi[i,j,k]*(1-yijk[i,j,k]))^(-1)+(1-zj[i,j,k]*(1-yijk[i,j,k]))^(-1)-
(2 - kap*zpm3[i,j,k])/vijk[i,j,k]//Simplify


C2Mijkggk[i_,j_,k_]:=(1 - ep)*(p[i].p[j])^(-1)/vijk[i,j,k]//Simplify


pMij3[i_,j_,k_]:=-(Sqrt[(Qsq[i,j,k]-M[k]^2)^2]/Sqrt[lamb[Qsq[i,j,k],2*p[i].p[j],M[k]^2]])*
          (p[k] - (p[i].p[k] + p[j].p[k] + M[k]^2)/Qsq[i,j,k]*(p[i]+p[j]+p[k]))+
          s[i,j,k]/Qsq[i,j,k]*(p[i]+p[j]+p[k])//Simplify


pMk3[i_,j_,k_]:=p[i]+p[j]+p[k] - pMij3[i,j,k]//Simplify


zpm3[i_,j_,k_]:=(1 - vijk[i,j,k]^2)/4//Simplify


(* [4.(ij,a)=(gg,a): Dij^a]  *)


DijUaggUa[i_,j_,a_]:=-(2*p[i].p[j])^(-1)*xija[i,j,a]^(-1)*16*Pi*MU^(2*ep)*AL*((C1ijUaggUa[i,j,a]+
                    C2ijUaggUa[i,j,a]*cdabs[eh[co]]^(2))*B1[co]
                   -2*C2ijUaggUa[i,j,a]*dreal[eh[co]^(2)*B1dh[co]]) //Simplify 


C1ijUaggUa[i_,j_,a_]:=(1-zi[i,j,a] + (1-xija[i,j,a]))^(-1) + (1-zj[i,j,a] + 
                                                  (1-xija[i,j,a]))^(-1)-2//Simplify


C2ijUaggUa[i_,j_,a_]:=(1 - ep)*(p[i].p[j])^(-1)//Simplify


(* Splitting (3):(a,i)=(f,g) *)


(* [5.(ai,k)=(fg,k): D^ai,k] *)


DaiDkfgDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*VaiDkfgDk[a,i,k]*
                                                      B1[co]//Simplify


VaiDkfgDk[a_,i_,k_]:=8*Pi*MU^(2*ep)*AL*(2*(1 - xika[i,k,a] + ui[a,i,k])^(-1) - 
                     (1+xika[i,k,a])-ep*(1-xika[i,k,a]))//Simplify 


     (* Massive case*)


DMaiDkfgDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*VMaiDkfgDk[a,i,k]*
                                                      B1[co]//Simplify 


VMaiDkfgDk[a_,i_,k_]:=8*Pi*MU^(2*ep)*AL*(2*(2 - xika[i,k,a] - zi[k,i,a])^(-1) - 
                     (1+xika[i,k,a])-ep*(1-xika[i,k,a]))//Simplify 


(* [6.(ai,b)=(fg,b): D^ai,b] *)


Daibfgb[a_,i_,b_]:=-(2*p[a].p[i])^(-1)*xiab[i,a,b]^(-1)*Vaibfgb[a,i,b]*
                                                        B1[co]//Simplify


Vaibfgb[a_,i_,b_]:=8*Pi*MU^(2*ep)*AL*((1 + xiab[i,a,b]^(2))*(1 - xiab[i,a,b])^(-1) 
                                                - ep*(1 - xiab[i,a,b])) //Simplify 


(* Splitting (4):(a,i)=(g,g) *)


(* [7.(ai,k)=(gg,k): D^ai,k] *)


DaiDkggDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*16*Pi*MU^(2*ep)*AL*(
                     (C1aiDkggDk[a,i,k] + C2aiDkggDk[a,i,k]*cdabs[eh[co]]^(2))*B1[co]
                      -2*C2aiDkggDk[a,i,k]*dreal[eh[co]^(2)*B1dh[co]]) //Simplify 


C1aiDkggDk[a_,i_,k_]:=(1 - xika[i,k,a] + ui[a,i,k])^(-1) - 1 + xika[i,k,a]*(1 - xika[i,k,a])//Simplify 


C2aiDkggDk[a_,i_,k_]:=(1 - ep)* (1 - xika[i,k,a])*xika[i,k,a]^(-1)*ui[a,i,k]*(1 - 
                       ui[a,i,k])*(p[i].p[k])^(-1)//Simplify 


     (* Massive case*)


(*DMaiDkggDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*16*Pi*MU^(2*ep)*AL*(
                     (C1MaiDkggDk[a,i,k] + C2MaiDkggDk[a,i,k]*dabs[eh[co]]^(2))*B1[co]
                      -2*C2MaiDkggDk[a,i,k]*dreal[eh[co]^(2)*B1dh[co]]) //Simplify *)


DMaiDkggDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*16*Pi*MU^(2*ep)*AL*(
                     (C1aiDkggDk[a,i,k] + C2aiDkggDk[a,i,k]*cdabs[eh[co]]^(2))*B1[co]
                      -2*C2aiDkggDk[a,i,k]*dreal[eh[co]^(2)*B1dh[co]]) //Simplify 


(*C1MaiDkggDk[a_,i_,k_]:=(1 - xika[i,k,a] + ui[a,i,k])^(-1) - 1 + xika[i,k,a]*(1 - xika[i,k,a])//Simplify *)


(*C2MaiDkggDk[a_,i_,k_]:=(1 - ep)* (1 - xika[i,k,a])*xika[i,k,a]^(-1)*ui[a,i,k]*(1-ui[a,i,k])*
(p[i].p[k])^(-1)//Simplify *) 


(* [8.(ai,b)=(gg,b): D^ai,b] *)


Daibggb[a_,i_,b_]:=-(2*p[a].p[i])^(-1)*xiab[i,a,b]^(-1)*16*Pi*MU^(2*ep)*AL*(
                     (C1aibggb[a,i,b] + C2aibggb[a,i,b]*cdabs[eh[co]]^(2))*B1[co]
                      -2*C2aibggb[a,i,b]*dreal[eh[co]^(2)*B1dh[co]]) //Simplify 


C1aibggb[a_,i_,b_]:=xiab[i,a,b]*(1 - xiab[i,a,b])^(-1) + xiab[i,a,b]*(1 - xiab[i,a,b])//Simplify


C2aibggb[a_,i_,b_]:=(1 - ep)*(1 - xiab[i,a,b])*xiab[i,a,b]^(-1)*p[a].p[b]*(p[i].p[a])^(-1)* 
                (p[i].p[b])^(-1)//Simplify


(* Pgg[a_,i_,b_]:=2*CA*(xiab[i,a,b]*(1 - xiab[i,a,b])^(-1) + (1 -xiab[i,a,b])*
                     xiab[i,a,b]^(-1) + xiab[i,a,b]*(1 - xiab[i,a,b]))//Simplify *)


    (* Dipole 2 call *)


(* Splitting (5):(i,j)=(f,fbar) *)


(* [9.(ij,k)=(f fbar,k): Dij,k] *)


Dijkffk[i_,j_,k_]:=-(2*p[i].p[j])^(-1)*8*Pi*MU^(2*ep)*AL*(TR/CA)*
                   ((1+C2ijkffk[i,j]*cdabs[eh[co]]^(2))*B2[co]
                    -2*C2ijkffk[i,j]*dreal[eh[co]^(2)*B2dh[co]]) //Simplify 


C2ijkffk[i_,j_]:=- 2*(p[i].p[j])^(-1)


     (* Massive case*)


DMijkffk[i_,j_,k_]:=-(M[i]^2 + p[i].p[j])^(-1)*4*Pi*MU^(2*ep)*AL*(TR/CA)*(vijk[i,j,k])^(-1)*
                   ((C1Mijkffk[i,j,k]+C2Mijkffk[i,j]*cdabs[eh[co]]^(2))*B2[co]
                    -2*C2Mijkffk[i,j]*dreal[eh[co]^(2)*B2dh[co]]) //Simplify 


C1Mijkffk[i_,j_,k_]:= 1 - 2*kap*(1 - ep)^(-1)*(zpm9[i,j,k] - M[i]^2*(2*M[i]^2 + 2*p[i].p[j]))


C2Mijkffk[i_,j_]:=- 2*(M[i]^2 + p[i].p[j])^(-1)


zpm9[i_,j_,k_]:=4^(-1)*(1 - viji[i,j,k]^2*vijk[i,j,k]^2)//Simplify 


(* [10.(ij,a)=(f fbar,a): Dij^a] *)


DijUaffUa[i_,j_,a_]:=-(2*p[i].p[j])^(-1)*xija[i,j,a]^(-1)*8*Pi*MU^(2*ep)*AL*(TR/CA)*
                     ((1+C2ijUaffUa[i,j]*cdabs[eh[co]]^(2))*B2[co]
                      -2*C2ijUaffUa[i,j]*dreal[eh[co]^(2)*B2dh[co]]) //Simplify 


C2ijUaffUa[i_,j_]:=- 2*(p[i].p[j])^(-1)


     (* Massive case*)


DMijUaffUa[i_,j_,a_]:=-(2*M[i]^2 + 2*p[i].p[j])^(-1)*xmija[i,j,a,0]^(-1)*8*Pi*MU^(2*ep)*AL*(TR/CA)*
                     ((1+C2MijUaffUa[i,j]*cdabs[eh[co]]^(2))*B2[co]
                      -2*C2MijUaffUa[i,j]*dreal[eh[co]^(2)*B2dh[co]]) //Simplify 


C2MijUaffUa[i_,j_]:=- 2*(M[i]^2 + p[i].p[j])^(-1)


    (* Dipole 3 call *)


(* Splitting (6):(a,i)=(f,f) or (fbar,fbar) *)


(* [11.(ai,k)=(uu,k): D^ai,k]  *)


DaiDkffDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*8*Pi*MU^(2*ep)*AL*(CF/CA)*(
                     (C1aiDkffDk[a,i,k] + C2aiDkffDk[a,i,k]*cdabs[eh[co]]^(2))*B3[co]
                      -2*C2aiDkffDk[a,i,k]*dreal[eh[co]^(2)*B3dh[co]]) //Simplify


C1aiDkffDk[a_,i_,k_]:=xika[i,k,a]//Simplify


C2aiDkffDk[a_,i_,k_]:=(1 - xika[i,k,a])*xika[i,k,a]^(-1)*2*ui[a,i,k]*(1 - ui[a,i,k])*
                       (p[i].p[k])^(-1)//Simplify


     (* Massive case*)


DMaiDkffDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*8*Pi*MU^(2*ep)*AL*(CF/CA)*(
                     (C1MaiDkffDk[a,i,k] + C2MaiDkffDk[a,i,k]*cdabs[eh[co]]^(2))*B3[co]
                      -2*C2MaiDkffDk[a,i,k]*dreal[eh[co]^(2)*B3dh[co]]) //Simplify


C1MaiDkffDk[a_,i_,k_]:=xika[i,k,a]//Simplify


C2MaiDkffDk[a_,i_,k_]:=(1 - xika[i,k,a])*xika[i,k,a]^(-1)*2*zi[i,k,a]*(1 - zi[i,k,a])*
                       (p[i].p[k])^(-1)//Simplify


(* [12.(ai,b)=(uu,b): D^aib]  *)


Daibffb[a_,i_,b_]:=-(2*p[a].p[i])^(-1)*xiab[i,a,b]^(-1)*8*Pi*MU^(2*ep)*AL*(CF/CA)*(
                     (C1aibffb[a,i,b] + C2aibffb[a,i,b]*cdabs[eh[co]]^(2))*B3[co]
                      -2*C2aibffb[a,i,b]*dreal[eh[co]^(2)*B3dh[co]]) //Simplify


C1aibffb[a_,i_,b_]:=xiab[i,a,b]//Simplify


C2aibffb[a_,i_,b_]:=(1 - xiab[i,a,b])*xiab[i,a,b]^(-1)*2*p[a].p[b]*(p[i].p[a])^(-1)* 
                     (p[i].p[b])^(-1)//Simplify


    (* Dipole 4 call *)


(* Splitting (7):(a,i)=(g,f) or (g,fbar) *)


(* [13.(ai,k)=(gu,k): D^ai,k] *)


DaiDkgfDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*VaiDkgfDk[a,i,k]*
                                                    B4[co]//Simplify 


VaiDkgfDk[a_,i_,k_]:=8*Pi*MU^(2*ep)*AL*(TR/CF)*(1 - ep - 2*xika[i,k,a]*(1 - 
                                                    xika[i,k,a]))//Simplify 


     (* Massive case*)


DMaiDkgfDk[a_,i_,k_]:=-(2*p[a].p[i])^(-1)*xika[i,k,a]^(-1)*VMaiDkgfDk[a,i,k]*
                                                    B4[co]//Simplify 


VMaiDkgfDk[a_,i_,k_]:=8*Pi*MU^(2*ep)*AL*(TR/CF)*(1 - ep - 2*xika[i,k,a]*(1 - 
                                                    xika[i,k,a]))//Simplify 


(* [14.(ai,b)=(gu,b): D^aib]  *)


Daibgfb[a_,i_,b_]:=-(2*p[a].p[i])^(-1)*xiab[i,a,b]^(-1)*Vaibgfb[a,i,b]*
                                                   B4[co]//Simplify 


Vaibgfb[a_,i_,b_]:=8*Pi*MU^(2*ep)*AL*(TR/CF)*(1 - ep - 2*xiab[i,a,b]*(1 - xiab[i,a,b]))//Simplify 


(* SUSY dipoles*)


(*[SUSY1.(ij,k)=(squark,g,k): Dij,k]*)


DMSijksfgk[i_,j_,k_]:=-(2*p[i].p[j])^(-1)*VMSijksfgk[i,j,k]*B1[co]//Simplify


VMSijksfgk[i_,j_,k_]:=8*Pi*MU^(2*ep)*AL*(
              2*(1-zi[i,j,k]*(1-yijk[i,j,k]))^(-1) 
              -vtildijk1[i,j,k]*(vijk[i,j,k])^(-1)*(2+M[i]^(2)*(p[i].p[j])^(-1)))//Simplify


(*[SUSY2.(ij,a)=(squark,g,a): Dij^a]*)


DMSijasfga[i_,j_,a_]:=-(2*p[i].p[j])^(-1)*xija[i,j,a]^(-1)*VMSijasfga[i,j,a]*B1[co] //Simplify


VMSijasfga[i_,j_,a_]:=8*Pi*MU^(2*ep)*AL*(2*(2-zi[i,j,a] -xija[i,j,a])^(-1) - 2 
                                                   - M[i]^2/p[i].p[j])//Simplify


(*  Variables *)


(* for Massless dipoles*)


zi[i_,j_,k_]:=p[i].p[k]*(p[j].p[k] + p[i].p[k])^(-1)


zj[i_,j_,k_]:=1-zi[i,j,k]


yijk[i_,j_,k_]:=p[i].p[j]*(p[i].p[j] + p[j].p[k] + p[i].p[k])^(-1)


pij[i_,j_,k_]:=p[i] + p[j] - yijk[i,j,k]*(1-yijk[i,j,k])^(-1)*p[k]//Simplify


pk[i_,j_,k_]:=(1-yijk[i,j,k])^(-1)*p[k]//Simplify


xija[i_,j_,a_]:=(p[i].p[a] + p[j].p[a] - p[i].p[j])*(p[i].p[a] + p[j].p[a])^(-1)//Simplify


pija[i_,j_,a_]:=p[i] + p[j] - (1-xija[i,j,a])*p[a]//Simplify


pa[i_,j_,a_]:=xija[i,j,a]*p[a]//Simplify


ui[a_,i_,k_]:=p[i].p[a]*(p[i].p[a] + p[k].p[a])^(-1)


xika[i_,k_,a_]:=(p[i].p[a] + p[k].p[a] - p[i].p[k])*(p[i].p[a] + p[k].p[a])^(-1)//Simplify


pai[a_,i_,k_]:=xika[i,k,a]*p[a]//Simplify


paikk[a_,i_,k_]:=p[k] + p[i] - (1-xika[i,k,a])*p[a]//Simplify


xiab[i_,a_,b_]:=(p[a].p[b] - p[i].p[a] - p[i].p[b])/p[a].p[b]//Simplify


paibai[a_,i_,b_]:=xiab[i,a,b]*p[a]//Simplify


ptil[j_,a_,i_,b_]:=p[j] -((1+xiab[i,a,b])*p[a]+2*p[b]-p[i])*((1+xiab[i,a,b])*p[j].p[a]+2*p[j].p[b]-p[j].p[i])*
(2*(1+xiab[i,a,b])*p[a].p[b]-(1+xiab[i,a,b])*p[a].p[i] -2*p[b].p[i])^(-1)+
(p[j].p[a]+p[j].p[b]-p[j].p[i])*(p[a].p[b]-p[a].p[i]-p[b].p[i])^(-1)*(xiab[i,a,b]*p[a]+p[b]);


(*ptil[j_,a_,i_,b_]:=p[j]-2*((1 - xiab[i,a,b])*p[j].p[a] - p[j].p[i])*
       (-2*(1 - xiab[i,a,b])*p[i].p[a] + M[i]^2)^(-1)*((1 - xiab[i,a,b])*p[a] - p[i])//Simplify *)


(* q[a_,i_,b_]:=(1 - xiab[i,a,b])*p[a] - p[i]//Simplify *)


(* ns[a],ns[ai]: Number of polarization *)


(*B[c_]:=Which[TrueQ[c==a],A[1],TrueQ[c==b],A[2]];*)


(*ns[c_]:=Which[(TrueQ[B[c]== u]||TrueQ[B[c]==ubar]||TrueQ[B[c]== u]||TrueQ[B[c]==ubar]),
            nsf,TrueQ[B[c]==g],nsg];*)


(*nstil[c_,i_]:=If[TrueQ[B[c]==X[i]],nstilg,nstilf];*)


(* nsf=2;nstilf=2;nsg=2*(1-ep);nstilg=2*(1-ep); *)


(* for Massive dipoles*)


s[i_,j_,k_]:=p[i].p[j]+p[j].p[k]+p[k].p[i]


Qsq[i_,j_,k_]:=M[i]^2+M[j]^2+M[k]^2+2*s[i,j,k]


lamb[x_,y_,z_]:=x^2+y^2+z^2-2*(x*y+y*z+z*x)//Expand//Simplify


musq[l_,i_,j_,k_]:=M[l]^(2)/Qsq[i,j,k]


vijknum[i_,j_,k_]:=(M[k]^2 + s[i,j,k]*(1 -yijk[i,j,k]))^2 - M[k]^2*Qsq[i,j,k]//Expand//Simplify


vijkden[i_,j_,k_]:=s[i,j,k]*(1 - yijk[i,j,k])//Expand//Simplify


vijk[i_,j_,k_]:=Sqrt[vijknum[i,j,k]]/vijkden[i,j,k]//Simplify


viji[i_,j_,k_]:=Sqrt[s[i,j,k]^2*yijk[i,j,k]^2 - M[i]^2*M[j]^2]/(s[i,j,k]*yijk[i,j,k] + M[i]^2)//Simplify


zim[i_,j_,k_]:=zi[i,j,k] - (1 - vijk[i,j,k])/2//Simplify


pMij[i_,j_,k_,mij_]:=-(Sqrt[lamb[Qsq[i,j,k],mij^2,M[k]^2]]/
                        Sqrt[lamb[Qsq[i,j,k],M[i]^2+M[j]^2+2*p[i].p[j],M[k]^2]])*
          (p[k] - (p[i].p[k] + p[j].p[k] + M[k]^2)/Qsq[i,j,k]*(p[i]+p[j]+p[k]))+
          (Qsq[i,j,k]-M[k]^2+mij^2)/(2*Qsq[i,j,k])*(p[i]+p[j]+p[k])//Simplify


pMk[i_,j_,k_,mij_]:=p[i]+p[j]+p[k] - pMij[i,j,k,mij]//Simplify


xmija[i_,j_,a_,mij_]:=(p[i].p[a] + p[j].p[a] - p[i].p[j] + 2^(-1)*(mij^2 - M[i]^2 - M[j]^2))*
                       (p[i].p[a] + p[j].p[a])^(-1)//Simplify


pMija[i_,j_,a_,mij_]:=p[i] + p[j] - (1-xmija[i,j,a,mij])*p[a]//Simplify


pMa[i_,j_,a_,mij_]:=xmija[i,j,a,mij]*p[a]//Simplify


pless[k_]:=p[k] - M[k]^2*q[2]/(2*p[k].q[2]);


(* E for Massless dipoles*)


Eijk[i_,j_,k_]:=ph[pem[0,co]]*zi[i,j,k]*sp[p[j],p[i]]*spc[pem[0,co],p[i]]/(rtwo*sp[p[j],pem[0,co]])


Eija[i_,j_,a_]:=ph[pem[0,co]]*zi[i,j,a]*sp[p[j],p[i]]*spc[pem[0,co],p[i]]/(rtwo*sp[p[j],pem[0,co]])


Eaik[a_,i_,k_]:=sp[p[i],p[k]]*spzc[p[k],pem[0,co]]/(rtwo*(1-ui[a,i,k])*spz[p[i],pem[0,co]])//Simplify


Eaib[a_,i_,b_]:=-s[a,i]*spz[p[i],p[b]]*zspz[pem[0,co],p[b]]/(rtwo*sab*spz[p[i],pem[0,co]])//Simplify 


(* EM for Massive dipoles*)


EMijk[i_,j_,k_]:=ph[pem[0,co]]*zim[i,j,k]*sp[p[j],p[i]]*spc[pem[0,co],p[i]]/(rtwo*sp[p[j],pem[0,co]])


EMija[i_,j_,k_]:=ph[pem[0,co]]*zim[i,j,k]*sp[p[j],p[i]]*spc[pem[0,co],p[i]]/(rtwo*sp[p[j],pem[0,co]])


EMaik[a_,i_,k_]:=sp[p[i],plk[0,co]]*spzc[plk[0,co],pem[0,co]]/(rtwo*spz[p[i],pem[0,co]]*(1-ui[a,i,k]))


(* Add for scalar transformation *)


replist1[i_,j_,k_]:={p[i].p[j]->t[i,j],p[j].p[i]->t[i,j],p[i].p[k]->t[i,k],
                        p[k].p[i]->t[i,k],p[j].p[k]->t[j,k],p[k].p[j]->t[k,j]}


t[i_Integer,j_Integer]:=If[i<j,s[i,j]/2,s[j,i]/2];


t[i_Integer,j_Symbol]:=s[j,i]/2;


t[i_Symbol,j_Integer]:=s[i,j]/2;


t[a,b]=s[a,b]/2;t[b,a]=s[a,b]/2;


s[i_,j_]:=Module[{},tmp={ToString[s],ToString[i],ToString[j]};
tmp2=StringJoin[tmp];ToExpression[tmp2]];


repmom[i_,j_,k_]:={p[i]->p[r,i+2],p[j]->p[r,j+2],p[k]->p[r,k+2]}


repmom2[i_,j_,k_]:={p[i]->p[i+2],p[j]->p[j+2],p[k]->p[k+2]}


repmom3[i_,j_,k_]:={p[i]->p[0,i+2],p[j]->p[0,j+2],p[k]->p[0,k+2]}


collinearset[co_,emit1_,emit2_]:=Module[{},
                                          If[IntegerQ[emit1],dum1=emit1+2,
                                          If[emit1==a,dum1=1];If[emit1==b,dum1=2];];
                                          If[IntegerQ[emit2],dum2=emit2+2,
                                          If[emit2==a,dum2=1];If[emit2==b,dum2=2];];
                                  If[dum1 > dum2,temp1=dum1;temp2=dum2;dum1=temp2;dum2=temp1];
                                          emitpair[co]={dum1,dum2};
                                        ];


messageforIPK:=Module[{},
Print["*************************************************************************"];
(*Print["I, P and K terms which can be created by the following run"];
Print["-------------------"];*)
If[dAs >= 1, 
(*Print["You can create I-term by the command, `VirtualCreation' for the process,"];*)
Print["I-term can be created for the process"];
Print["B1:",{A[1],A[2]}," --> ", A1];
Print["-------------------"];
];
pkexist=0;
pkexist=dss[3]+dss[4];
If[pkexist >= 1,
(*Print["You can create P and K-terms by the command, `PDFfactorizationCreation' 
for the process,"];*)
Print["P and K terms can be created for the process"];
Print["B1:",{A[1],A[2]}," --> ", A1];
];
];


printsummary:=Module[{},
Print["\n\n\n"];
Print["--------------------------------------------------------------------"];
Print["-----------------------Summary of creation------------------------"];
Print["--------------------------------------------------------------------"];
Print["NLO real correction: ",{A[1],A[2]}," --> ",flistm];
Print["D :",dtotal];
If[dAstotal >= 1, Print["B1:",{A[1],A[2]}," --> ", A1,"\n"];];
If[dss[51] >= 1, Print["B2u:",{A[1],A[2]}," --> ", A2a1,"\n"];];
If[dss[53] >= 1, Print["B2d:",{A[1],A[2]}," --> ", A2a2,"\n"];];
If[dss[54] >= 1, Print["B2s:",{A[1],A[2]}," --> ", A2a5,"\n"];];
If[dss[55] >= 1, Print["B2c:",{A[1],A[2]}," --> ", A2a6,"\n"];];
If[dss[57] >= 1, Print["B2b:",{A[1],A[2]}," --> ", A2a4,"\n"];];
If[dss[58] >= 1, Print["B2t:",{A[1],A[2]}," --> ", A2a3,"\n"];];
If[dss[61] >= 1, Print["B3u:",A3a1in," --> ", A3a1,"\n"];];
If[dss[62] >= 1, Print["B3ubar:",A3a2in," --> ", A3a2,"\n"];];
If[dss[63] >= 1, Print["B3d:",A3a3in," --> ", A3a3,"\n"];];
If[dss[64] >= 1, Print["B3dbar:",A3a4in," --> ", A3a4,"\n"];];
If[dss[65] >= 1, Print["B3s:",A3a5in," --> ", A3a5,"\n"];];
If[dss[66] >= 1, Print["B3sbar:",A3a6in," --> ", A3a6,"\n"];];
If[dss[67] >= 1, Print["B3c:",A3a7in," --> ", A3a7,"\n"];];
If[dss[68] >= 1, Print["B3cbar:",A3a8in," --> ", A3a8,"\n"];];
If[dss[69] >= 1, Print["B3b:",A3a9in," --> ", A3a9,"\n"];];
If[dss[70] >= 1, Print["B3bbar:",A3a10in," --> ", A3a10,"\n"];];
If[dss[71] >= 1, Print["B4u:",A4a1in," --> ", A4a1,"\n"];];
If[dss[72] >= 1, Print["B4ubar:",A4a2in," --> ", A4a2,"\n"];];
If[dss[73] >= 1, Print["B4d:",A4a3in," --> ", A4a3,"\n"];];
If[dss[74] >= 1, Print["B4dbar:",A4a4in," --> ", A4a4,"\n"];];
If[dss[75] >= 1, Print["B4s:",A4a5in," --> ", A4a5,"\n"];];
If[dss[76] >= 1, Print["B4sbar:",A4a6in," --> ", A4a6,"\n"];];
If[dss[77] >= 1, Print["B4c:",A4a7in," --> ", A4a7,"\n"];];
If[dss[78] >= 1, Print["B4cbar:",A4a8in," --> ", A4a8,"\n"];];
If[dss[79] >= 1, Print["B4b:",A4a9in," --> ", A4a9,"\n"];];
If[dss[80] >= 1, Print["B4bbar:",A4a10in," --> ", A4a10,"\n"];];
Print[""];
If[dAstotal >=1, Print["I :",itotal];
Print["B1:",{A[1],A[2]}," --> ", A1];];
Print[""];
If[pkexist >= 1, Print["PK :",pksum];
Print["B1:",{A[1],A[2]}," --> ", A1];];
Print["--------------------------------------------------------------------"];
Print["--------------------------------END---------------------------------"];
Print["--------------------------------------------------------------------"];
]
